/********************************************************************************
** Form generated from reading UI file 'ClassesWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CLASSESWIDGET_H
#define UI_CLASSESWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/IaitoTreeView.h"

QT_BEGIN_NAMESPACE

class Ui_ClassesWidget
{
public:
    QAction *seekToVTableAction;
    QAction *editMethodAction;
    QAction *addMethodAction;
    QAction *newClassAction;
    QAction *renameClassAction;
    QAction *deleteClassAction;
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout;
    IaitoTreeView *classesTreeView;
    QHBoxLayout *horizontalLayout_17;
    QLabel *classSourceLabel;
    QComboBox *classSourceCombo;

    void setupUi(QDockWidget *ClassesWidget)
    {
        if (ClassesWidget->objectName().isEmpty())
            ClassesWidget->setObjectName("ClassesWidget");
        ClassesWidget->resize(400, 300);
        ClassesWidget->setWindowTitle(QString::fromUtf8("Classes"));
        seekToVTableAction = new QAction(ClassesWidget);
        seekToVTableAction->setObjectName("seekToVTableAction");
        editMethodAction = new QAction(ClassesWidget);
        editMethodAction->setObjectName("editMethodAction");
        addMethodAction = new QAction(ClassesWidget);
        addMethodAction->setObjectName("addMethodAction");
        newClassAction = new QAction(ClassesWidget);
        newClassAction->setObjectName("newClassAction");
        renameClassAction = new QAction(ClassesWidget);
        renameClassAction->setObjectName("renameClassAction");
        deleteClassAction = new QAction(ClassesWidget);
        deleteClassAction->setObjectName("deleteClassAction");
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        verticalLayout = new QVBoxLayout(dockWidgetContents);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        classesTreeView = new IaitoTreeView(dockWidgetContents);
        classesTreeView->setObjectName("classesTreeView");
        classesTreeView->setContextMenuPolicy(Qt::CustomContextMenu);
        classesTreeView->setStyleSheet(QString::fromUtf8("IaitoTreeView::item\n"
"{\n"
"    padding-top: 1px;\n"
"    padding-bottom: 1px;\n"
"}"));
        classesTreeView->setFrameShape(QFrame::NoFrame);
        classesTreeView->setLineWidth(0);
        classesTreeView->setSortingEnabled(true);
        classesTreeView->setExpandsOnDoubleClick(false);

        verticalLayout->addWidget(classesTreeView);

        horizontalLayout_17 = new QHBoxLayout();
        horizontalLayout_17->setSpacing(10);
        horizontalLayout_17->setObjectName("horizontalLayout_17");
        horizontalLayout_17->setContentsMargins(0, 0, 0, -1);
        classSourceLabel = new QLabel(dockWidgetContents);
        classSourceLabel->setObjectName("classSourceLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(classSourceLabel->sizePolicy().hasHeightForWidth());
        classSourceLabel->setSizePolicy(sizePolicy);

        horizontalLayout_17->addWidget(classSourceLabel);

        classSourceCombo = new QComboBox(dockWidgetContents);
        classSourceCombo->addItem(QString());
        classSourceCombo->addItem(QString());
        classSourceCombo->setObjectName("classSourceCombo");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(classSourceCombo->sizePolicy().hasHeightForWidth());
        classSourceCombo->setSizePolicy(sizePolicy1);

        horizontalLayout_17->addWidget(classSourceCombo);


        verticalLayout->addLayout(horizontalLayout_17);

        ClassesWidget->setWidget(dockWidgetContents);

        retranslateUi(ClassesWidget);

        QMetaObject::connectSlotsByName(ClassesWidget);
    } // setupUi

    void retranslateUi(QDockWidget *ClassesWidget)
    {
        seekToVTableAction->setText(QCoreApplication::translate("ClassesWidget", "Seek to VTable", nullptr));
        editMethodAction->setText(QCoreApplication::translate("ClassesWidget", "Edit Method", nullptr));
        addMethodAction->setText(QCoreApplication::translate("ClassesWidget", "Add Method", nullptr));
        newClassAction->setText(QCoreApplication::translate("ClassesWidget", "Create new Class", nullptr));
        renameClassAction->setText(QCoreApplication::translate("ClassesWidget", "Rename Class", nullptr));
        deleteClassAction->setText(QCoreApplication::translate("ClassesWidget", "Delete Class", nullptr));
        classSourceLabel->setText(QCoreApplication::translate("ClassesWidget", "Source:", nullptr));
        classSourceCombo->setItemText(0, QCoreApplication::translate("ClassesWidget", "Binary Info (Fixed)", nullptr));
        classSourceCombo->setItemText(1, QCoreApplication::translate("ClassesWidget", "Analysis (Editable)", nullptr));

        (void)ClassesWidget;
    } // retranslateUi

};

namespace Ui {
    class ClassesWidget: public Ui_ClassesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CLASSESWIDGET_H
