/********************************************************************************
** Form generated from reading UI file 'ConsoleWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONSOLEWIDGET_H
#define UI_CONSOLEWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "common/DirectionalComboBox.h"

QT_BEGIN_NAMESPACE

class Ui_ConsoleWidget
{
public:
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout;
    QPlainTextEdit *outputTextEdit;
    QGridLayout *gridLayout;
    DirectionalComboBox *inputCombo;
    QLineEdit *r2InputLineEdit;
    QLineEdit *debugeeInputLineEdit;
    QToolButton *execButton;

    void setupUi(QDockWidget *ConsoleWidget)
    {
        if (ConsoleWidget->objectName().isEmpty())
            ConsoleWidget->setObjectName("ConsoleWidget");
        ConsoleWidget->resize(400, 300);
        ConsoleWidget->setWindowTitle(QString::fromUtf8("Console"));
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        verticalLayout = new QVBoxLayout(dockWidgetContents);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        outputTextEdit = new QPlainTextEdit(dockWidgetContents);
        outputTextEdit->setObjectName("outputTextEdit");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(outputTextEdit->sizePolicy().hasHeightForWidth());
        outputTextEdit->setSizePolicy(sizePolicy);
        QFont font;
        font.setFamilies({QString::fromUtf8("Monospace")});
        outputTextEdit->setFont(font);
        outputTextEdit->setFrameShape(QFrame::NoFrame);
        outputTextEdit->setLineWidth(0);
        outputTextEdit->setUndoRedoEnabled(false);
        outputTextEdit->setReadOnly(true);
        outputTextEdit->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        verticalLayout->addWidget(outputTextEdit);

        gridLayout = new QGridLayout();
        gridLayout->setSpacing(5);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(4, 2, 2, 2);
        inputCombo = new DirectionalComboBox(dockWidgetContents);
        inputCombo->addItem(QString());
        inputCombo->addItem(QString());
        inputCombo->setObjectName("inputCombo");
        inputCombo->setSizeAdjustPolicy(QComboBox::AdjustToContents);
        inputCombo->setVisible(false);

        gridLayout->addWidget(inputCombo, 0, 0, 1, 1);

        r2InputLineEdit = new QLineEdit(dockWidgetContents);
        r2InputLineEdit->setObjectName("r2InputLineEdit");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(r2InputLineEdit->sizePolicy().hasHeightForWidth());
        r2InputLineEdit->setSizePolicy(sizePolicy1);
        r2InputLineEdit->setFrame(false);
        r2InputLineEdit->setClearButtonEnabled(true);

        gridLayout->addWidget(r2InputLineEdit, 0, 1, 1, 1);

        debugeeInputLineEdit = new QLineEdit(dockWidgetContents);
        debugeeInputLineEdit->setObjectName("debugeeInputLineEdit");
        debugeeInputLineEdit->setVisible(false);
        sizePolicy1.setHeightForWidth(debugeeInputLineEdit->sizePolicy().hasHeightForWidth());
        debugeeInputLineEdit->setSizePolicy(sizePolicy1);
        debugeeInputLineEdit->setFrame(false);
        debugeeInputLineEdit->setClearButtonEnabled(true);

        gridLayout->addWidget(debugeeInputLineEdit, 0, 1, 1, 1);

        execButton = new QToolButton(dockWidgetContents);
        execButton->setObjectName("execButton");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(execButton->sizePolicy().hasHeightForWidth());
        execButton->setSizePolicy(sizePolicy2);
        execButton->setStyleSheet(QString::fromUtf8(""));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/img/icons/arrow_right.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        execButton->setIcon(icon);
        execButton->setIconSize(QSize(24, 16));

        gridLayout->addWidget(execButton, 0, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        ConsoleWidget->setWidget(dockWidgetContents);

        retranslateUi(ConsoleWidget);

        QMetaObject::connectSlotsByName(ConsoleWidget);
    } // setupUi

    void retranslateUi(QDockWidget *ConsoleWidget)
    {
        outputTextEdit->setPlainText(QString());
        inputCombo->setItemText(0, QCoreApplication::translate("ConsoleWidget", "R2 Console", nullptr));
        inputCombo->setItemText(1, QCoreApplication::translate("ConsoleWidget", "Debugee Input", nullptr));

        r2InputLineEdit->setPlaceholderText(QCoreApplication::translate("ConsoleWidget", " Type \"?\" for help", nullptr));
        debugeeInputLineEdit->setPlaceholderText(QCoreApplication::translate("ConsoleWidget", " Enter input for the debugee", nullptr));
#if QT_CONFIG(tooltip)
        execButton->setToolTip(QCoreApplication::translate("ConsoleWidget", "Execute command", nullptr));
#endif // QT_CONFIG(tooltip)
        execButton->setText(QCoreApplication::translate("ConsoleWidget", "...", nullptr));
        (void)ConsoleWidget;
    } // retranslateUi

};

namespace Ui {
    class ConsoleWidget: public Ui_ConsoleWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CONSOLEWIDGET_H
