/****************************************************************************
** Meta object code from reading C++ file 'DisassemblerGraphView.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/widgets/DisassemblerGraphView.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DisassemblerGraphView.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21DisassemblerGraphViewE_t {};
} // unnamed namespace

template <> constexpr inline auto DisassemblerGraphView::qt_create_metaobjectdata<qt_meta_tag_ZN21DisassemblerGraphViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DisassemblerGraphView",
        "nameChanged",
        "",
        "name",
        "refreshView",
        "onSeekChanged",
        "RVA",
        "addr",
        "takeTrue",
        "takeFalse",
        "nextInstr",
        "prevInstr",
        "seekPrevBlock",
        "copySelection",
        "centerOnFocusedNode",
        "applyAddressRangeSelection",
        "start",
        "end",
        "showExportDialog",
        "onActionHighlightBITriggered",
        "onActionUnhighlightBITriggered"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'refreshView'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onSeekChanged'
        QtMocHelpers::SlotData<void(RVA)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'takeTrue'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'takeFalse'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'nextInstr'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'prevInstr'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'seekPrevBlock'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copySelection'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'centerOnFocusedNode'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'applyAddressRangeSelection'
        QtMocHelpers::SlotData<void(RVA, RVA)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 16 }, { 0x80000000 | 6, 17 },
        }}),
        // Slot 'showExportDialog'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onActionHighlightBITriggered'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onActionUnhighlightBITriggered'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DisassemblerGraphView, qt_meta_tag_ZN21DisassemblerGraphViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DisassemblerGraphView::staticMetaObject = { {
    QMetaObject::SuperData::link<IaitoGraphView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21DisassemblerGraphViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21DisassemblerGraphViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21DisassemblerGraphViewE_t>.metaTypes,
    nullptr
} };

void DisassemblerGraphView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DisassemblerGraphView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->refreshView(); break;
        case 2: _t->onSeekChanged((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1]))); break;
        case 3: _t->takeTrue(); break;
        case 4: _t->takeFalse(); break;
        case 5: _t->nextInstr(); break;
        case 6: _t->prevInstr(); break;
        case 7: _t->seekPrevBlock(); break;
        case 8: _t->copySelection(); break;
        case 9: _t->centerOnFocusedNode(); break;
        case 10: _t->applyAddressRangeSelection((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<RVA>>(_a[2]))); break;
        case 11: _t->showExportDialog(); break;
        case 12: _t->onActionHighlightBITriggered(); break;
        case 13: _t->onActionUnhighlightBITriggered(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DisassemblerGraphView::*)(const QString & )>(_a, &DisassemblerGraphView::nameChanged, 0))
            return;
    }
}

const QMetaObject *DisassemblerGraphView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DisassemblerGraphView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21DisassemblerGraphViewE_t>.strings))
        return static_cast<void*>(this);
    return IaitoGraphView::qt_metacast(_clname);
}

int DisassemblerGraphView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = IaitoGraphView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void DisassemblerGraphView::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
