/********************************************************************************
** Form generated from reading UI file 'Dashboard.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DASHBOARD_H
#define UI_DASHBOARD_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_Dashboard
{
public:
    QWidget *dockWidgetContents;
    QHBoxLayout *horizontalLayout;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer;
    QFrame *mainFrame;
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QFrame *line;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_2;
    QFormLayout *formLayout;
    QLabel *label_3;
    QLineEdit *fileEdit;
    QLabel *label_10;
    QLineEdit *formatEdit;
    QLabel *label_11;
    QLineEdit *modeEdit;
    QLabel *label_12;
    QLabel *label_13;
    QLineEdit *typeEdit;
    QLabel *label_15;
    QLineEdit *classEdit;
    QLabel *label_18;
    QLineEdit *langEdit;
    QLabel *label_19;
    QLineEdit *bitsEdit;
    QLineEdit *sizeEdit;
    QFormLayout *formLayout_4;
    QLabel *label_4;
    QLineEdit *fdEdit;
    QLabel *label_20;
    QLineEdit *baddrEdit;
    QLabel *label_21;
    QLineEdit *vaEdit;
    QLabel *label_22;
    QLineEdit *canaryEdit;
    QLabel *label_23;
    QLineEdit *cryptoEdit;
    QLabel *label_24;
    QLineEdit *nxEdit;
    QLabel *label_25;
    QLineEdit *picEdit;
    QLabel *label_26;
    QLabel *label_34;
    QLineEdit *relroEdit;
    QLineEdit *staticEdit;
    QFormLayout *formLayout_3;
    QLabel *label_14;
    QLineEdit *archEdit;
    QLabel *label_16;
    QLineEdit *machineEdit;
    QLabel *label_17;
    QLineEdit *osEdit;
    QLabel *label_30;
    QLineEdit *subsysEdit;
    QLabel *label_27;
    QLineEdit *strippedEdit;
    QLabel *label_29;
    QLineEdit *relocsEdit;
    QLabel *label_28;
    QLineEdit *endianEdit;
    QLabel *label_31;
    QLineEdit *compilationDateEdit;
    QLabel *label_5;
    QLineEdit *compilerEdit;
    QSpacerItem *verticalSpacer_2;
    QFrame *line_3;
    QHBoxLayout *horizontalLayout_7;
    QPushButton *certificateButton;
    QPushButton *versioninfoButton;
    QFrame *line_2;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_7;
    QLabel *label_6;
    QHBoxLayout *horizontalLayout_4;
    QVBoxLayout *verticalLayout_4;
    QVBoxLayout *hashesVerticalLayout;
    QLabel *label_9;
    QFormLayout *formLayout_5;
    QLabel *functionsLabel;
    QLineEdit *functionsLineEdit;
    QLabel *xRefsLabel;
    QLineEdit *xRefsLineEdit;
    QLabel *callsLabel;
    QLineEdit *callsLineEdit;
    QLabel *stringsLabel;
    QLineEdit *stringsLineEdit;
    QLabel *symbolsLabel;
    QLineEdit *symbolsLineEdit;
    QLabel *importsLabel;
    QLineEdit *importsLineEdit;
    QLabel *coverageLabel;
    QLineEdit *coverageLineEdit;
    QLabel *codeSizeLabel;
    QLineEdit *codeSizeLineEdit;
    QLabel *percentageLabel;
    QLineEdit *percentageLineEdit;
    QVBoxLayout *verticalLayout_2;
    QSpacerItem *verticalSpacer;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QDockWidget *Dashboard)
    {
        if (Dashboard->objectName().isEmpty())
            Dashboard->setObjectName("Dashboard");
        Dashboard->resize(1055, 999);
        Dashboard->setStyleSheet(QString::fromUtf8(""));
        Dashboard->setWindowTitle(QString::fromUtf8("Dashboard"));
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        horizontalLayout = new QHBoxLayout(dockWidgetContents);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        scrollArea = new QScrollArea(dockWidgetContents);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setFrameShape(QFrame::NoFrame);
        scrollArea->setFrameShadow(QFrame::Plain);
        scrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 1055, 980));
        horizontalLayout_5 = new QHBoxLayout(scrollAreaWidgetContents);
        horizontalLayout_5->setSpacing(0);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalLayout_5->setContentsMargins(0, 0, 0, 0);
        horizontalSpacer = new QSpacerItem(39, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer);

        mainFrame = new QFrame(scrollAreaWidgetContents);
        mainFrame->setObjectName("mainFrame");
        mainFrame->setMinimumSize(QSize(800, 0));
        mainFrame->setFrameShape(QFrame::NoFrame);
        mainFrame->setFrameShadow(QFrame::Plain);
        verticalLayout = new QVBoxLayout(mainFrame);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(mainFrame);
        label->setObjectName("label");
        QFont font;
        font.setPointSize(19);
        font.setBold(true);
        label->setFont(font);
        label->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        verticalLayout->addWidget(label);

        line = new QFrame(mainFrame);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        label_2 = new QLabel(mainFrame);
        label_2->setObjectName("label_2");
        QFont font1;
        font1.setPointSize(17);
        font1.setBold(true);
        label_2->setFont(font1);
        label_2->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        verticalLayout->addWidget(label_2);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(10);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(-1, 0, -1, 0);
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout->setLabelAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        formLayout->setVerticalSpacing(3);
        label_3 = new QLabel(mainFrame);
        label_3->setObjectName("label_3");
        QFont font2;
        font2.setBold(true);
        label_3->setFont(font2);
        label_3->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_3);

        fileEdit = new QLineEdit(mainFrame);
        fileEdit->setObjectName("fileEdit");
        fileEdit->setFrame(false);
        fileEdit->setReadOnly(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, fileEdit);

        label_10 = new QLabel(mainFrame);
        label_10->setObjectName("label_10");
        label_10->setFont(font2);
        label_10->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_10);

        formatEdit = new QLineEdit(mainFrame);
        formatEdit->setObjectName("formatEdit");
        formatEdit->setFrame(false);
        formatEdit->setReadOnly(true);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, formatEdit);

        label_11 = new QLabel(mainFrame);
        label_11->setObjectName("label_11");
        label_11->setFont(font2);
        label_11->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_11);

        modeEdit = new QLineEdit(mainFrame);
        modeEdit->setObjectName("modeEdit");
        modeEdit->setFrame(false);
        modeEdit->setReadOnly(true);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, modeEdit);

        label_12 = new QLabel(mainFrame);
        label_12->setObjectName("label_12");
        label_12->setFont(font2);
        label_12->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_12);

        label_13 = new QLabel(mainFrame);
        label_13->setObjectName("label_13");
        label_13->setFont(font2);
        label_13->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_13);

        typeEdit = new QLineEdit(mainFrame);
        typeEdit->setObjectName("typeEdit");
        typeEdit->setFrame(false);
        typeEdit->setReadOnly(true);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, typeEdit);

        label_15 = new QLabel(mainFrame);
        label_15->setObjectName("label_15");
        label_15->setFont(font2);
        label_15->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_15);

        classEdit = new QLineEdit(mainFrame);
        classEdit->setObjectName("classEdit");
        classEdit->setFrame(false);
        classEdit->setReadOnly(true);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, classEdit);

        label_18 = new QLabel(mainFrame);
        label_18->setObjectName("label_18");
        label_18->setFont(font2);
        label_18->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, label_18);

        langEdit = new QLineEdit(mainFrame);
        langEdit->setObjectName("langEdit");
        langEdit->setFrame(false);
        langEdit->setReadOnly(true);

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, langEdit);

        label_19 = new QLabel(mainFrame);
        label_19->setObjectName("label_19");
        label_19->setFont(font2);
        label_19->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_19);

        bitsEdit = new QLineEdit(mainFrame);
        bitsEdit->setObjectName("bitsEdit");
        bitsEdit->setFrame(false);
        bitsEdit->setReadOnly(true);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, bitsEdit);

        sizeEdit = new QLineEdit(mainFrame);
        sizeEdit->setObjectName("sizeEdit");
        sizeEdit->setFrame(false);
        sizeEdit->setReadOnly(true);

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, sizeEdit);


        horizontalLayout_2->addLayout(formLayout);

        formLayout_4 = new QFormLayout();
        formLayout_4->setObjectName("formLayout_4");
        formLayout_4->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout_4->setLabelAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        formLayout_4->setVerticalSpacing(3);
        formLayout_4->setContentsMargins(-1, 0, -1, -1);
        label_4 = new QLabel(mainFrame);
        label_4->setObjectName("label_4");
        label_4->setFont(font2);
        label_4->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, label_4);

        fdEdit = new QLineEdit(mainFrame);
        fdEdit->setObjectName("fdEdit");
        fdEdit->setFrame(false);
        fdEdit->setReadOnly(true);

        formLayout_4->setWidget(0, QFormLayout::ItemRole::FieldRole, fdEdit);

        label_20 = new QLabel(mainFrame);
        label_20->setObjectName("label_20");
        label_20->setFont(font2);
        label_20->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_4->setWidget(1, QFormLayout::ItemRole::LabelRole, label_20);

        baddrEdit = new QLineEdit(mainFrame);
        baddrEdit->setObjectName("baddrEdit");
        baddrEdit->setFrame(false);
        baddrEdit->setReadOnly(true);

        formLayout_4->setWidget(1, QFormLayout::ItemRole::FieldRole, baddrEdit);

        label_21 = new QLabel(mainFrame);
        label_21->setObjectName("label_21");
        label_21->setFont(font2);
        label_21->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_4->setWidget(2, QFormLayout::ItemRole::LabelRole, label_21);

        vaEdit = new QLineEdit(mainFrame);
        vaEdit->setObjectName("vaEdit");
        vaEdit->setFrame(false);
        vaEdit->setReadOnly(true);

        formLayout_4->setWidget(2, QFormLayout::ItemRole::FieldRole, vaEdit);

        label_22 = new QLabel(mainFrame);
        label_22->setObjectName("label_22");
        label_22->setFont(font2);
        label_22->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_4->setWidget(3, QFormLayout::ItemRole::LabelRole, label_22);

        canaryEdit = new QLineEdit(mainFrame);
        canaryEdit->setObjectName("canaryEdit");
        canaryEdit->setFrame(false);
        canaryEdit->setReadOnly(true);

        formLayout_4->setWidget(3, QFormLayout::ItemRole::FieldRole, canaryEdit);

        label_23 = new QLabel(mainFrame);
        label_23->setObjectName("label_23");
        label_23->setFont(font2);
        label_23->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_4->setWidget(4, QFormLayout::ItemRole::LabelRole, label_23);

        cryptoEdit = new QLineEdit(mainFrame);
        cryptoEdit->setObjectName("cryptoEdit");
        cryptoEdit->setFrame(false);
        cryptoEdit->setReadOnly(true);

        formLayout_4->setWidget(4, QFormLayout::ItemRole::FieldRole, cryptoEdit);

        label_24 = new QLabel(mainFrame);
        label_24->setObjectName("label_24");
        label_24->setFont(font2);
        label_24->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_4->setWidget(5, QFormLayout::ItemRole::LabelRole, label_24);

        nxEdit = new QLineEdit(mainFrame);
        nxEdit->setObjectName("nxEdit");
        nxEdit->setFrame(false);
        nxEdit->setReadOnly(true);

        formLayout_4->setWidget(5, QFormLayout::ItemRole::FieldRole, nxEdit);

        label_25 = new QLabel(mainFrame);
        label_25->setObjectName("label_25");
        label_25->setFont(font2);
        label_25->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_4->setWidget(6, QFormLayout::ItemRole::LabelRole, label_25);

        picEdit = new QLineEdit(mainFrame);
        picEdit->setObjectName("picEdit");
        picEdit->setFrame(false);
        picEdit->setReadOnly(true);

        formLayout_4->setWidget(6, QFormLayout::ItemRole::FieldRole, picEdit);

        label_26 = new QLabel(mainFrame);
        label_26->setObjectName("label_26");
        label_26->setFont(font2);
        label_26->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_4->setWidget(7, QFormLayout::ItemRole::LabelRole, label_26);

        label_34 = new QLabel(mainFrame);
        label_34->setObjectName("label_34");
        label_34->setFont(font2);
        label_34->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_4->setWidget(8, QFormLayout::ItemRole::LabelRole, label_34);

        relroEdit = new QLineEdit(mainFrame);
        relroEdit->setObjectName("relroEdit");
        relroEdit->setFrame(false);
        relroEdit->setReadOnly(true);

        formLayout_4->setWidget(8, QFormLayout::ItemRole::FieldRole, relroEdit);

        staticEdit = new QLineEdit(mainFrame);
        staticEdit->setObjectName("staticEdit");
        staticEdit->setFrame(false);
        staticEdit->setReadOnly(true);

        formLayout_4->setWidget(7, QFormLayout::ItemRole::FieldRole, staticEdit);


        horizontalLayout_2->addLayout(formLayout_4);

        formLayout_3 = new QFormLayout();
        formLayout_3->setObjectName("formLayout_3");
        formLayout_3->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout_3->setLabelAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        formLayout_3->setVerticalSpacing(3);
        label_14 = new QLabel(mainFrame);
        label_14->setObjectName("label_14");
        label_14->setFont(font2);
        label_14->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, label_14);

        archEdit = new QLineEdit(mainFrame);
        archEdit->setObjectName("archEdit");
        archEdit->setFrame(false);
        archEdit->setReadOnly(true);

        formLayout_3->setWidget(1, QFormLayout::ItemRole::FieldRole, archEdit);

        label_16 = new QLabel(mainFrame);
        label_16->setObjectName("label_16");
        label_16->setFont(font2);
        label_16->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_3->setWidget(2, QFormLayout::ItemRole::LabelRole, label_16);

        machineEdit = new QLineEdit(mainFrame);
        machineEdit->setObjectName("machineEdit");
        machineEdit->setFrame(false);
        machineEdit->setReadOnly(true);

        formLayout_3->setWidget(2, QFormLayout::ItemRole::FieldRole, machineEdit);

        label_17 = new QLabel(mainFrame);
        label_17->setObjectName("label_17");
        label_17->setFont(font2);
        label_17->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_3->setWidget(3, QFormLayout::ItemRole::LabelRole, label_17);

        osEdit = new QLineEdit(mainFrame);
        osEdit->setObjectName("osEdit");
        osEdit->setFrame(false);
        osEdit->setReadOnly(true);

        formLayout_3->setWidget(3, QFormLayout::ItemRole::FieldRole, osEdit);

        label_30 = new QLabel(mainFrame);
        label_30->setObjectName("label_30");
        label_30->setFont(font2);
        label_30->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_3->setWidget(4, QFormLayout::ItemRole::LabelRole, label_30);

        subsysEdit = new QLineEdit(mainFrame);
        subsysEdit->setObjectName("subsysEdit");
        subsysEdit->setFrame(false);
        subsysEdit->setReadOnly(true);

        formLayout_3->setWidget(4, QFormLayout::ItemRole::FieldRole, subsysEdit);

        label_27 = new QLabel(mainFrame);
        label_27->setObjectName("label_27");
        label_27->setFont(font2);
        label_27->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_3->setWidget(5, QFormLayout::ItemRole::LabelRole, label_27);

        strippedEdit = new QLineEdit(mainFrame);
        strippedEdit->setObjectName("strippedEdit");
        strippedEdit->setFrame(false);
        strippedEdit->setReadOnly(true);

        formLayout_3->setWidget(5, QFormLayout::ItemRole::FieldRole, strippedEdit);

        label_29 = new QLabel(mainFrame);
        label_29->setObjectName("label_29");
        label_29->setFont(font2);
        label_29->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_3->setWidget(6, QFormLayout::ItemRole::LabelRole, label_29);

        relocsEdit = new QLineEdit(mainFrame);
        relocsEdit->setObjectName("relocsEdit");
        relocsEdit->setFrame(false);
        relocsEdit->setReadOnly(true);

        formLayout_3->setWidget(6, QFormLayout::ItemRole::FieldRole, relocsEdit);

        label_28 = new QLabel(mainFrame);
        label_28->setObjectName("label_28");
        label_28->setFont(font2);
        label_28->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_3->setWidget(7, QFormLayout::ItemRole::LabelRole, label_28);

        endianEdit = new QLineEdit(mainFrame);
        endianEdit->setObjectName("endianEdit");
        endianEdit->setFrame(false);
        endianEdit->setReadOnly(true);

        formLayout_3->setWidget(7, QFormLayout::ItemRole::FieldRole, endianEdit);

        label_31 = new QLabel(mainFrame);
        label_31->setObjectName("label_31");
        label_31->setFont(font2);
        label_31->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_3->setWidget(8, QFormLayout::ItemRole::LabelRole, label_31);

        compilationDateEdit = new QLineEdit(mainFrame);
        compilationDateEdit->setObjectName("compilationDateEdit");
        compilationDateEdit->setFrame(false);
        compilationDateEdit->setReadOnly(true);

        formLayout_3->setWidget(8, QFormLayout::ItemRole::FieldRole, compilationDateEdit);

        label_5 = new QLabel(mainFrame);
        label_5->setObjectName("label_5");
        label_5->setFont(font2);
        label_5->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_3->setWidget(9, QFormLayout::ItemRole::LabelRole, label_5);

        compilerEdit = new QLineEdit(mainFrame);
        compilerEdit->setObjectName("compilerEdit");
        compilerEdit->setFrame(false);
        compilerEdit->setReadOnly(true);

        formLayout_3->setWidget(9, QFormLayout::ItemRole::FieldRole, compilerEdit);


        horizontalLayout_2->addLayout(formLayout_3);


        verticalLayout->addLayout(horizontalLayout_2);

        verticalSpacer_2 = new QSpacerItem(20, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_2);

        line_3 = new QFrame(mainFrame);
        line_3->setObjectName("line_3");
        line_3->setFrameShape(QFrame::Shape::HLine);
        line_3->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line_3);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        certificateButton = new QPushButton(mainFrame);
        certificateButton->setObjectName("certificateButton");
        certificateButton->setEnabled(true);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(certificateButton->sizePolicy().hasHeightForWidth());
        certificateButton->setSizePolicy(sizePolicy);

        horizontalLayout_7->addWidget(certificateButton);

        versioninfoButton = new QPushButton(mainFrame);
        versioninfoButton->setObjectName("versioninfoButton");
        sizePolicy.setHeightForWidth(versioninfoButton->sizePolicy().hasHeightForWidth());
        versioninfoButton->setSizePolicy(sizePolicy);

        horizontalLayout_7->addWidget(versioninfoButton);


        verticalLayout->addLayout(horizontalLayout_7);

        line_2 = new QFrame(mainFrame);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setContentsMargins(-1, 0, -1, -1);
        label_7 = new QLabel(mainFrame);
        label_7->setObjectName("label_7");
        label_7->setFont(font1);
        label_7->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        horizontalLayout_3->addWidget(label_7);

        label_6 = new QLabel(mainFrame);
        label_6->setObjectName("label_6");
        label_6->setFont(font1);
        label_6->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        horizontalLayout_3->addWidget(label_6);

        horizontalLayout_3->setStretch(0, 2);
        horizontalLayout_3->setStretch(1, 1);

        verticalLayout->addLayout(horizontalLayout_3);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalLayout_4->setContentsMargins(-1, 0, -1, -1);
        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(-1, -1, 5, -1);
        hashesVerticalLayout = new QVBoxLayout();
        hashesVerticalLayout->setObjectName("hashesVerticalLayout");

        verticalLayout_4->addLayout(hashesVerticalLayout);

        label_9 = new QLabel(mainFrame);
        label_9->setObjectName("label_9");
        label_9->setFont(font1);
        label_9->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        verticalLayout_4->addWidget(label_9);

        formLayout_5 = new QFormLayout();
        formLayout_5->setObjectName("formLayout_5");
        formLayout_5->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout_5->setVerticalSpacing(3);
        functionsLabel = new QLabel(mainFrame);
        functionsLabel->setObjectName("functionsLabel");
        functionsLabel->setFont(font2);
        functionsLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_5->setWidget(0, QFormLayout::ItemRole::LabelRole, functionsLabel);

        functionsLineEdit = new QLineEdit(mainFrame);
        functionsLineEdit->setObjectName("functionsLineEdit");
        functionsLineEdit->setFrame(false);
        functionsLineEdit->setReadOnly(true);

        formLayout_5->setWidget(0, QFormLayout::ItemRole::FieldRole, functionsLineEdit);

        xRefsLabel = new QLabel(mainFrame);
        xRefsLabel->setObjectName("xRefsLabel");
        xRefsLabel->setFont(font2);
        xRefsLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_5->setWidget(1, QFormLayout::ItemRole::LabelRole, xRefsLabel);

        xRefsLineEdit = new QLineEdit(mainFrame);
        xRefsLineEdit->setObjectName("xRefsLineEdit");
        xRefsLineEdit->setFrame(false);
        xRefsLineEdit->setReadOnly(true);

        formLayout_5->setWidget(1, QFormLayout::ItemRole::FieldRole, xRefsLineEdit);

        callsLabel = new QLabel(mainFrame);
        callsLabel->setObjectName("callsLabel");
        callsLabel->setFont(font2);
        callsLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_5->setWidget(2, QFormLayout::ItemRole::LabelRole, callsLabel);

        callsLineEdit = new QLineEdit(mainFrame);
        callsLineEdit->setObjectName("callsLineEdit");
        callsLineEdit->setFrame(false);
        callsLineEdit->setReadOnly(true);

        formLayout_5->setWidget(2, QFormLayout::ItemRole::FieldRole, callsLineEdit);

        stringsLabel = new QLabel(mainFrame);
        stringsLabel->setObjectName("stringsLabel");
        stringsLabel->setFont(font2);
        stringsLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_5->setWidget(3, QFormLayout::ItemRole::LabelRole, stringsLabel);

        stringsLineEdit = new QLineEdit(mainFrame);
        stringsLineEdit->setObjectName("stringsLineEdit");
        stringsLineEdit->setFrame(false);
        stringsLineEdit->setReadOnly(true);

        formLayout_5->setWidget(3, QFormLayout::ItemRole::FieldRole, stringsLineEdit);

        symbolsLabel = new QLabel(mainFrame);
        symbolsLabel->setObjectName("symbolsLabel");
        symbolsLabel->setFont(font2);
        symbolsLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_5->setWidget(4, QFormLayout::ItemRole::LabelRole, symbolsLabel);

        symbolsLineEdit = new QLineEdit(mainFrame);
        symbolsLineEdit->setObjectName("symbolsLineEdit");
        symbolsLineEdit->setFrame(false);
        symbolsLineEdit->setReadOnly(true);

        formLayout_5->setWidget(4, QFormLayout::ItemRole::FieldRole, symbolsLineEdit);

        importsLabel = new QLabel(mainFrame);
        importsLabel->setObjectName("importsLabel");
        importsLabel->setFont(font2);
        importsLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_5->setWidget(5, QFormLayout::ItemRole::LabelRole, importsLabel);

        importsLineEdit = new QLineEdit(mainFrame);
        importsLineEdit->setObjectName("importsLineEdit");
        importsLineEdit->setFrame(false);
        importsLineEdit->setReadOnly(true);

        formLayout_5->setWidget(5, QFormLayout::ItemRole::FieldRole, importsLineEdit);

        coverageLabel = new QLabel(mainFrame);
        coverageLabel->setObjectName("coverageLabel");
        coverageLabel->setFont(font2);
        coverageLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_5->setWidget(6, QFormLayout::ItemRole::LabelRole, coverageLabel);

        coverageLineEdit = new QLineEdit(mainFrame);
        coverageLineEdit->setObjectName("coverageLineEdit");
        coverageLineEdit->setFrame(false);
        coverageLineEdit->setReadOnly(true);

        formLayout_5->setWidget(6, QFormLayout::ItemRole::FieldRole, coverageLineEdit);

        codeSizeLabel = new QLabel(mainFrame);
        codeSizeLabel->setObjectName("codeSizeLabel");
        codeSizeLabel->setFont(font2);
        codeSizeLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_5->setWidget(7, QFormLayout::ItemRole::LabelRole, codeSizeLabel);

        codeSizeLineEdit = new QLineEdit(mainFrame);
        codeSizeLineEdit->setObjectName("codeSizeLineEdit");
        codeSizeLineEdit->setFrame(false);
        codeSizeLineEdit->setReadOnly(true);

        formLayout_5->setWidget(7, QFormLayout::ItemRole::FieldRole, codeSizeLineEdit);

        percentageLabel = new QLabel(mainFrame);
        percentageLabel->setObjectName("percentageLabel");
        percentageLabel->setFont(font2);
        percentageLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_5->setWidget(8, QFormLayout::ItemRole::LabelRole, percentageLabel);

        percentageLineEdit = new QLineEdit(mainFrame);
        percentageLineEdit->setObjectName("percentageLineEdit");
        percentageLineEdit->setFrame(false);
        percentageLineEdit->setReadOnly(true);

        formLayout_5->setWidget(8, QFormLayout::ItemRole::FieldRole, percentageLineEdit);


        verticalLayout_4->addLayout(formLayout_5);


        horizontalLayout_4->addLayout(verticalLayout_4);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");

        horizontalLayout_4->addLayout(verticalLayout_2);

        horizontalLayout_4->setStretch(0, 2);
        horizontalLayout_4->setStretch(1, 1);

        verticalLayout->addLayout(horizontalLayout_4);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        horizontalLayout_5->addWidget(mainFrame);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_2);

        scrollArea->setWidget(scrollAreaWidgetContents);

        horizontalLayout->addWidget(scrollArea);

        Dashboard->setWidget(dockWidgetContents);

        retranslateUi(Dashboard);

        QMetaObject::connectSlotsByName(Dashboard);
    } // setupUi

    void retranslateUi(QDockWidget *Dashboard)
    {
        label->setText(QCoreApplication::translate("Dashboard", "OVERVIEW", nullptr));
        label_2->setText(QCoreApplication::translate("Dashboard", "Info", nullptr));
        label_3->setText(QCoreApplication::translate("Dashboard", "File:", nullptr));
        fileEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_10->setText(QCoreApplication::translate("Dashboard", "Format:", nullptr));
        formatEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_11->setText(QCoreApplication::translate("Dashboard", "Mode:", nullptr));
        modeEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_12->setText(QCoreApplication::translate("Dashboard", "Size:", nullptr));
        label_13->setText(QCoreApplication::translate("Dashboard", "Type:", nullptr));
        typeEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_15->setText(QCoreApplication::translate("Dashboard", "Class:", nullptr));
        classEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_18->setText(QCoreApplication::translate("Dashboard", "Language:", nullptr));
        langEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_19->setText(QCoreApplication::translate("Dashboard", "Bits:", nullptr));
        bitsEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        sizeEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_4->setText(QCoreApplication::translate("Dashboard", "FD:", nullptr));
        fdEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_20->setText(QCoreApplication::translate("Dashboard", "Base addr:", nullptr));
        baddrEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_21->setText(QCoreApplication::translate("Dashboard", "Virtual addr:", nullptr));
        vaEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_22->setText(QCoreApplication::translate("Dashboard", "Canary:", nullptr));
        canaryEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_23->setText(QCoreApplication::translate("Dashboard", "Crypto:", nullptr));
        cryptoEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_24->setText(QCoreApplication::translate("Dashboard", "NX bit:", nullptr));
        nxEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_25->setText(QCoreApplication::translate("Dashboard", "PIC:", nullptr));
        picEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_26->setText(QCoreApplication::translate("Dashboard", "Static:", nullptr));
        label_34->setText(QCoreApplication::translate("Dashboard", "Relro:", nullptr));
        relroEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        staticEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_14->setText(QCoreApplication::translate("Dashboard", "Architecture:", nullptr));
        archEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_16->setText(QCoreApplication::translate("Dashboard", "Machine:", nullptr));
        machineEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_17->setText(QCoreApplication::translate("Dashboard", "OS:", nullptr));
        osEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_30->setText(QCoreApplication::translate("Dashboard", "Subsystem:", nullptr));
        subsysEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_27->setText(QCoreApplication::translate("Dashboard", "Stripped:", nullptr));
        strippedEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_29->setText(QCoreApplication::translate("Dashboard", "Relocs:", nullptr));
        relocsEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_28->setText(QCoreApplication::translate("Dashboard", "Endianness:", nullptr));
        endianEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_31->setText(QCoreApplication::translate("Dashboard", "Compiled:", nullptr));
        compilationDateEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        label_5->setText(QCoreApplication::translate("Dashboard", "Compiler:", nullptr));
        compilerEdit->setText(QCoreApplication::translate("Dashboard", "--", nullptr));
        certificateButton->setText(QCoreApplication::translate("Dashboard", "Certificates", nullptr));
        versioninfoButton->setText(QCoreApplication::translate("Dashboard", "Version info", nullptr));
        label_7->setText(QCoreApplication::translate("Dashboard", "Hashes", nullptr));
        label_6->setText(QCoreApplication::translate("Dashboard", "Libraries", nullptr));
        label_9->setText(QCoreApplication::translate("Dashboard", "Analysis info", nullptr));
        functionsLabel->setText(QCoreApplication::translate("Dashboard", "Functions:", nullptr));
        xRefsLabel->setText(QCoreApplication::translate("Dashboard", "X-Refs:", nullptr));
        callsLabel->setText(QCoreApplication::translate("Dashboard", "Calls:", nullptr));
        stringsLabel->setText(QCoreApplication::translate("Dashboard", "Strings:", nullptr));
        symbolsLabel->setText(QCoreApplication::translate("Dashboard", "Symbols:", nullptr));
        importsLabel->setText(QCoreApplication::translate("Dashboard", "Imports:", nullptr));
        coverageLabel->setText(QCoreApplication::translate("Dashboard", "Analysis coverage:", nullptr));
        codeSizeLabel->setText(QCoreApplication::translate("Dashboard", "Code size:", nullptr));
        percentageLabel->setText(QCoreApplication::translate("Dashboard", "Coverage percent:", nullptr));
        (void)Dashboard;
    } // retranslateUi

};

namespace Ui {
    class Dashboard: public Ui_Dashboard {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DASHBOARD_H
