/********************************************************************************
** Form generated from reading UI file 'R2PluginsDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_R2PLUGINSDIALOG_H
#define UI_R2PLUGINSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_R2PluginsDialog
{
public:
    QVBoxLayout *verticalLayout_1;
    QTabWidget *tabWidget;
    QWidget *RBinTab;
    QVBoxLayout *verticalLayout_2;
    QLabel *RBinLabel;
    QTreeWidget *RBinTreeWidget;
    QWidget *RIOTab;
    QVBoxLayout *verticalLayout_3;
    QLabel *RIOLabel;
    QTreeWidget *RIOTreeWidget;
    QWidget *RCoreTab;
    QVBoxLayout *verticalLayout_4;
    QLabel *RCoreLabel;
    QTreeWidget *RCoreTreeWidget;
    QWidget *RAsmTab;
    QVBoxLayout *verticalLayout_5;
    QLabel *RAsmLabel;
    QTreeWidget *RAsmTreeWidget;
    QWidget *RAnalTab;
    QVBoxLayout *verticalLayout_6;
    QLabel *RAnalLabel;
    QTreeWidget *RAnalTreeWidget;
    QWidget *RMutaTab;
    QVBoxLayout *verticalLayout_7;
    QLabel *RMutaLabel;
    QTreeWidget *RMutaTreeWidget;
    QWidget *RLangTab;
    QVBoxLayout *verticalLayout_8;
    QLabel *RLangLabel;
    QTreeWidget *RLangTreeWidget;
    QWidget *RFSTab;
    QVBoxLayout *verticalLayout_9;
    QLabel *RFSLabel;
    QTreeWidget *RFSTreeWidget;
    QWidget *RDebugTab;
    QVBoxLayout *verticalLayout_10;
    QLabel *RDebugLabel;
    QTreeWidget *RDebugTreeWidget;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *R2PluginsDialog)
    {
        if (R2PluginsDialog->objectName().isEmpty())
            R2PluginsDialog->setObjectName("R2PluginsDialog");
        R2PluginsDialog->resize(618, 642);
        verticalLayout_1 = new QVBoxLayout(R2PluginsDialog);
        verticalLayout_1->setObjectName("verticalLayout_1");
        tabWidget = new QTabWidget(R2PluginsDialog);
        tabWidget->setObjectName("tabWidget");
        RBinTab = new QWidget();
        RBinTab->setObjectName("RBinTab");
        verticalLayout_2 = new QVBoxLayout(RBinTab);
        verticalLayout_2->setObjectName("verticalLayout_2");
        RBinLabel = new QLabel(RBinTab);
        RBinLabel->setObjectName("RBinLabel");

        verticalLayout_2->addWidget(RBinLabel);

        RBinTreeWidget = new QTreeWidget(RBinTab);
        RBinTreeWidget->setObjectName("RBinTreeWidget");
        RBinTreeWidget->setSortingEnabled(true);

        verticalLayout_2->addWidget(RBinTreeWidget);

        tabWidget->addTab(RBinTab, QString());
        RIOTab = new QWidget();
        RIOTab->setObjectName("RIOTab");
        verticalLayout_3 = new QVBoxLayout(RIOTab);
        verticalLayout_3->setObjectName("verticalLayout_3");
        RIOLabel = new QLabel(RIOTab);
        RIOLabel->setObjectName("RIOLabel");

        verticalLayout_3->addWidget(RIOLabel);

        RIOTreeWidget = new QTreeWidget(RIOTab);
        RIOTreeWidget->setObjectName("RIOTreeWidget");
        RIOTreeWidget->setSortingEnabled(true);

        verticalLayout_3->addWidget(RIOTreeWidget);

        tabWidget->addTab(RIOTab, QString());
        RCoreTab = new QWidget();
        RCoreTab->setObjectName("RCoreTab");
        verticalLayout_4 = new QVBoxLayout(RCoreTab);
        verticalLayout_4->setObjectName("verticalLayout_4");
        RCoreLabel = new QLabel(RCoreTab);
        RCoreLabel->setObjectName("RCoreLabel");

        verticalLayout_4->addWidget(RCoreLabel);

        RCoreTreeWidget = new QTreeWidget(RCoreTab);
        RCoreTreeWidget->setObjectName("RCoreTreeWidget");
        RCoreTreeWidget->setSortingEnabled(true);

        verticalLayout_4->addWidget(RCoreTreeWidget);

        tabWidget->addTab(RCoreTab, QString());
        RAsmTab = new QWidget();
        RAsmTab->setObjectName("RAsmTab");
        verticalLayout_5 = new QVBoxLayout(RAsmTab);
        verticalLayout_5->setObjectName("verticalLayout_5");
        RAsmLabel = new QLabel(RAsmTab);
        RAsmLabel->setObjectName("RAsmLabel");

        verticalLayout_5->addWidget(RAsmLabel);

        RAsmTreeWidget = new QTreeWidget(RAsmTab);
        RAsmTreeWidget->setObjectName("RAsmTreeWidget");
        RAsmTreeWidget->setSortingEnabled(true);

        verticalLayout_5->addWidget(RAsmTreeWidget);

        tabWidget->addTab(RAsmTab, QString());
        RAnalTab = new QWidget();
        RAnalTab->setObjectName("RAnalTab");
        verticalLayout_6 = new QVBoxLayout(RAnalTab);
        verticalLayout_6->setObjectName("verticalLayout_6");
        RAnalLabel = new QLabel(RAnalTab);
        RAnalLabel->setObjectName("RAnalLabel");

        verticalLayout_6->addWidget(RAnalLabel);

        RAnalTreeWidget = new QTreeWidget(RAnalTab);
        RAnalTreeWidget->setObjectName("RAnalTreeWidget");
        RAnalTreeWidget->setSortingEnabled(true);

        verticalLayout_6->addWidget(RAnalTreeWidget);

        tabWidget->addTab(RAnalTab, QString());
        RMutaTab = new QWidget();
        RMutaTab->setObjectName("RMutaTab");
        verticalLayout_7 = new QVBoxLayout(RMutaTab);
        verticalLayout_7->setObjectName("verticalLayout_7");
        RMutaLabel = new QLabel(RMutaTab);
        RMutaLabel->setObjectName("RMutaLabel");

        verticalLayout_7->addWidget(RMutaLabel);

        RMutaTreeWidget = new QTreeWidget(RMutaTab);
        RMutaTreeWidget->setObjectName("RMutaTreeWidget");
        RMutaTreeWidget->setSortingEnabled(true);

        verticalLayout_7->addWidget(RMutaTreeWidget);

        tabWidget->addTab(RMutaTab, QString());
        RLangTab = new QWidget();
        RLangTab->setObjectName("RLangTab");
        verticalLayout_8 = new QVBoxLayout(RLangTab);
        verticalLayout_8->setObjectName("verticalLayout_8");
        RLangLabel = new QLabel(RLangTab);
        RLangLabel->setObjectName("RLangLabel");

        verticalLayout_8->addWidget(RLangLabel);

        RLangTreeWidget = new QTreeWidget(RLangTab);
        RLangTreeWidget->setObjectName("RLangTreeWidget");
        RLangTreeWidget->setSortingEnabled(true);

        verticalLayout_8->addWidget(RLangTreeWidget);

        tabWidget->addTab(RLangTab, QString());
        RFSTab = new QWidget();
        RFSTab->setObjectName("RFSTab");
        verticalLayout_9 = new QVBoxLayout(RFSTab);
        verticalLayout_9->setObjectName("verticalLayout_9");
        RFSLabel = new QLabel(RFSTab);
        RFSLabel->setObjectName("RFSLabel");

        verticalLayout_9->addWidget(RFSLabel);

        RFSTreeWidget = new QTreeWidget(RFSTab);
        RFSTreeWidget->setObjectName("RFSTreeWidget");
        RFSTreeWidget->setSortingEnabled(true);

        verticalLayout_9->addWidget(RFSTreeWidget);

        tabWidget->addTab(RFSTab, QString());
        RDebugTab = new QWidget();
        RDebugTab->setObjectName("RDebugTab");
        verticalLayout_10 = new QVBoxLayout(RDebugTab);
        verticalLayout_10->setObjectName("verticalLayout_10");
        RDebugLabel = new QLabel(RDebugTab);
        RDebugLabel->setObjectName("RDebugLabel");

        verticalLayout_10->addWidget(RDebugLabel);

        RDebugTreeWidget = new QTreeWidget(RDebugTab);
        RDebugTreeWidget->setObjectName("RDebugTreeWidget");
        RDebugTreeWidget->setSortingEnabled(true);

        verticalLayout_10->addWidget(RDebugTreeWidget);

        tabWidget->addTab(RDebugTab, QString());

        verticalLayout_1->addWidget(tabWidget);

        buttonBox = new QDialogButtonBox(R2PluginsDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);

        verticalLayout_1->addWidget(buttonBox);


        retranslateUi(R2PluginsDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, R2PluginsDialog, qOverload<>(&QDialog::accept));

        tabWidget->setCurrentIndex(4);


        QMetaObject::connectSlotsByName(R2PluginsDialog);
    } // setupUi

    void retranslateUi(QDialog *R2PluginsDialog)
    {
        R2PluginsDialog->setWindowTitle(QCoreApplication::translate("R2PluginsDialog", "radare2 plugin information", nullptr));
        RBinLabel->setText(QCoreApplication::translate("R2PluginsDialog", "Parse and load binary file formats (ELF, PE, Mach-O, ...)", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = RBinTreeWidget->headerItem();
        ___qtreewidgetitem->setText(3, QCoreApplication::translate("R2PluginsDialog", "Type", nullptr));
        ___qtreewidgetitem->setText(2, QCoreApplication::translate("R2PluginsDialog", "License", nullptr));
        ___qtreewidgetitem->setText(1, QCoreApplication::translate("R2PluginsDialog", "Description", nullptr));
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("R2PluginsDialog", "Name", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(RBinTab), QCoreApplication::translate("R2PluginsDialog", "RBin", nullptr));
        RIOLabel->setText(QCoreApplication::translate("R2PluginsDialog", "Access and manage different data sources and protocols", nullptr));
        QTreeWidgetItem *___qtreewidgetitem1 = RIOTreeWidget->headerItem();
        ___qtreewidgetitem1->setText(3, QCoreApplication::translate("R2PluginsDialog", "Permissions", nullptr));
        ___qtreewidgetitem1->setText(2, QCoreApplication::translate("R2PluginsDialog", "License", nullptr));
        ___qtreewidgetitem1->setText(1, QCoreApplication::translate("R2PluginsDialog", "Description", nullptr));
        ___qtreewidgetitem1->setText(0, QCoreApplication::translate("R2PluginsDialog", "Name", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(RIOTab), QCoreApplication::translate("R2PluginsDialog", "RIO", nullptr));
        RCoreLabel->setText(QCoreApplication::translate("R2PluginsDialog", "Extend the core with new commands and features", nullptr));
        QTreeWidgetItem *___qtreewidgetitem2 = RCoreTreeWidget->headerItem();
        ___qtreewidgetitem2->setText(1, QCoreApplication::translate("R2PluginsDialog", "Description", nullptr));
        ___qtreewidgetitem2->setText(0, QCoreApplication::translate("R2PluginsDialog", "Name", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(RCoreTab), QCoreApplication::translate("R2PluginsDialog", "RCore", nullptr));
        RAsmLabel->setText(QCoreApplication::translate("R2PluginsDialog", "Assemble and disassemble CPU architectures", nullptr));
        QTreeWidgetItem *___qtreewidgetitem3 = RAsmTreeWidget->headerItem();
        ___qtreewidgetitem3->setText(6, QCoreApplication::translate("R2PluginsDialog", "Author", nullptr));
        ___qtreewidgetitem3->setText(5, QCoreApplication::translate("R2PluginsDialog", "License", nullptr));
        ___qtreewidgetitem3->setText(4, QCoreApplication::translate("R2PluginsDialog", "Description", nullptr));
        ___qtreewidgetitem3->setText(3, QCoreApplication::translate("R2PluginsDialog", "Version", nullptr));
        ___qtreewidgetitem3->setText(2, QCoreApplication::translate("R2PluginsDialog", "CPU's", nullptr));
        ___qtreewidgetitem3->setText(1, QCoreApplication::translate("R2PluginsDialog", "Architecture", nullptr));
        ___qtreewidgetitem3->setText(0, QCoreApplication::translate("R2PluginsDialog", "Name", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(RAsmTab), QCoreApplication::translate("R2PluginsDialog", "RArch", nullptr));
        RAnalLabel->setText(QCoreApplication::translate("R2PluginsDialog", "Analyze code, control flow and data references", nullptr));
        QTreeWidgetItem *___qtreewidgetitem4 = RAnalTreeWidget->headerItem();
        ___qtreewidgetitem4->setText(6, QCoreApplication::translate("R2PluginsDialog", "CPU's", nullptr));
        ___qtreewidgetitem4->setText(5, QCoreApplication::translate("R2PluginsDialog", "Author", nullptr));
        ___qtreewidgetitem4->setText(4, QCoreApplication::translate("R2PluginsDialog", "License", nullptr));
        ___qtreewidgetitem4->setText(3, QCoreApplication::translate("R2PluginsDialog", "Description", nullptr));
        ___qtreewidgetitem4->setText(2, QCoreApplication::translate("R2PluginsDialog", "Version", nullptr));
        ___qtreewidgetitem4->setText(1, QCoreApplication::translate("R2PluginsDialog", "Architecture", nullptr));
        ___qtreewidgetitem4->setText(0, QCoreApplication::translate("R2PluginsDialog", "Name", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(RAnalTab), QCoreApplication::translate("R2PluginsDialog", "RAnal", nullptr));
        RMutaLabel->setText(QCoreApplication::translate("R2PluginsDialog", "Crypto, hashing and encoding transformations", nullptr));
        QTreeWidgetItem *___qtreewidgetitem5 = RMutaTreeWidget->headerItem();
        ___qtreewidgetitem5->setText(4, QCoreApplication::translate("R2PluginsDialog", "Author", nullptr));
        ___qtreewidgetitem5->setText(3, QCoreApplication::translate("R2PluginsDialog", "License", nullptr));
        ___qtreewidgetitem5->setText(2, QCoreApplication::translate("R2PluginsDialog", "Description", nullptr));
        ___qtreewidgetitem5->setText(1, QCoreApplication::translate("R2PluginsDialog", "Type", nullptr));
        ___qtreewidgetitem5->setText(0, QCoreApplication::translate("R2PluginsDialog", "Name", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(RMutaTab), QCoreApplication::translate("R2PluginsDialog", "RMuta", nullptr));
        RLangLabel->setText(QCoreApplication::translate("R2PluginsDialog", "Scripting language bindings for automation", nullptr));
        QTreeWidgetItem *___qtreewidgetitem6 = RLangTreeWidget->headerItem();
        ___qtreewidgetitem6->setText(4, QCoreApplication::translate("R2PluginsDialog", "Extension", nullptr));
        ___qtreewidgetitem6->setText(3, QCoreApplication::translate("R2PluginsDialog", "Alias", nullptr));
        ___qtreewidgetitem6->setText(2, QCoreApplication::translate("R2PluginsDialog", "License", nullptr));
        ___qtreewidgetitem6->setText(1, QCoreApplication::translate("R2PluginsDialog", "Description", nullptr));
        ___qtreewidgetitem6->setText(0, QCoreApplication::translate("R2PluginsDialog", "Name", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(RLangTab), QCoreApplication::translate("R2PluginsDialog", "RLang", nullptr));
        RFSLabel->setText(QCoreApplication::translate("R2PluginsDialog", "Mount and browse filesystem images", nullptr));
        QTreeWidgetItem *___qtreewidgetitem7 = RFSTreeWidget->headerItem();
        ___qtreewidgetitem7->setText(3, QCoreApplication::translate("R2PluginsDialog", "Author", nullptr));
        ___qtreewidgetitem7->setText(2, QCoreApplication::translate("R2PluginsDialog", "License", nullptr));
        ___qtreewidgetitem7->setText(1, QCoreApplication::translate("R2PluginsDialog", "Description", nullptr));
        ___qtreewidgetitem7->setText(0, QCoreApplication::translate("R2PluginsDialog", "Name", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(RFSTab), QCoreApplication::translate("R2PluginsDialog", "RFS", nullptr));
        RDebugLabel->setText(QCoreApplication::translate("R2PluginsDialog", "Debugger backends for local and remote targets", nullptr));
        QTreeWidgetItem *___qtreewidgetitem8 = RDebugTreeWidget->headerItem();
        ___qtreewidgetitem8->setText(4, QCoreApplication::translate("R2PluginsDialog", "Author", nullptr));
        ___qtreewidgetitem8->setText(3, QCoreApplication::translate("R2PluginsDialog", "License", nullptr));
        ___qtreewidgetitem8->setText(2, QCoreApplication::translate("R2PluginsDialog", "Arch", nullptr));
        ___qtreewidgetitem8->setText(1, QCoreApplication::translate("R2PluginsDialog", "Description", nullptr));
        ___qtreewidgetitem8->setText(0, QCoreApplication::translate("R2PluginsDialog", "Name", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(RDebugTab), QCoreApplication::translate("R2PluginsDialog", "RDebug", nullptr));
    } // retranslateUi

};

namespace Ui {
    class R2PluginsDialog: public Ui_R2PluginsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_R2PLUGINSDIALOG_H
