/********************************************************************************
** Form generated from reading UI file 'EditMethodDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITMETHODDIALOG_H
#define UI_EDITMETHODDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_EditMethodDialog
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *label;
    QLabel *nameLabel;
    QLineEdit *nameEdit;
    QLabel *addressLabel;
    QLineEdit *addressEdit;
    QLabel *virtualLabel;
    QCheckBox *virtualCheckBox;
    QLabel *vtableOffsetLabel;
    QLineEdit *vtableOffsetEdit;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *EditMethodDialog)
    {
        if (EditMethodDialog->objectName().isEmpty())
            EditMethodDialog->setObjectName("EditMethodDialog");
        EditMethodDialog->setWindowModality(Qt::NonModal);
        EditMethodDialog->resize(461, 238);
        EditMethodDialog->setWindowTitle(QString::fromUtf8("Method"));
        verticalLayout = new QVBoxLayout(EditMethodDialog);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label = new QLabel(EditMethodDialog);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        nameLabel = new QLabel(EditMethodDialog);
        nameLabel->setObjectName("nameLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, nameLabel);

        nameEdit = new QLineEdit(EditMethodDialog);
        nameEdit->setObjectName("nameEdit");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, nameEdit);

        addressLabel = new QLabel(EditMethodDialog);
        addressLabel->setObjectName("addressLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, addressLabel);

        addressEdit = new QLineEdit(EditMethodDialog);
        addressEdit->setObjectName("addressEdit");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, addressEdit);

        virtualLabel = new QLabel(EditMethodDialog);
        virtualLabel->setObjectName("virtualLabel");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, virtualLabel);

        virtualCheckBox = new QCheckBox(EditMethodDialog);
        virtualCheckBox->setObjectName("virtualCheckBox");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, virtualCheckBox);

        vtableOffsetLabel = new QLabel(EditMethodDialog);
        vtableOffsetLabel->setObjectName("vtableOffsetLabel");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, vtableOffsetLabel);

        vtableOffsetEdit = new QLineEdit(EditMethodDialog);
        vtableOffsetEdit->setObjectName("vtableOffsetEdit");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, vtableOffsetEdit);


        verticalLayout->addLayout(formLayout);

        buttonBox = new QDialogButtonBox(EditMethodDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(EditMethodDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, EditMethodDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, EditMethodDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(EditMethodDialog);
    } // setupUi

    void retranslateUi(QDialog *EditMethodDialog)
    {
        label->setText(QCoreApplication::translate("EditMethodDialog", "Class:", nullptr));
        nameLabel->setText(QCoreApplication::translate("EditMethodDialog", "Name:", nullptr));
        addressLabel->setText(QCoreApplication::translate("EditMethodDialog", "Address:", nullptr));
        virtualLabel->setText(QCoreApplication::translate("EditMethodDialog", "Virtual:", nullptr));
        virtualCheckBox->setText(QString());
        vtableOffsetLabel->setText(QCoreApplication::translate("EditMethodDialog", "Offset in VTable:", nullptr));
        (void)EditMethodDialog;
    } // retranslateUi

};

namespace Ui {
    class EditMethodDialog: public Ui_EditMethodDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_EDITMETHODDIALOG_H
