/********************************************************************************
** Form generated from reading UI file 'AttachProcDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ATTACHPROCDIALOG_H
#define UI_ATTACHPROCDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_AttachProcDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_2;
    QTreeView *procBeingAnalyzedView;
    QGroupBox *groupBox;
    QTreeView *allProcView;
    QLineEdit *filterLineEdit;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *AttachProcDialog)
    {
        if (AttachProcDialog->objectName().isEmpty())
            AttachProcDialog->setObjectName("AttachProcDialog");
        AttachProcDialog->resize(800, 600);
        verticalLayout_2 = new QVBoxLayout(AttachProcDialog);
        verticalLayout_2->setSpacing(2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(2, 5, 2, 2);
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(-1, 0, -1, -1);
        groupBox_2 = new QGroupBox(AttachProcDialog);
        groupBox_2->setObjectName("groupBox_2");
        groupBox_2->setMaximumSize(QSize(16777215, 150));
        procBeingAnalyzedView = new QTreeView(groupBox_2);
        procBeingAnalyzedView->setObjectName("procBeingAnalyzedView");
        procBeingAnalyzedView->setGeometry(QRect(0, 30, 794, 111));
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(procBeingAnalyzedView->sizePolicy().hasHeightForWidth());
        procBeingAnalyzedView->setSizePolicy(sizePolicy);
        procBeingAnalyzedView->setMaximumSize(QSize(16777215, 16777215));
        procBeingAnalyzedView->setStyleSheet(QString::fromUtf8("QTreeView::item\n"
"{\n"
"    padding-top: 1px;\n"
"    padding-bottom: 1px;\n"
"}"));
        procBeingAnalyzedView->setFrameShape(QFrame::NoFrame);
        procBeingAnalyzedView->setLineWidth(0);
        procBeingAnalyzedView->setIndentation(8);
        procBeingAnalyzedView->setSortingEnabled(true);

        verticalLayout->addWidget(groupBox_2);

        groupBox = new QGroupBox(AttachProcDialog);
        groupBox->setObjectName("groupBox");
        allProcView = new QTreeView(groupBox);
        allProcView->setObjectName("allProcView");
        allProcView->setGeometry(QRect(0, 50, 794, 331));
        allProcView->setMaximumSize(QSize(16777215, 16777215));
        allProcView->setStyleSheet(QString::fromUtf8("QTreeView::item\n"
"{\n"
"    padding-top: 1px;\n"
"    padding-bottom: 1px;\n"
"}"));
        allProcView->setFrameShape(QFrame::NoFrame);
        allProcView->setLineWidth(0);
        allProcView->setIndentation(8);
        allProcView->setSortingEnabled(true);

        verticalLayout->addWidget(groupBox);


        verticalLayout_2->addLayout(verticalLayout);

        filterLineEdit = new QLineEdit(AttachProcDialog);
        filterLineEdit->setObjectName("filterLineEdit");

        verticalLayout_2->addWidget(filterLineEdit);

        buttonBox = new QDialogButtonBox(AttachProcDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(AttachProcDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, AttachProcDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, AttachProcDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(AttachProcDialog);
    } // setupUi

    void retranslateUi(QDialog *AttachProcDialog)
    {
        AttachProcDialog->setWindowTitle(QCoreApplication::translate("AttachProcDialog", "Select process to attach...", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("AttachProcDialog", "Processes with same name as currently open file:", nullptr));
        groupBox->setTitle(QCoreApplication::translate("AttachProcDialog", "All processes:", nullptr));
        filterLineEdit->setPlaceholderText(QCoreApplication::translate("AttachProcDialog", "Quick Filter", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AttachProcDialog: public Ui_AttachProcDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ATTACHPROCDIALOG_H
