/****************************************************************************
** Meta object code from reading C++ file 'Configuration.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/common/Configuration.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Configuration.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ConfigurationE_t {};
} // unnamed namespace

template <> constexpr inline auto Configuration::qt_create_metaobjectdata<qt_meta_tag_ZN13ConfigurationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Configuration",
        "fontsUpdated",
        "",
        "colorsUpdated",
        "interfacePaletteUpdated",
        "interfaceThemeChanged",
        "visualNavbarLocationChanged",
        "VisualNavbarLocation",
        "location",
        "visualNavbarThicknessChanged",
        "thickness",
        "addressRangeSelectionSyncEnabledChanged",
        "enabled",
        "refreshFont",
        "Top",
        "Bottom",
        "Left",
        "Right",
        "SuperTop",
        "SuperBottom"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fontsUpdated'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorsUpdated'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'interfacePaletteUpdated'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'interfaceThemeChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visualNavbarLocationChanged'
        QtMocHelpers::SignalData<void(enum VisualNavbarLocation)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'visualNavbarThicknessChanged'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'addressRangeSelectionSyncEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'refreshFont'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'VisualNavbarLocation'
        QtMocHelpers::EnumData<enum VisualNavbarLocation>(7, 7, QMC::EnumIsScoped).add({
            {   14, VisualNavbarLocation::Top },
            {   15, VisualNavbarLocation::Bottom },
            {   16, VisualNavbarLocation::Left },
            {   17, VisualNavbarLocation::Right },
            {   18, VisualNavbarLocation::SuperTop },
            {   19, VisualNavbarLocation::SuperBottom },
        }),
    };
    return QtMocHelpers::metaObjectData<Configuration, qt_meta_tag_ZN13ConfigurationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Configuration::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ConfigurationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ConfigurationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ConfigurationE_t>.metaTypes,
    nullptr
} };

void Configuration::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Configuration *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fontsUpdated(); break;
        case 1: _t->colorsUpdated(); break;
        case 2: _t->interfacePaletteUpdated(); break;
        case 3: _t->interfaceThemeChanged(); break;
        case 4: _t->visualNavbarLocationChanged((*reinterpret_cast<std::add_pointer_t<enum VisualNavbarLocation>>(_a[1]))); break;
        case 5: _t->visualNavbarThicknessChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->addressRangeSelectionSyncEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->refreshFont(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Configuration::*)()>(_a, &Configuration::fontsUpdated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Configuration::*)()>(_a, &Configuration::colorsUpdated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Configuration::*)()>(_a, &Configuration::interfacePaletteUpdated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Configuration::*)()>(_a, &Configuration::interfaceThemeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Configuration::*)(VisualNavbarLocation )>(_a, &Configuration::visualNavbarLocationChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Configuration::*)(int )>(_a, &Configuration::visualNavbarThicknessChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Configuration::*)(bool )>(_a, &Configuration::addressRangeSelectionSyncEnabledChanged, 6))
            return;
    }
}

const QMetaObject *Configuration::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Configuration::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ConfigurationE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Configuration::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Configuration::fontsUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Configuration::colorsUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Configuration::interfacePaletteUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Configuration::interfaceThemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Configuration::visualNavbarLocationChanged(VisualNavbarLocation _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Configuration::visualNavbarThicknessChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Configuration::addressRangeSelectionSyncEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
