/********************************************************************************
** Form generated from reading UI file 'AnalOptionsWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ANALOPTIONSWIDGET_H
#define UI_ANALOPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_AnalOptionsWidget
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *analInLabel;
    QComboBox *analInComboBox;
    QLabel *ptrDepthLabel;
    QSpinBox *ptrDepthSpinBox;
    QLabel *preludeLabel;
    QLineEdit *preludeLineEdit;
    QCheckBox *autonameCheckbox;
    QCheckBox *hasnextCheckbox;
    QCheckBox *jmpRefCheckbox;
    QCheckBox *jmpTblCheckbox;
    QCheckBox *pushRetCheckBox;
    QCheckBox *typesVerboseCheckBox;
    QCheckBox *verboseCheckBox;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *AnalOptionsWidget)
    {
        if (AnalOptionsWidget->objectName().isEmpty())
            AnalOptionsWidget->setObjectName("AnalOptionsWidget");
        verticalLayout = new QVBoxLayout(AnalOptionsWidget);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        analInLabel = new QLabel(AnalOptionsWidget);
        analInLabel->setObjectName("analInLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, analInLabel);

        analInComboBox = new QComboBox(AnalOptionsWidget);
        analInComboBox->setObjectName("analInComboBox");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, analInComboBox);

        ptrDepthLabel = new QLabel(AnalOptionsWidget);
        ptrDepthLabel->setObjectName("ptrDepthLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, ptrDepthLabel);

        ptrDepthSpinBox = new QSpinBox(AnalOptionsWidget);
        ptrDepthSpinBox->setObjectName("ptrDepthSpinBox");
        ptrDepthSpinBox->setMinimum(0);
        ptrDepthSpinBox->setValue(0);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, ptrDepthSpinBox);

        preludeLabel = new QLabel(AnalOptionsWidget);
        preludeLabel->setObjectName("preludeLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, preludeLabel);

        preludeLineEdit = new QLineEdit(AnalOptionsWidget);
        preludeLineEdit->setObjectName("preludeLineEdit");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(preludeLineEdit->sizePolicy().hasHeightForWidth());
        preludeLineEdit->setSizePolicy(sizePolicy);
        preludeLineEdit->setPlaceholderText(QString::fromUtf8("e.g.: 0x554889e5"));

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, preludeLineEdit);


        verticalLayout->addLayout(formLayout);

        autonameCheckbox = new QCheckBox(AnalOptionsWidget);
        autonameCheckbox->setObjectName("autonameCheckbox");

        verticalLayout->addWidget(autonameCheckbox, 0, Qt::AlignLeft);

        hasnextCheckbox = new QCheckBox(AnalOptionsWidget);
        hasnextCheckbox->setObjectName("hasnextCheckbox");

        verticalLayout->addWidget(hasnextCheckbox, 0, Qt::AlignLeft);

        jmpRefCheckbox = new QCheckBox(AnalOptionsWidget);
        jmpRefCheckbox->setObjectName("jmpRefCheckbox");

        verticalLayout->addWidget(jmpRefCheckbox, 0, Qt::AlignLeft);

        jmpTblCheckbox = new QCheckBox(AnalOptionsWidget);
        jmpTblCheckbox->setObjectName("jmpTblCheckbox");

        verticalLayout->addWidget(jmpTblCheckbox, 0, Qt::AlignLeft);

        pushRetCheckBox = new QCheckBox(AnalOptionsWidget);
        pushRetCheckBox->setObjectName("pushRetCheckBox");

        verticalLayout->addWidget(pushRetCheckBox, 0, Qt::AlignLeft);

        typesVerboseCheckBox = new QCheckBox(AnalOptionsWidget);
        typesVerboseCheckBox->setObjectName("typesVerboseCheckBox");

        verticalLayout->addWidget(typesVerboseCheckBox, 0, Qt::AlignLeft);

        verboseCheckBox = new QCheckBox(AnalOptionsWidget);
        verboseCheckBox->setObjectName("verboseCheckBox");

        verticalLayout->addWidget(verboseCheckBox, 0, Qt::AlignLeft);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(AnalOptionsWidget);

        QMetaObject::connectSlotsByName(AnalOptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *AnalOptionsWidget)
    {
        AnalOptionsWidget->setWindowTitle(QCoreApplication::translate("AnalOptionsWidget", "Analysis", nullptr));
        analInLabel->setText(QCoreApplication::translate("AnalOptionsWidget", "Search boundaries for analysis (anal.in):", nullptr));
        ptrDepthLabel->setText(QCoreApplication::translate("AnalOptionsWidget", "Pointer depth (anal.ptrdepth):", nullptr));
        preludeLabel->setText(QCoreApplication::translate("AnalOptionsWidget", "Functions Prelude (anal.prelude):", nullptr));
        autonameCheckbox->setText(QCoreApplication::translate("AnalOptionsWidget", "Speculatively set a name for the functions (anal.autoname)", nullptr));
        hasnextCheckbox->setText(QCoreApplication::translate("AnalOptionsWidget", "Search for new functions following already defined functions (anal.hasnext)", nullptr));
        jmpRefCheckbox->setText(QCoreApplication::translate("AnalOptionsWidget", "Create references for unconditional jumps (anal.jmp.ref)", nullptr));
        jmpTblCheckbox->setText(QCoreApplication::translate("AnalOptionsWidget", "Analyze jump tables in switch statements (anal.jmp.tbl)", nullptr));
        pushRetCheckBox->setText(QCoreApplication::translate("AnalOptionsWidget", "Analyze push+ret as jmp (anal.pushret)", nullptr));
        typesVerboseCheckBox->setText(QCoreApplication::translate("AnalOptionsWidget", "Verbose output from type analysis (types.verbose)", nullptr));
        verboseCheckBox->setText(QCoreApplication::translate("AnalOptionsWidget", "Show verbose information when performing analysis (anal.verbose)", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AnalOptionsWidget: public Ui_AnalOptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ANALOPTIONSWIDGET_H
