/********************************************************************************
** Form generated from reading UI file 'IaitoTreeView.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IAITOTREEVIEW_H
#define UI_IAITOTREEVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTreeView>

QT_BEGIN_NAMESPACE

class Ui_IaitoTreeView
{
public:

    void setupUi(QTreeView *IaitoTreeView)
    {
        if (IaitoTreeView->objectName().isEmpty())
            IaitoTreeView->setObjectName("IaitoTreeView");
        if (IaitoTreeView->header()->objectName().isEmpty())

        retranslateUi(IaitoTreeView);

        QMetaObject::connectSlotsByName(IaitoTreeView);
    } // setupUi

    void retranslateUi(QTreeView *IaitoTreeView)
    {
        (void)IaitoTreeView;
    } // retranslateUi

};

namespace Ui {
    class IaitoTreeView: public Ui_IaitoTreeView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_IAITOTREEVIEW_H
