/********************************************************************************
** Form generated from reading UI file 'AppearanceOptionsWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_APPEARANCEOPTIONSWIDGET_H
#define UI_APPEARANCEOPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/ColorThemeComboBox.h"

QT_BEGIN_NAMESPACE

class Ui_AppearanceOptionsWidget
{
public:
    QAction *actionSaveAsDefault;
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *fontLabel;
    QHBoxLayout *fontSelectionLayout;
    QComboBox *fontFamilyComboBox;
    QSpinBox *fontSizeSpinBox;
    QLabel *fontSelectionLabel;
    QPushButton *fontSelectionButton;
    QPushButton *fontResetButton;
    QLabel *label;
    QSpinBox *fontZoomBox;
    QLabel *languageLabel;
    QComboBox *languageComboBox;
    QLabel *themeLabel;
    QHBoxLayout *interfaceThemeLayout;
    QComboBox *themeComboBox;
    QPushButton *ifaceEditButton;
    QPushButton *ifaceRenameButton;
    QPushButton *ifaceCopyButton;
    QPushButton *ifaceDeleteButton;
    QPushButton *ifaceExportButton;
    QPushButton *ifaceImportButton;
    QSpacerItem *interfaceThemeSpacer;
    QLabel *visualNavbarLabel;
    QVBoxLayout *visualNavbarSettingsLayout;
    QHBoxLayout *visualNavbarLayout;
    QComboBox *visualNavbarLocationComboBox;
    QLabel *visualNavbarThicknessLabel;
    QSpinBox *visualNavbarThicknessSpinBox;
    QLabel *colorLabel;
    QHBoxLayout *horizontalLayout_3;
    ColorThemeComboBox *colorComboBox;
    QPushButton *editButton;
    QPushButton *renameButton;
    QPushButton *copyButton;
    QPushButton *deleteButton;
    QPushButton *exportButton;
    QPushButton *importButton;
    QSpacerItem *horizontalSpacer;
    QCheckBox *decompilerRunInBackground;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *AppearanceOptionsWidget)
    {
        if (AppearanceOptionsWidget->objectName().isEmpty())
            AppearanceOptionsWidget->setObjectName("AppearanceOptionsWidget");
        actionSaveAsDefault = new QAction(AppearanceOptionsWidget);
        actionSaveAsDefault->setObjectName("actionSaveAsDefault");
        verticalLayout = new QVBoxLayout(AppearanceOptionsWidget);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setLabelAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        formLayout->setFormAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        fontLabel = new QLabel(AppearanceOptionsWidget);
        fontLabel->setObjectName("fontLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, fontLabel);

        fontSelectionLayout = new QHBoxLayout();
        fontSelectionLayout->setObjectName("fontSelectionLayout");
        fontFamilyComboBox = new QComboBox(AppearanceOptionsWidget);
        fontFamilyComboBox->setObjectName("fontFamilyComboBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(fontFamilyComboBox->sizePolicy().hasHeightForWidth());
        fontFamilyComboBox->setSizePolicy(sizePolicy);

        fontSelectionLayout->addWidget(fontFamilyComboBox);

        fontSizeSpinBox = new QSpinBox(AppearanceOptionsWidget);
        fontSizeSpinBox->setObjectName("fontSizeSpinBox");
        fontSizeSpinBox->setMinimum(6);
        fontSizeSpinBox->setMaximum(72);
        fontSizeSpinBox->setValue(13);

        fontSelectionLayout->addWidget(fontSizeSpinBox);

        fontSelectionLabel = new QLabel(AppearanceOptionsWidget);
        fontSelectionLabel->setObjectName("fontSelectionLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Ignored, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(1);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(fontSelectionLabel->sizePolicy().hasHeightForWidth());
        fontSelectionLabel->setSizePolicy(sizePolicy1);
        fontSelectionLabel->setMinimumSize(QSize(0, 0));
        fontSelectionLabel->setText(QString::fromUtf8(""));
        fontSelectionLabel->setTextInteractionFlags(Qt::TextSelectableByMouse);

        fontSelectionLayout->addWidget(fontSelectionLabel);

        fontSelectionButton = new QPushButton(AppearanceOptionsWidget);
        fontSelectionButton->setObjectName("fontSelectionButton");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(fontSelectionButton->sizePolicy().hasHeightForWidth());
        fontSelectionButton->setSizePolicy(sizePolicy2);

        fontSelectionLayout->addWidget(fontSelectionButton);

        fontResetButton = new QPushButton(AppearanceOptionsWidget);
        fontResetButton->setObjectName("fontResetButton");
        sizePolicy2.setHeightForWidth(fontResetButton->sizePolicy().hasHeightForWidth());
        fontResetButton->setSizePolicy(sizePolicy2);

        fontSelectionLayout->addWidget(fontResetButton);


        formLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, fontSelectionLayout);

        label = new QLabel(AppearanceOptionsWidget);
        label->setObjectName("label");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label);

        fontZoomBox = new QSpinBox(AppearanceOptionsWidget);
        fontZoomBox->setObjectName("fontZoomBox");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(fontZoomBox->sizePolicy().hasHeightForWidth());
        fontZoomBox->setSizePolicy(sizePolicy3);
        fontZoomBox->setWrapping(false);
        fontZoomBox->setFrame(true);
        fontZoomBox->setButtonSymbols(QAbstractSpinBox::PlusMinus);
        fontZoomBox->setProperty("showGroupSeparator", QVariant(false));
        fontZoomBox->setMinimum(10);
        fontZoomBox->setMaximum(3000);
        fontZoomBox->setSingleStep(10);
        fontZoomBox->setValue(100);

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, fontZoomBox);

        languageLabel = new QLabel(AppearanceOptionsWidget);
        languageLabel->setObjectName("languageLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, languageLabel);

        languageComboBox = new QComboBox(AppearanceOptionsWidget);
        languageComboBox->setObjectName("languageComboBox");
        sizePolicy3.setHeightForWidth(languageComboBox->sizePolicy().hasHeightForWidth());
        languageComboBox->setSizePolicy(sizePolicy3);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, languageComboBox);

        themeLabel = new QLabel(AppearanceOptionsWidget);
        themeLabel->setObjectName("themeLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, themeLabel);

        interfaceThemeLayout = new QHBoxLayout();
        interfaceThemeLayout->setObjectName("interfaceThemeLayout");
        themeComboBox = new QComboBox(AppearanceOptionsWidget);
        themeComboBox->setObjectName("themeComboBox");
        sizePolicy3.setHeightForWidth(themeComboBox->sizePolicy().hasHeightForWidth());
        themeComboBox->setSizePolicy(sizePolicy3);

        interfaceThemeLayout->addWidget(themeComboBox);

        ifaceEditButton = new QPushButton(AppearanceOptionsWidget);
        ifaceEditButton->setObjectName("ifaceEditButton");
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/img/icons/pencil_thin.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        ifaceEditButton->setIcon(icon);

        interfaceThemeLayout->addWidget(ifaceEditButton);

        ifaceRenameButton = new QPushButton(AppearanceOptionsWidget);
        ifaceRenameButton->setObjectName("ifaceRenameButton");
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/img/icons/rename.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        ifaceRenameButton->setIcon(icon1);

        interfaceThemeLayout->addWidget(ifaceRenameButton);

        ifaceCopyButton = new QPushButton(AppearanceOptionsWidget);
        ifaceCopyButton->setObjectName("ifaceCopyButton");
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/img/icons/copy.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        ifaceCopyButton->setIcon(icon2);

        interfaceThemeLayout->addWidget(ifaceCopyButton);

        ifaceDeleteButton = new QPushButton(AppearanceOptionsWidget);
        ifaceDeleteButton->setObjectName("ifaceDeleteButton");
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/img/icons/trash_bin.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        ifaceDeleteButton->setIcon(icon3);

        interfaceThemeLayout->addWidget(ifaceDeleteButton);

        ifaceExportButton = new QPushButton(AppearanceOptionsWidget);
        ifaceExportButton->setObjectName("ifaceExportButton");
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/img/icons/upload_black.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        ifaceExportButton->setIcon(icon4);

        interfaceThemeLayout->addWidget(ifaceExportButton);

        ifaceImportButton = new QPushButton(AppearanceOptionsWidget);
        ifaceImportButton->setObjectName("ifaceImportButton");
        QIcon icon5;
        icon5.addFile(QString::fromUtf8(":/img/icons/download_black.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        ifaceImportButton->setIcon(icon5);

        interfaceThemeLayout->addWidget(ifaceImportButton);

        interfaceThemeSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        interfaceThemeLayout->addItem(interfaceThemeSpacer);


        formLayout->setLayout(2, QFormLayout::ItemRole::FieldRole, interfaceThemeLayout);

        visualNavbarLabel = new QLabel(AppearanceOptionsWidget);
        visualNavbarLabel->setObjectName("visualNavbarLabel");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, visualNavbarLabel);

        visualNavbarSettingsLayout = new QVBoxLayout();
        visualNavbarSettingsLayout->setObjectName("visualNavbarSettingsLayout");
        visualNavbarLayout = new QHBoxLayout();
        visualNavbarLayout->setObjectName("visualNavbarLayout");
        visualNavbarLocationComboBox = new QComboBox(AppearanceOptionsWidget);
        visualNavbarLocationComboBox->setObjectName("visualNavbarLocationComboBox");
        sizePolicy3.setHeightForWidth(visualNavbarLocationComboBox->sizePolicy().hasHeightForWidth());
        visualNavbarLocationComboBox->setSizePolicy(sizePolicy3);

        visualNavbarLayout->addWidget(visualNavbarLocationComboBox);

        visualNavbarThicknessLabel = new QLabel(AppearanceOptionsWidget);
        visualNavbarThicknessLabel->setObjectName("visualNavbarThicknessLabel");

        visualNavbarLayout->addWidget(visualNavbarThicknessLabel);

        visualNavbarThicknessSpinBox = new QSpinBox(AppearanceOptionsWidget);
        visualNavbarThicknessSpinBox->setObjectName("visualNavbarThicknessSpinBox");
        visualNavbarThicknessSpinBox->setMinimum(8);
        visualNavbarThicknessSpinBox->setMaximum(64);

        visualNavbarLayout->addWidget(visualNavbarThicknessSpinBox);


        visualNavbarSettingsLayout->addLayout(visualNavbarLayout);


        formLayout->setLayout(3, QFormLayout::ItemRole::FieldRole, visualNavbarSettingsLayout);

        colorLabel = new QLabel(AppearanceOptionsWidget);
        colorLabel->setObjectName("colorLabel");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, colorLabel);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        colorComboBox = new ColorThemeComboBox(AppearanceOptionsWidget);
        colorComboBox->setObjectName("colorComboBox");
        sizePolicy3.setHeightForWidth(colorComboBox->sizePolicy().hasHeightForWidth());
        colorComboBox->setSizePolicy(sizePolicy3);

        horizontalLayout_3->addWidget(colorComboBox);

        editButton = new QPushButton(AppearanceOptionsWidget);
        editButton->setObjectName("editButton");
        editButton->setIcon(icon);

        horizontalLayout_3->addWidget(editButton);

        renameButton = new QPushButton(AppearanceOptionsWidget);
        renameButton->setObjectName("renameButton");
        renameButton->setIcon(icon1);

        horizontalLayout_3->addWidget(renameButton);

        copyButton = new QPushButton(AppearanceOptionsWidget);
        copyButton->setObjectName("copyButton");
        sizePolicy3.setHeightForWidth(copyButton->sizePolicy().hasHeightForWidth());
        copyButton->setSizePolicy(sizePolicy3);
        copyButton->setIcon(icon2);

        horizontalLayout_3->addWidget(copyButton);

        deleteButton = new QPushButton(AppearanceOptionsWidget);
        deleteButton->setObjectName("deleteButton");
        deleteButton->setIcon(icon3);

        horizontalLayout_3->addWidget(deleteButton);

        exportButton = new QPushButton(AppearanceOptionsWidget);
        exportButton->setObjectName("exportButton");
        exportButton->setIcon(icon4);

        horizontalLayout_3->addWidget(exportButton);

        importButton = new QPushButton(AppearanceOptionsWidget);
        importButton->setObjectName("importButton");
        importButton->setIcon(icon5);

        horizontalLayout_3->addWidget(importButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);


        formLayout->setLayout(4, QFormLayout::ItemRole::FieldRole, horizontalLayout_3);


        verticalLayout->addLayout(formLayout);

        decompilerRunInBackground = new QCheckBox(AppearanceOptionsWidget);
        decompilerRunInBackground->setObjectName("decompilerRunInBackground");

        verticalLayout->addWidget(decompilerRunInBackground);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(AppearanceOptionsWidget);

        QMetaObject::connectSlotsByName(AppearanceOptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *AppearanceOptionsWidget)
    {
        AppearanceOptionsWidget->setWindowTitle(QCoreApplication::translate("AppearanceOptionsWidget", "Appearance", nullptr));
        actionSaveAsDefault->setText(QCoreApplication::translate("AppearanceOptionsWidget", "Save as Default", nullptr));
        fontLabel->setText(QCoreApplication::translate("AppearanceOptionsWidget", "Font:", nullptr));
        fontSizeSpinBox->setSuffix(QCoreApplication::translate("AppearanceOptionsWidget", " pt", nullptr));
        fontSelectionButton->setText(QCoreApplication::translate("AppearanceOptionsWidget", "...", nullptr));
#if QT_CONFIG(tooltip)
        fontSelectionButton->setToolTip(QCoreApplication::translate("AppearanceOptionsWidget", "Select font", nullptr));
#endif // QT_CONFIG(tooltip)
        fontResetButton->setText(QCoreApplication::translate("AppearanceOptionsWidget", "Reset", nullptr));
        label->setText(QCoreApplication::translate("AppearanceOptionsWidget", "Zoom:", nullptr));
        fontZoomBox->setSuffix(QCoreApplication::translate("AppearanceOptionsWidget", "%", nullptr));
        languageLabel->setText(QCoreApplication::translate("AppearanceOptionsWidget", "Language:", nullptr));
        themeLabel->setText(QCoreApplication::translate("AppearanceOptionsWidget", "Interface Theme:", nullptr));
#if QT_CONFIG(tooltip)
        ifaceEditButton->setToolTip(QCoreApplication::translate("AppearanceOptionsWidget", "Edit Theme", nullptr));
#endif // QT_CONFIG(tooltip)
        ifaceEditButton->setText(QString());
#if QT_CONFIG(tooltip)
        ifaceRenameButton->setToolTip(QCoreApplication::translate("AppearanceOptionsWidget", "Rename", nullptr));
#endif // QT_CONFIG(tooltip)
        ifaceRenameButton->setText(QString());
#if QT_CONFIG(tooltip)
        ifaceCopyButton->setToolTip(QCoreApplication::translate("AppearanceOptionsWidget", "Copy", nullptr));
#endif // QT_CONFIG(tooltip)
        ifaceCopyButton->setText(QString());
#if QT_CONFIG(tooltip)
        ifaceDeleteButton->setToolTip(QCoreApplication::translate("AppearanceOptionsWidget", "Delete", nullptr));
#endif // QT_CONFIG(tooltip)
        ifaceDeleteButton->setText(QString());
#if QT_CONFIG(tooltip)
        ifaceExportButton->setToolTip(QCoreApplication::translate("AppearanceOptionsWidget", "Export", nullptr));
#endif // QT_CONFIG(tooltip)
        ifaceExportButton->setText(QString());
#if QT_CONFIG(tooltip)
        ifaceImportButton->setToolTip(QCoreApplication::translate("AppearanceOptionsWidget", "Import", nullptr));
#endif // QT_CONFIG(tooltip)
        ifaceImportButton->setText(QString());
        visualNavbarLabel->setText(QCoreApplication::translate("AppearanceOptionsWidget", "Navigation Bar:", nullptr));
        visualNavbarThicknessLabel->setText(QCoreApplication::translate("AppearanceOptionsWidget", "Thickness", nullptr));
        visualNavbarThicknessSpinBox->setSuffix(QCoreApplication::translate("AppearanceOptionsWidget", " px", nullptr));
        colorLabel->setText(QCoreApplication::translate("AppearanceOptionsWidget", "Color Theme:", nullptr));
#if QT_CONFIG(tooltip)
        editButton->setToolTip(QCoreApplication::translate("AppearanceOptionsWidget", "Edit Theme", nullptr));
#endif // QT_CONFIG(tooltip)
        editButton->setText(QString());
#if QT_CONFIG(tooltip)
        renameButton->setToolTip(QCoreApplication::translate("AppearanceOptionsWidget", "Rename", nullptr));
#endif // QT_CONFIG(tooltip)
        renameButton->setText(QString());
#if QT_CONFIG(tooltip)
        copyButton->setToolTip(QCoreApplication::translate("AppearanceOptionsWidget", "Copy", nullptr));
#endif // QT_CONFIG(tooltip)
        copyButton->setText(QString());
#if QT_CONFIG(tooltip)
        deleteButton->setToolTip(QCoreApplication::translate("AppearanceOptionsWidget", "Delete", nullptr));
#endif // QT_CONFIG(tooltip)
        deleteButton->setText(QString());
#if QT_CONFIG(tooltip)
        exportButton->setToolTip(QCoreApplication::translate("AppearanceOptionsWidget", "Export", nullptr));
#endif // QT_CONFIG(tooltip)
        exportButton->setText(QString());
#if QT_CONFIG(tooltip)
        importButton->setToolTip(QCoreApplication::translate("AppearanceOptionsWidget", "Import", nullptr));
#endif // QT_CONFIG(tooltip)
        importButton->setText(QString());
#if QT_CONFIG(tooltip)
        decompilerRunInBackground->setToolTip(QCoreApplication::translate("AppearanceOptionsWidget", "Run decompilation tasks in the background (asynchronous). When disabled, runs in foreground (synchronous).", nullptr));
#endif // QT_CONFIG(tooltip)
        decompilerRunInBackground->setText(QCoreApplication::translate("AppearanceOptionsWidget", "Run decompilation in background", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AppearanceOptionsWidget: public Ui_AppearanceOptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_APPEARANCEOPTIONSWIDGET_H
