/********************************************************************************
** Form generated from reading UI file 'LinkTypeDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LINKTYPEDIALOG_H
#define UI_LINKTYPEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>

QT_BEGIN_NAMESPACE

class Ui_LinkTypeDialog
{
public:
    QGridLayout *gridLayout;
    QLabel *equalSymbolLabel;
    QLineEdit *addressLineEdit;
    QLineEdit *exprLineEdit;
    QLabel *structureTypeLabel;
    QComboBox *structureTypeComboBox;
    QDialogButtonBox *buttonBox;
    QLabel *addressLabel;

    void setupUi(QDialog *LinkTypeDialog)
    {
        if (LinkTypeDialog->objectName().isEmpty())
            LinkTypeDialog->setObjectName("LinkTypeDialog");
        LinkTypeDialog->resize(500, 105);
        LinkTypeDialog->setMinimumSize(QSize(500, 0));
        gridLayout = new QGridLayout(LinkTypeDialog);
        gridLayout->setObjectName("gridLayout");
        equalSymbolLabel = new QLabel(LinkTypeDialog);
        equalSymbolLabel->setObjectName("equalSymbolLabel");

        gridLayout->addWidget(equalSymbolLabel, 1, 2, 1, 1);

        addressLineEdit = new QLineEdit(LinkTypeDialog);
        addressLineEdit->setObjectName("addressLineEdit");
        addressLineEdit->setEnabled(true);
        addressLineEdit->setReadOnly(true);

        gridLayout->addWidget(addressLineEdit, 1, 3, 1, 1);

        exprLineEdit = new QLineEdit(LinkTypeDialog);
        exprLineEdit->setObjectName("exprLineEdit");

        gridLayout->addWidget(exprLineEdit, 1, 1, 1, 1);

        structureTypeLabel = new QLabel(LinkTypeDialog);
        structureTypeLabel->setObjectName("structureTypeLabel");

        gridLayout->addWidget(structureTypeLabel, 0, 0, 1, 1);

        structureTypeComboBox = new QComboBox(LinkTypeDialog);
        structureTypeComboBox->setObjectName("structureTypeComboBox");

        gridLayout->addWidget(structureTypeComboBox, 0, 1, 1, 3);

        buttonBox = new QDialogButtonBox(LinkTypeDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 2, 3, 1, 1);

        addressLabel = new QLabel(LinkTypeDialog);
        addressLabel->setObjectName("addressLabel");

        gridLayout->addWidget(addressLabel, 1, 0, 1, 1);

#if QT_CONFIG(shortcut)
        structureTypeLabel->setBuddy(structureTypeComboBox);
        addressLabel->setBuddy(exprLineEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(LinkTypeDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, LinkTypeDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, LinkTypeDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(LinkTypeDialog);
    } // setupUi

    void retranslateUi(QDialog *LinkTypeDialog)
    {
        LinkTypeDialog->setWindowTitle(QCoreApplication::translate("LinkTypeDialog", "Dialog", nullptr));
        equalSymbolLabel->setText(QCoreApplication::translate("LinkTypeDialog", "=", nullptr));
        exprLineEdit->setPlaceholderText(QCoreApplication::translate("LinkTypeDialog", "Enter Address", nullptr));
        structureTypeLabel->setText(QCoreApplication::translate("LinkTypeDialog", "Structure Type", nullptr));
        addressLabel->setText(QCoreApplication::translate("LinkTypeDialog", "Address/Flag", nullptr));
    } // retranslateUi

};

namespace Ui {
    class LinkTypeDialog: public Ui_LinkTypeDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LINKTYPEDIALOG_H
