/****************************************************************************
** Meta object code from reading C++ file 'DecompilerContextMenu.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/menus/DecompilerContextMenu.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DecompilerContextMenu.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21DecompilerContextMenuE_t {};
} // unnamed namespace

template <> constexpr inline auto DecompilerContextMenu::qt_create_metaobjectdata<qt_meta_tag_ZN21DecompilerContextMenuE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DecompilerContextMenu",
        "copy",
        "",
        "setCurHighlightedWord",
        "word",
        "setOffset",
        "RVA",
        "newOffset",
        "setDecompiledFunctionAddress",
        "functionAddr",
        "setFirstOffsetInLine",
        "firstOffset",
        "setAvailableBreakpoints",
        "QList<RVA>",
        "offsetList",
        "aboutToShowSlot",
        "aboutToHideSlot",
        "actionCopyTriggered",
        "actionCopyInstructionAddressTriggered",
        "actionCopyReferenceAddressTriggered",
        "actionCopyDeepLinkTriggered",
        "actionEditAnnotationTriggered",
        "actionAddCommentTriggered",
        "actionDeleteCommentTriggered",
        "actionRenameThingHereTriggered",
        "actionDeleteNameTriggered",
        "actionEditFunctionVariablesTriggered",
        "actionXRefsTriggered",
        "actionToggleBreakpointTriggered",
        "actionAdvancedBreakpointTriggered",
        "actionContinueUntilTriggered",
        "actionSetPCTriggered"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'copy'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setCurHighlightedWord'
        QtMocHelpers::SlotData<void(QString)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'setOffset'
        QtMocHelpers::SlotData<void(RVA)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'setDecompiledFunctionAddress'
        QtMocHelpers::SlotData<void(RVA)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 9 },
        }}),
        // Slot 'setFirstOffsetInLine'
        QtMocHelpers::SlotData<void(RVA)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 11 },
        }}),
        // Slot 'setAvailableBreakpoints'
        QtMocHelpers::SlotData<void(QVector<RVA>)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'aboutToShowSlot'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'aboutToHideSlot'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'actionCopyTriggered'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'actionCopyInstructionAddressTriggered'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'actionCopyReferenceAddressTriggered'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'actionCopyDeepLinkTriggered'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'actionEditAnnotationTriggered'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'actionAddCommentTriggered'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'actionDeleteCommentTriggered'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'actionRenameThingHereTriggered'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'actionDeleteNameTriggered'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'actionEditFunctionVariablesTriggered'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'actionXRefsTriggered'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'actionToggleBreakpointTriggered'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'actionAdvancedBreakpointTriggered'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'actionContinueUntilTriggered'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'actionSetPCTriggered'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DecompilerContextMenu, qt_meta_tag_ZN21DecompilerContextMenuE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DecompilerContextMenu::staticMetaObject = { {
    QMetaObject::SuperData::link<QMenu::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21DecompilerContextMenuE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21DecompilerContextMenuE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21DecompilerContextMenuE_t>.metaTypes,
    nullptr
} };

void DecompilerContextMenu::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DecompilerContextMenu *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->copy(); break;
        case 1: _t->setCurHighlightedWord((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->setOffset((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1]))); break;
        case 3: _t->setDecompiledFunctionAddress((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1]))); break;
        case 4: _t->setFirstOffsetInLine((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1]))); break;
        case 5: _t->setAvailableBreakpoints((*reinterpret_cast<std::add_pointer_t<QList<RVA>>>(_a[1]))); break;
        case 6: _t->aboutToShowSlot(); break;
        case 7: _t->aboutToHideSlot(); break;
        case 8: _t->actionCopyTriggered(); break;
        case 9: _t->actionCopyInstructionAddressTriggered(); break;
        case 10: _t->actionCopyReferenceAddressTriggered(); break;
        case 11: _t->actionCopyDeepLinkTriggered(); break;
        case 12: _t->actionEditAnnotationTriggered(); break;
        case 13: _t->actionAddCommentTriggered(); break;
        case 14: _t->actionDeleteCommentTriggered(); break;
        case 15: _t->actionRenameThingHereTriggered(); break;
        case 16: _t->actionDeleteNameTriggered(); break;
        case 17: _t->actionEditFunctionVariablesTriggered(); break;
        case 18: _t->actionXRefsTriggered(); break;
        case 19: _t->actionToggleBreakpointTriggered(); break;
        case 20: _t->actionAdvancedBreakpointTriggered(); break;
        case 21: _t->actionContinueUntilTriggered(); break;
        case 22: _t->actionSetPCTriggered(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DecompilerContextMenu::*)()>(_a, &DecompilerContextMenu::copy, 0))
            return;
    }
}

const QMetaObject *DecompilerContextMenu::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DecompilerContextMenu::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21DecompilerContextMenuE_t>.strings))
        return static_cast<void*>(this);
    return QMenu::qt_metacast(_clname);
}

int DecompilerContextMenu::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMenu::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void DecompilerContextMenu::copy()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
