/********************************************************************************
** Form generated from reading UI file 'QuickFilterView.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QUICKFILTERVIEW_H
#define UI_QUICKFILTERVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_QuickFilterView
{
public:
    QHBoxLayout *horizontalLayout;
    QLineEdit *filterLineEdit;

    void setupUi(QWidget *QuickFilterView)
    {
        if (QuickFilterView->objectName().isEmpty())
            QuickFilterView->setObjectName("QuickFilterView");
        QuickFilterView->resize(327, 25);
        horizontalLayout = new QHBoxLayout(QuickFilterView);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        filterLineEdit = new QLineEdit(QuickFilterView);
        filterLineEdit->setObjectName("filterLineEdit");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(filterLineEdit->sizePolicy().hasHeightForWidth());
        filterLineEdit->setSizePolicy(sizePolicy);
        filterLineEdit->setClearButtonEnabled(false);

        horizontalLayout->addWidget(filterLineEdit);


        retranslateUi(QuickFilterView);

        QMetaObject::connectSlotsByName(QuickFilterView);
    } // setupUi

    void retranslateUi(QWidget *QuickFilterView)
    {
        QuickFilterView->setWindowTitle(QCoreApplication::translate("QuickFilterView", "Form", nullptr));
        filterLineEdit->setPlaceholderText(QCoreApplication::translate("QuickFilterView", "Quick Filter", nullptr));
    } // retranslateUi

};

namespace Ui {
    class QuickFilterView: public Ui_QuickFilterView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QUICKFILTERVIEW_H
