/********************************************************************************
** Form generated from reading UI file 'AboutDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ABOUTDIALOG_H
#define UI_ABOUTDIALOG_H

#include <QtCore/QVariant>
#include <QtSvgWidgets/QSvgWidget>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_AboutDialog
{
public:
    QGridLayout *gridLayout_2;
    QLabel *label;
    QDialogButtonBox *buttonBox;
    QGridLayout *gridLayout;
    QLabel *label_3;
    QSvgWidget *logoSvgWidget;
    QLabel *label_2;
    QPushButton *showVersionButton;
    QPushButton *showPluginsButton;
    QPushButton *showPackageManagerButton;

    void setupUi(QDialog *AboutDialog)
    {
        if (AboutDialog->objectName().isEmpty())
            AboutDialog->setObjectName("AboutDialog");
        AboutDialog->resize(593, 393);
        gridLayout_2 = new QGridLayout(AboutDialog);
        gridLayout_2->setObjectName("gridLayout_2");
        label = new QLabel(AboutDialog);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);
        label->setStyleSheet(QString::fromUtf8("s"));
        label->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        label->setMargin(5);
        label->setOpenExternalLinks(true);
        label->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout_2->addWidget(label, 1, 0, 1, 1);

        buttonBox = new QDialogButtonBox(AboutDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        gridLayout_2->addWidget(buttonBox, 2, 0, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        gridLayout->setHorizontalSpacing(5);
        gridLayout->setVerticalSpacing(15);
        label_3 = new QLabel(AboutDialog);
        label_3->setObjectName("label_3");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(label_3, 3, 1, 1, 3, Qt::AlignHCenter|Qt::AlignVCenter);

        logoSvgWidget = new QSvgWidget(AboutDialog);
        logoSvgWidget->setObjectName("logoSvgWidget");
        logoSvgWidget->setMinimumSize(QSize(96, 96));
        logoSvgWidget->setMaximumSize(QSize(96, 96));

        gridLayout->addWidget(logoSvgWidget, 1, 2, 1, 1, Qt::AlignHCenter|Qt::AlignVCenter);

        label_2 = new QLabel(AboutDialog);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 2, 2, 1, 1, Qt::AlignHCenter|Qt::AlignVCenter);

        showVersionButton = new QPushButton(AboutDialog);
        showVersionButton->setObjectName("showVersionButton");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Maximum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(showVersionButton->sizePolicy().hasHeightForWidth());
        showVersionButton->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(showVersionButton, 4, 3, 1, 1);

        showPluginsButton = new QPushButton(AboutDialog);
        showPluginsButton->setObjectName("showPluginsButton");
        sizePolicy2.setHeightForWidth(showPluginsButton->sizePolicy().hasHeightForWidth());
        showPluginsButton->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(showPluginsButton, 4, 1, 1, 1);

        showPackageManagerButton = new QPushButton(AboutDialog);
        showPackageManagerButton->setObjectName("showPackageManagerButton");
        sizePolicy2.setHeightForWidth(showPackageManagerButton->sizePolicy().hasHeightForWidth());
        showPackageManagerButton->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(showPackageManagerButton, 4, 2, 1, 1, Qt::AlignHCenter|Qt::AlignVCenter);


        gridLayout_2->addLayout(gridLayout, 0, 0, 1, 1);


        retranslateUi(AboutDialog);

        QMetaObject::connectSlotsByName(AboutDialog);
    } // setupUi

    void retranslateUi(QDialog *AboutDialog)
    {
        AboutDialog->setWindowTitle(QCoreApplication::translate("AboutDialog", "About iaito", nullptr));
        label->setText(QCoreApplication::translate("AboutDialog", "<html><head/><body><p><br/></p></body></html>", nullptr));
        label_3->setText(QCoreApplication::translate("AboutDialog", "<html><head/><body><p align=\"center\"><span style=\" font-size:11pt; font-weight:600;\">iaito is a free and open-source reverse engineering platform powered by radare2</span></p></body></html>", nullptr));
        label_2->setText(QCoreApplication::translate("AboutDialog", "<html><head/><body><p><span style=\" font-size:28pt; font-weight:600;\">iaito</span></p></body></html>", nullptr));
        showVersionButton->setText(QCoreApplication::translate("AboutDialog", "Show version information", nullptr));
        showPluginsButton->setText(QCoreApplication::translate("AboutDialog", "Show radare2 plugin information", nullptr));
        showPackageManagerButton->setText(QCoreApplication::translate("AboutDialog", "Package Manager", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AboutDialog: public Ui_AboutDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ABOUTDIALOG_H
