/********************************************************************************
** Form generated from reading UI file 'InitialOptionsDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INITIALOPTIONSDIALOG_H
#define UI_INITIALOPTIONSDIALOG_H

#include <QtCore/QVariant>
#include <QtSvgWidgets/QSvgWidget>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_InitialOptionsDialog
{
public:
    QVBoxLayout *verticalLayout_10;
    QVBoxLayout *verticalLayout_9;
    QSvgWidget *logoSvgWidget;
    QHBoxLayout *horizontalLayout;
    QLabel *programLabel;
    QLineEdit *programLineEdit;
    QFrame *line_3;
    QWidget *optionsWidget;
    QVBoxLayout *verticalLayout_3;
    QVBoxLayout *verticalLayout_4;
    QFrame *line;
    QCheckBox *analCheckBox;
    QLabel *analDescription;
    QSlider *analSlider;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_5;
    QFrame *frame;
    QVBoxLayout *verticalLayout;
    QVBoxLayout *verticalLayout_2;
    QFrame *analoptionsFrame;
    QVBoxLayout *verticalLayout_7;
    QFrame *advancedAnlysisLine;
    QCheckBox *writeCheckBox;
    QCheckBox *binCacheCheckBox;
    QCheckBox *binCheckBox;
    QCheckBox *varCheckBox;
    QCheckBox *vaCheckBox;
    QCheckBox *demangleCheckBox;
    QHBoxLayout *horizontalLayout_6;
    QToolButton *AdvOptButton;
    QLabel *label_5;
    QFrame *hideFrame;
    QVBoxLayout *verticalLayout_8;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_2;
    QLabel *archLabel;
    QComboBox *archComboBox;
    QLabel *cpuLabel;
    QComboBox *cpuComboBox;
    QHBoxLayout *horizontalLayout_5;
    QLabel *bitsLabel;
    QComboBox *bitsComboBox;
    QLabel *endiannessLabel;
    QComboBox *endiannessComboBox;
    QHBoxLayout *horizontalLayout_3;
    QLabel *kernelLabel;
    QComboBox *kernelComboBox;
    QLabel *formatLabel;
    QComboBox *formatComboBox;
    QFrame *line_2;
    QFormLayout *formLayout_2;
    QLabel *offsetLabel;
    QLineEdit *entry_loadOffset;
    QLabel *mapLabel;
    QLineEdit *entry_mapOffset;
    QCheckBox *pdbCheckBox;
    QWidget *pdbWidget;
    QHBoxLayout *pdbLayout;
    QLineEdit *pdbLineEdit;
    QPushButton *pdbSelectButton;
    QCheckBox *scriptCheckBox;
    QWidget *scriptWidget;
    QHBoxLayout *scriptLayout;
    QLineEdit *scriptLineEdit;
    QPushButton *scriptSelectButton;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer_3;
    QPushButton *cancelButton;
    QPushButton *okButton;

    void setupUi(QDialog *InitialOptionsDialog)
    {
        if (InitialOptionsDialog->objectName().isEmpty())
            InitialOptionsDialog->setObjectName("InitialOptionsDialog");
        InitialOptionsDialog->resize(598, 558);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(InitialOptionsDialog->sizePolicy().hasHeightForWidth());
        InitialOptionsDialog->setSizePolicy(sizePolicy);
        InitialOptionsDialog->setMinimumSize(QSize(400, 0));
        InitialOptionsDialog->setAutoFillBackground(false);
        InitialOptionsDialog->setStyleSheet(QString::fromUtf8("QCheckBox {\n"
"    margin-top: 5px;\n"
"    margin-bottom: 5px;\n"
"}"));
        verticalLayout_10 = new QVBoxLayout(InitialOptionsDialog);
        verticalLayout_10->setObjectName("verticalLayout_10");
        verticalLayout_9 = new QVBoxLayout();
        verticalLayout_9->setObjectName("verticalLayout_9");
        verticalLayout_9->setContentsMargins(8, 8, 8, 8);
        logoSvgWidget = new QSvgWidget(InitialOptionsDialog);
        logoSvgWidget->setObjectName("logoSvgWidget");
        logoSvgWidget->setMinimumSize(QSize(88, 88));
        logoSvgWidget->setMaximumSize(QSize(88, 88));

        verticalLayout_9->addWidget(logoSvgWidget, 0, Qt::AlignmentFlag::AlignHCenter);


        verticalLayout_10->addLayout(verticalLayout_9);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(-1, 5, -1, -1);
        programLabel = new QLabel(InitialOptionsDialog);
        programLabel->setObjectName("programLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(programLabel->sizePolicy().hasHeightForWidth());
        programLabel->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(programLabel);

        programLineEdit = new QLineEdit(InitialOptionsDialog);
        programLineEdit->setObjectName("programLineEdit");
        programLineEdit->setFocusPolicy(Qt::FocusPolicy::ClickFocus);
        programLineEdit->setText(QString::fromUtf8(""));
        programLineEdit->setFrame(false);
        programLineEdit->setReadOnly(true);
        programLineEdit->setClearButtonEnabled(false);

        horizontalLayout->addWidget(programLineEdit);


        verticalLayout_10->addLayout(horizontalLayout);

        line_3 = new QFrame(InitialOptionsDialog);
        line_3->setObjectName("line_3");
        line_3->setFrameShape(QFrame::Shape::HLine);
        line_3->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_10->addWidget(line_3);

        optionsWidget = new QWidget(InitialOptionsDialog);
        optionsWidget->setObjectName("optionsWidget");
        verticalLayout_3 = new QVBoxLayout(optionsWidget);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setSpacing(5);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setSizeConstraint(QLayout::SizeConstraint::SetDefaultConstraint);
        line = new QFrame(optionsWidget);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::VLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_4->addWidget(line);

        analCheckBox = new QCheckBox(optionsWidget);
        analCheckBox->setObjectName("analCheckBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(analCheckBox->sizePolicy().hasHeightForWidth());
        analCheckBox->setSizePolicy(sizePolicy2);
        analCheckBox->setLayoutDirection(Qt::LayoutDirection::LeftToRight);
        analCheckBox->setStyleSheet(QString::fromUtf8(""));
        analCheckBox->setChecked(true);

        verticalLayout_4->addWidget(analCheckBox);

        analDescription = new QLabel(optionsWidget);
        analDescription->setObjectName("analDescription");
        sizePolicy2.setHeightForWidth(analDescription->sizePolicy().hasHeightForWidth());
        analDescription->setSizePolicy(sizePolicy2);

        verticalLayout_4->addWidget(analDescription);


        verticalLayout_3->addLayout(verticalLayout_4);

        analSlider = new QSlider(optionsWidget);
        analSlider->setObjectName("analSlider");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(analSlider->sizePolicy().hasHeightForWidth());
        analSlider->setSizePolicy(sizePolicy3);
        analSlider->setMinimum(0);
        analSlider->setMaximum(6);
        analSlider->setPageStep(1);
        analSlider->setValue(0);
        analSlider->setOrientation(Qt::Orientation::Horizontal);
        analSlider->setInvertedAppearance(false);
        analSlider->setTickPosition(QSlider::TickPosition::NoTicks);

        verticalLayout_3->addWidget(analSlider);

        scrollArea = new QScrollArea(optionsWidget);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 572, 508));
        verticalLayout_5 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_5->setSpacing(0);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(-1, 0, -1, 0);
        frame = new QFrame(scrollAreaWidgetContents);
        frame->setObjectName("frame");
        sizePolicy1.setHeightForWidth(frame->sizePolicy().hasHeightForWidth());
        frame->setSizePolicy(sizePolicy1);
        frame->setFrameShape(QFrame::Shape::NoFrame);
        frame->setFrameShadow(QFrame::Shadow::Plain);
        verticalLayout = new QVBoxLayout(frame);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setSizeConstraint(QLayout::SizeConstraint::SetDefaultConstraint);
        verticalLayout->setContentsMargins(5, 0, 5, 0);
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setSizeConstraint(QLayout::SizeConstraint::SetMinimumSize);
        analoptionsFrame = new QFrame(frame);
        analoptionsFrame->setObjectName("analoptionsFrame");
        analoptionsFrame->setEnabled(true);
        sizePolicy3.setHeightForWidth(analoptionsFrame->sizePolicy().hasHeightForWidth());
        analoptionsFrame->setSizePolicy(sizePolicy3);
        verticalLayout_7 = new QVBoxLayout(analoptionsFrame);
        verticalLayout_7->setSpacing(6);
        verticalLayout_7->setObjectName("verticalLayout_7");
        verticalLayout_7->setContentsMargins(5, 5, 5, 5);

        verticalLayout_2->addWidget(analoptionsFrame);

        advancedAnlysisLine = new QFrame(frame);
        advancedAnlysisLine->setObjectName("advancedAnlysisLine");
        advancedAnlysisLine->setVisible(false);
        advancedAnlysisLine->setFrameShape(QFrame::Shape::HLine);
        advancedAnlysisLine->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_2->addWidget(advancedAnlysisLine);

        writeCheckBox = new QCheckBox(frame);
        writeCheckBox->setObjectName("writeCheckBox");
        writeCheckBox->setChecked(false);

        verticalLayout_2->addWidget(writeCheckBox);

        binCacheCheckBox = new QCheckBox(frame);
        binCacheCheckBox->setObjectName("binCacheCheckBox");
        binCacheCheckBox->setChecked(false);

        verticalLayout_2->addWidget(binCacheCheckBox);

        binCheckBox = new QCheckBox(frame);
        binCheckBox->setObjectName("binCheckBox");
        binCheckBox->setChecked(true);

        verticalLayout_2->addWidget(binCheckBox);

        varCheckBox = new QCheckBox(frame);
        varCheckBox->setObjectName("varCheckBox");

        verticalLayout_2->addWidget(varCheckBox);

        vaCheckBox = new QCheckBox(frame);
        vaCheckBox->setObjectName("vaCheckBox");
        vaCheckBox->setStyleSheet(QString::fromUtf8(""));
        vaCheckBox->setChecked(true);

        verticalLayout_2->addWidget(vaCheckBox);

        demangleCheckBox = new QCheckBox(frame);
        demangleCheckBox->setObjectName("demangleCheckBox");
        demangleCheckBox->setChecked(true);

        verticalLayout_2->addWidget(demangleCheckBox);


        verticalLayout->addLayout(verticalLayout_2);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalLayout_6->setContentsMargins(-1, 0, -1, -1);
        AdvOptButton = new QToolButton(frame);
        AdvOptButton->setObjectName("AdvOptButton");
        AdvOptButton->setIconSize(QSize(8, 8));
        AdvOptButton->setCheckable(true);
        AdvOptButton->setArrowType(Qt::ArrowType::RightArrow);

        horizontalLayout_6->addWidget(AdvOptButton);

        label_5 = new QLabel(frame);
        label_5->setObjectName("label_5");
        sizePolicy1.setHeightForWidth(label_5->sizePolicy().hasHeightForWidth());
        label_5->setSizePolicy(sizePolicy1);
        QFont font;
        font.setBold(true);
        label_5->setFont(font);

        horizontalLayout_6->addWidget(label_5);


        verticalLayout->addLayout(horizontalLayout_6);

        hideFrame = new QFrame(frame);
        hideFrame->setObjectName("hideFrame");
        verticalLayout_8 = new QVBoxLayout(hideFrame);
        verticalLayout_8->setObjectName("verticalLayout_8");
        label_2 = new QLabel(hideFrame);
        label_2->setObjectName("label_2");
        sizePolicy1.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy1);
        label_2->setFont(font);
#if QT_CONFIG(tooltip)
        label_2->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(accessibility)
        label_2->setAccessibleDescription(QString::fromUtf8(""));
#endif // QT_CONFIG(accessibility)

        verticalLayout_8->addWidget(label_2);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        archLabel = new QLabel(hideFrame);
        archLabel->setObjectName("archLabel");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(archLabel->sizePolicy().hasHeightForWidth());
        archLabel->setSizePolicy(sizePolicy4);

        horizontalLayout_2->addWidget(archLabel);

        archComboBox = new QComboBox(hideFrame);
        archComboBox->addItem(QString());
        archComboBox->setObjectName("archComboBox");
        archComboBox->setCurrentText(QString::fromUtf8("Auto"));

        horizontalLayout_2->addWidget(archComboBox);

        cpuLabel = new QLabel(hideFrame);
        cpuLabel->setObjectName("cpuLabel");
        sizePolicy4.setHeightForWidth(cpuLabel->sizePolicy().hasHeightForWidth());
        cpuLabel->setSizePolicy(sizePolicy4);

        horizontalLayout_2->addWidget(cpuLabel);

        cpuComboBox = new QComboBox(hideFrame);
        cpuComboBox->addItem(QString());
        cpuComboBox->setObjectName("cpuComboBox");
        cpuComboBox->setMinimumSize(QSize(70, 0));
        cpuComboBox->setEditable(true);

        horizontalLayout_2->addWidget(cpuComboBox);


        verticalLayout_8->addLayout(horizontalLayout_2);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalLayout_5->setContentsMargins(-1, 0, -1, -1);
        bitsLabel = new QLabel(hideFrame);
        bitsLabel->setObjectName("bitsLabel");
        sizePolicy4.setHeightForWidth(bitsLabel->sizePolicy().hasHeightForWidth());
        bitsLabel->setSizePolicy(sizePolicy4);
        bitsLabel->setText(QString::fromUtf8("Bits: "));

        horizontalLayout_5->addWidget(bitsLabel);

        bitsComboBox = new QComboBox(hideFrame);
        bitsComboBox->addItem(QString());
        bitsComboBox->addItem(QString());
        bitsComboBox->addItem(QString());
        bitsComboBox->addItem(QString());
        bitsComboBox->addItem(QString());
        bitsComboBox->setObjectName("bitsComboBox");

        horizontalLayout_5->addWidget(bitsComboBox);

        endiannessLabel = new QLabel(hideFrame);
        endiannessLabel->setObjectName("endiannessLabel");
        sizePolicy4.setHeightForWidth(endiannessLabel->sizePolicy().hasHeightForWidth());
        endiannessLabel->setSizePolicy(sizePolicy4);

        horizontalLayout_5->addWidget(endiannessLabel);

        endiannessComboBox = new QComboBox(hideFrame);
        endiannessComboBox->addItem(QString());
        endiannessComboBox->addItem(QString());
        endiannessComboBox->addItem(QString());
        endiannessComboBox->setObjectName("endiannessComboBox");
        endiannessComboBox->setEditable(false);
        endiannessComboBox->setCurrentText(QString::fromUtf8("Auto"));

        horizontalLayout_5->addWidget(endiannessComboBox);


        verticalLayout_8->addLayout(horizontalLayout_5);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setContentsMargins(-1, 0, -1, -1);
        kernelLabel = new QLabel(hideFrame);
        kernelLabel->setObjectName("kernelLabel");
        sizePolicy4.setHeightForWidth(kernelLabel->sizePolicy().hasHeightForWidth());
        kernelLabel->setSizePolicy(sizePolicy4);

        horizontalLayout_3->addWidget(kernelLabel);

        kernelComboBox = new QComboBox(hideFrame);
        kernelComboBox->addItem(QString());
        kernelComboBox->setObjectName("kernelComboBox");
        kernelComboBox->setEditable(false);
        kernelComboBox->setCurrentText(QString::fromUtf8("Auto"));

        horizontalLayout_3->addWidget(kernelComboBox);

        formatLabel = new QLabel(hideFrame);
        formatLabel->setObjectName("formatLabel");
        sizePolicy4.setHeightForWidth(formatLabel->sizePolicy().hasHeightForWidth());
        formatLabel->setSizePolicy(sizePolicy4);

        horizontalLayout_3->addWidget(formatLabel);

        formatComboBox = new QComboBox(hideFrame);
        formatComboBox->addItem(QString());
        formatComboBox->setObjectName("formatComboBox");
        formatComboBox->setCurrentText(QString::fromUtf8("Auto"));

        horizontalLayout_3->addWidget(formatComboBox);


        verticalLayout_8->addLayout(horizontalLayout_3);

        line_2 = new QFrame(hideFrame);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_8->addWidget(line_2);

        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setSizeConstraint(QLayout::SizeConstraint::SetDefaultConstraint);
        formLayout_2->setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy::ExpandingFieldsGrow);
        formLayout_2->setLabelAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);
        formLayout_2->setFormAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);
        formLayout_2->setVerticalSpacing(10);
        formLayout_2->setContentsMargins(-1, 0, -1, -1);
        offsetLabel = new QLabel(hideFrame);
        offsetLabel->setObjectName("offsetLabel");
        sizePolicy4.setHeightForWidth(offsetLabel->sizePolicy().hasHeightForWidth());
        offsetLabel->setSizePolicy(sizePolicy4);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, offsetLabel);

        entry_loadOffset = new QLineEdit(hideFrame);
        entry_loadOffset->setObjectName("entry_loadOffset");
        entry_loadOffset->setInputMask(QString::fromUtf8(""));
        entry_loadOffset->setText(QString::fromUtf8(""));
        entry_loadOffset->setFrame(false);
        entry_loadOffset->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, entry_loadOffset);

        mapLabel = new QLabel(hideFrame);
        mapLabel->setObjectName("mapLabel");
        sizePolicy4.setHeightForWidth(mapLabel->sizePolicy().hasHeightForWidth());
        mapLabel->setSizePolicy(sizePolicy4);
        mapLabel->setMinimumSize(QSize(0, 0));

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, mapLabel);

        entry_mapOffset = new QLineEdit(hideFrame);
        entry_mapOffset->setObjectName("entry_mapOffset");
        entry_mapOffset->setFrame(false);
        entry_mapOffset->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, entry_mapOffset);

        pdbCheckBox = new QCheckBox(hideFrame);
        pdbCheckBox->setObjectName("pdbCheckBox");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, pdbCheckBox);

        pdbWidget = new QWidget(hideFrame);
        pdbWidget->setObjectName("pdbWidget");
        pdbWidget->setEnabled(true);
        pdbLayout = new QHBoxLayout(pdbWidget);
        pdbLayout->setObjectName("pdbLayout");
        pdbLayout->setContentsMargins(0, 0, 0, 0);
        pdbLineEdit = new QLineEdit(pdbWidget);
        pdbLineEdit->setObjectName("pdbLineEdit");

        pdbLayout->addWidget(pdbLineEdit);

        pdbSelectButton = new QPushButton(pdbWidget);
        pdbSelectButton->setObjectName("pdbSelectButton");

        pdbLayout->addWidget(pdbSelectButton);


        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, pdbWidget);

        scriptCheckBox = new QCheckBox(hideFrame);
        scriptCheckBox->setObjectName("scriptCheckBox");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, scriptCheckBox);

        scriptWidget = new QWidget(hideFrame);
        scriptWidget->setObjectName("scriptWidget");
        scriptWidget->setEnabled(true);
        scriptLayout = new QHBoxLayout(scriptWidget);
        scriptLayout->setObjectName("scriptLayout");
        scriptLayout->setContentsMargins(0, 0, 0, 0);
        scriptLineEdit = new QLineEdit(scriptWidget);
        scriptLineEdit->setObjectName("scriptLineEdit");

        scriptLayout->addWidget(scriptLineEdit);

        scriptSelectButton = new QPushButton(scriptWidget);
        scriptSelectButton->setObjectName("scriptSelectButton");

        scriptLayout->addWidget(scriptSelectButton);


        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, scriptWidget);


        verticalLayout_8->addLayout(formLayout_2);


        verticalLayout->addWidget(hideFrame);


        verticalLayout_5->addWidget(frame);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_3->addWidget(scrollArea);


        verticalLayout_10->addWidget(optionsWidget);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalLayout_4->setContentsMargins(-1, 0, -1, -1);
        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_3);

        cancelButton = new QPushButton(InitialOptionsDialog);
        cancelButton->setObjectName("cancelButton");
        cancelButton->setFlat(false);

        horizontalLayout_4->addWidget(cancelButton);

        okButton = new QPushButton(InitialOptionsDialog);
        okButton->setObjectName("okButton");

        horizontalLayout_4->addWidget(okButton);


        verticalLayout_10->addLayout(horizontalLayout_4);


        retranslateUi(InitialOptionsDialog);

        cancelButton->setDefault(false);
        okButton->setDefault(true);


        QMetaObject::connectSlotsByName(InitialOptionsDialog);
    } // setupUi

    void retranslateUi(QDialog *InitialOptionsDialog)
    {
        InitialOptionsDialog->setWindowTitle(QCoreApplication::translate("InitialOptionsDialog", "Load Options", nullptr));
        programLabel->setText(QCoreApplication::translate("InitialOptionsDialog", "Program:", nullptr));
        analCheckBox->setText(QCoreApplication::translate("InitialOptionsDialog", "Analysis: Enabled", nullptr));
        analDescription->setText(QCoreApplication::translate("InitialOptionsDialog", "Level: ", nullptr));
        writeCheckBox->setText(QCoreApplication::translate("InitialOptionsDialog", "Load in write mode (-w)", nullptr));
        binCacheCheckBox->setText(QCoreApplication::translate("InitialOptionsDialog", "Apply relocation patches", nullptr));
        binCheckBox->setText(QCoreApplication::translate("InitialOptionsDialog", "Load debug information (dwarf)", nullptr));
        varCheckBox->setText(QCoreApplication::translate("InitialOptionsDialog", "Local variable analysis", nullptr));
        vaCheckBox->setText(QCoreApplication::translate("InitialOptionsDialog", "Use virtual addressing", nullptr));
        demangleCheckBox->setText(QCoreApplication::translate("InitialOptionsDialog", "Demangle symbol names", nullptr));
        AdvOptButton->setText(QCoreApplication::translate("InitialOptionsDialog", "...", nullptr));
        label_5->setText(QCoreApplication::translate("InitialOptionsDialog", "Advanced options", nullptr));
        label_2->setText(QCoreApplication::translate("InitialOptionsDialog", "CPU options", nullptr));
        archLabel->setText(QCoreApplication::translate("InitialOptionsDialog", "Architecture:", nullptr));
        archComboBox->setItemText(0, QCoreApplication::translate("InitialOptionsDialog", "Auto", nullptr));

        cpuLabel->setText(QCoreApplication::translate("InitialOptionsDialog", "CPU:", nullptr));
        cpuComboBox->setItemText(0, QString());

        bitsComboBox->setItemText(0, QCoreApplication::translate("InitialOptionsDialog", "Auto", nullptr));
        bitsComboBox->setItemText(1, QCoreApplication::translate("InitialOptionsDialog", "8", nullptr));
        bitsComboBox->setItemText(2, QCoreApplication::translate("InitialOptionsDialog", "16", nullptr));
        bitsComboBox->setItemText(3, QCoreApplication::translate("InitialOptionsDialog", "32", nullptr));
        bitsComboBox->setItemText(4, QCoreApplication::translate("InitialOptionsDialog", "64", nullptr));

        endiannessLabel->setText(QCoreApplication::translate("InitialOptionsDialog", "Endianness: ", nullptr));
        endiannessComboBox->setItemText(0, QCoreApplication::translate("InitialOptionsDialog", "Auto", nullptr));
        endiannessComboBox->setItemText(1, QCoreApplication::translate("InitialOptionsDialog", "Little", nullptr));
        endiannessComboBox->setItemText(2, QCoreApplication::translate("InitialOptionsDialog", "Big", nullptr));

        kernelLabel->setText(QCoreApplication::translate("InitialOptionsDialog", "Kernel: ", nullptr));
        kernelComboBox->setItemText(0, QCoreApplication::translate("InitialOptionsDialog", "Auto", nullptr));

        formatLabel->setText(QCoreApplication::translate("InitialOptionsDialog", "Format:", nullptr));
        formatComboBox->setItemText(0, QCoreApplication::translate("InitialOptionsDialog", "Auto", nullptr));

        offsetLabel->setText(QCoreApplication::translate("InitialOptionsDialog", "Load bin offset (-B)", nullptr));
        entry_loadOffset->setPlaceholderText(QCoreApplication::translate("InitialOptionsDialog", "1024", nullptr));
        mapLabel->setText(QCoreApplication::translate("InitialOptionsDialog", "Map offset (-m)", nullptr));
        entry_mapOffset->setText(QString());
        entry_mapOffset->setPlaceholderText(QCoreApplication::translate("InitialOptionsDialog", "0x40000", nullptr));
        pdbCheckBox->setText(QCoreApplication::translate("InitialOptionsDialog", "Load PDB", nullptr));
        pdbLineEdit->setPlaceholderText(QCoreApplication::translate("InitialOptionsDialog", "PDB File path", nullptr));
        pdbSelectButton->setText(QCoreApplication::translate("InitialOptionsDialog", "Select", nullptr));
        scriptCheckBox->setText(QCoreApplication::translate("InitialOptionsDialog", "Load script file", nullptr));
        scriptLineEdit->setPlaceholderText(QCoreApplication::translate("InitialOptionsDialog", "Path to radare2 script file", nullptr));
        scriptSelectButton->setText(QCoreApplication::translate("InitialOptionsDialog", "Select", nullptr));
        cancelButton->setText(QCoreApplication::translate("InitialOptionsDialog", "Cancel", nullptr));
        okButton->setText(QCoreApplication::translate("InitialOptionsDialog", "  Ok  ", nullptr));
    } // retranslateUi

};

namespace Ui {
    class InitialOptionsDialog: public Ui_InitialOptionsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_INITIALOPTIONSDIALOG_H
