/****************************************************************************
** Meta object code from reading C++ file 'NewFileDialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/dialogs/NewFileDialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'NewFileDialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13NewFileDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto NewFileDialog::qt_create_metaobjectdata<qt_meta_tag_ZN13NewFileDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NewFileDialog",
        "on_loadFileButton_clicked",
        "",
        "on_checkBox_FilelessOpen_clicked",
        "on_selectFileButton_clicked",
        "on_newFileEdit_textChanged",
        "text",
        "on_selectProjectsDirButton_clicked",
        "on_loadProjectButton_clicked",
        "on_shellcodeButton_clicked",
        "on_shellcodeText_textChanged",
        "on_logoSvgWidget_clicked",
        "on_recentsListWidget_itemClicked",
        "QListWidgetItem*",
        "item",
        "on_recentsListWidget_itemDoubleClicked",
        "on_projectsListWidget_itemSelectionChanged",
        "on_projectsListWidget_itemDoubleClicked",
        "on_actionRemove_item_triggered",
        "on_actionClear_all_triggered",
        "on_actionRemove_project_triggered",
        "on_importProjectButton_clicked",
        "on_exportProjectButton_clicked",
        "on_tabWidget_currentChanged",
        "index",
        "on_sha256ScanButton_clicked",
        "on_sha256OpenButton_clicked",
        "on_sha256DeleteButton_clicked",
        "on_sha256LookupButton_clicked",
        "on_sha256TableView_doubleClicked",
        "QModelIndex",
        "on_sha256TableView_customContextMenuRequested",
        "QPoint",
        "pos",
        "on_attachButton_clicked",
        "on_attachProcView_doubleClicked",
        "on_refreshProcessesButton_clicked"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'on_loadFileButton_clicked'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_checkBox_FilelessOpen_clicked'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_selectFileButton_clicked'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_newFileEdit_textChanged'
        QtMocHelpers::SlotData<void(const QString &)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'on_selectProjectsDirButton_clicked'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_loadProjectButton_clicked'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_shellcodeButton_clicked'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_shellcodeText_textChanged'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_logoSvgWidget_clicked'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_recentsListWidget_itemClicked'
        QtMocHelpers::SlotData<void(QListWidgetItem *)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'on_recentsListWidget_itemDoubleClicked'
        QtMocHelpers::SlotData<void(QListWidgetItem *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'on_projectsListWidget_itemSelectionChanged'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_projectsListWidget_itemDoubleClicked'
        QtMocHelpers::SlotData<void(QListWidgetItem *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'on_actionRemove_item_triggered'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionClear_all_triggered'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionRemove_project_triggered'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_importProjectButton_clicked'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_exportProjectButton_clicked'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_tabWidget_currentChanged'
        QtMocHelpers::SlotData<void(int)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'on_sha256ScanButton_clicked'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_sha256OpenButton_clicked'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_sha256DeleteButton_clicked'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_sha256LookupButton_clicked'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_sha256TableView_doubleClicked'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 24 },
        }}),
        // Slot 'on_sha256TableView_customContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'on_attachButton_clicked'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_attachProcView_doubleClicked'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 24 },
        }}),
        // Slot 'on_refreshProcessesButton_clicked'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NewFileDialog, qt_meta_tag_ZN13NewFileDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject NewFileDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13NewFileDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13NewFileDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13NewFileDialogE_t>.metaTypes,
    nullptr
} };

void NewFileDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NewFileDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->on_loadFileButton_clicked(); break;
        case 1: _t->on_checkBox_FilelessOpen_clicked(); break;
        case 2: _t->on_selectFileButton_clicked(); break;
        case 3: _t->on_newFileEdit_textChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->on_selectProjectsDirButton_clicked(); break;
        case 5: _t->on_loadProjectButton_clicked(); break;
        case 6: _t->on_shellcodeButton_clicked(); break;
        case 7: _t->on_shellcodeText_textChanged(); break;
        case 8: _t->on_logoSvgWidget_clicked(); break;
        case 9: _t->on_recentsListWidget_itemClicked((*reinterpret_cast<std::add_pointer_t<QListWidgetItem*>>(_a[1]))); break;
        case 10: _t->on_recentsListWidget_itemDoubleClicked((*reinterpret_cast<std::add_pointer_t<QListWidgetItem*>>(_a[1]))); break;
        case 11: _t->on_projectsListWidget_itemSelectionChanged(); break;
        case 12: _t->on_projectsListWidget_itemDoubleClicked((*reinterpret_cast<std::add_pointer_t<QListWidgetItem*>>(_a[1]))); break;
        case 13: _t->on_actionRemove_item_triggered(); break;
        case 14: _t->on_actionClear_all_triggered(); break;
        case 15: _t->on_actionRemove_project_triggered(); break;
        case 16: _t->on_importProjectButton_clicked(); break;
        case 17: _t->on_exportProjectButton_clicked(); break;
        case 18: _t->on_tabWidget_currentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->on_sha256ScanButton_clicked(); break;
        case 20: _t->on_sha256OpenButton_clicked(); break;
        case 21: _t->on_sha256DeleteButton_clicked(); break;
        case 22: _t->on_sha256LookupButton_clicked(); break;
        case 23: _t->on_sha256TableView_doubleClicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 24: _t->on_sha256TableView_customContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 25: _t->on_attachButton_clicked(); break;
        case 26: _t->on_attachProcView_doubleClicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 27: _t->on_refreshProcessesButton_clicked(); break;
        default: ;
        }
    }
}

const QMetaObject *NewFileDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NewFileDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13NewFileDialogE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int NewFileDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 28;
    }
    return _id;
}
QT_WARNING_POP
