/****************************************************************************
** Meta object code from reading C++ file 'Iaito.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/core/Iaito.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Iaito.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9IaitoCoreE_t {};
} // unnamed namespace

template <> constexpr inline auto IaitoCore::qt_create_metaobjectdata<qt_meta_tag_ZN9IaitoCoreE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IaitoCore",
        "refreshAll",
        "",
        "functionRenamed",
        "RVA",
        "offset",
        "new_name",
        "varsChanged",
        "functionsChanged",
        "flagsChanged",
        "commentsChanged",
        "addr",
        "registersChanged",
        "instructionChanged",
        "breakpointsChanged",
        "refreshCodeViews",
        "stackChanged",
        "codeRebased",
        "switchedThread",
        "switchedProcess",
        "classNew",
        "cls",
        "classDeleted",
        "classRenamed",
        "oldName",
        "newName",
        "classAttrsChanged",
        "debugProcessFinished",
        "pid",
        "attachedRemote",
        "successfully",
        "projectSaved",
        "name",
        "ioCacheChanged",
        "newval",
        "writeModeChanged",
        "ioModeChanged",
        "debugTaskStateChanged",
        "asmOptionsChanged",
        "graphOptionsChanged",
        "seekChanged",
        "addressRangeSelectionChanged",
        "start",
        "end",
        "toggleDebugView",
        "newMessage",
        "msg",
        "newDebugMessage",
        "showMemoryWidgetRequested"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'refreshAll'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'functionRenamed'
        QtMocHelpers::SignalData<void(const RVA, const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'varsChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'functionsChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'flagsChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'commentsChanged'
        QtMocHelpers::SignalData<void(RVA)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 11 },
        }}),
        // Signal 'registersChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'instructionChanged'
        QtMocHelpers::SignalData<void(RVA)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'breakpointsChanged'
        QtMocHelpers::SignalData<void(RVA)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'refreshCodeViews'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stackChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'codeRebased'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'switchedThread'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'switchedProcess'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'classNew'
        QtMocHelpers::SignalData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Signal 'classDeleted'
        QtMocHelpers::SignalData<void(const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Signal 'classRenamed'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 25 },
        }}),
        // Signal 'classAttrsChanged'
        QtMocHelpers::SignalData<void(const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Signal 'debugProcessFinished'
        QtMocHelpers::SignalData<void(int)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Signal 'attachedRemote'
        QtMocHelpers::SignalData<void(bool)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Signal 'projectSaved'
        QtMocHelpers::SignalData<void(bool, const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 }, { QMetaType::QString, 32 },
        }}),
        // Signal 'ioCacheChanged'
        QtMocHelpers::SignalData<void(bool)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 34 },
        }}),
        // Signal 'writeModeChanged'
        QtMocHelpers::SignalData<void(bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 34 },
        }}),
        // Signal 'ioModeChanged'
        QtMocHelpers::SignalData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'debugTaskStateChanged'
        QtMocHelpers::SignalData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'asmOptionsChanged'
        QtMocHelpers::SignalData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'graphOptionsChanged'
        QtMocHelpers::SignalData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seekChanged'
        QtMocHelpers::SignalData<void(RVA)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'addressRangeSelectionChanged'
        QtMocHelpers::SignalData<void(RVA, RVA)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 42 }, { 0x80000000 | 4, 43 },
        }}),
        // Signal 'toggleDebugView'
        QtMocHelpers::SignalData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newMessage'
        QtMocHelpers::SignalData<void(const QString &)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 46 },
        }}),
        // Signal 'newDebugMessage'
        QtMocHelpers::SignalData<void(const QString &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 46 },
        }}),
        // Signal 'showMemoryWidgetRequested'
        QtMocHelpers::SignalData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IaitoCore, qt_meta_tag_ZN9IaitoCoreE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IaitoCore::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9IaitoCoreE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9IaitoCoreE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9IaitoCoreE_t>.metaTypes,
    nullptr
} };

void IaitoCore::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IaitoCore *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->refreshAll(); break;
        case 1: _t->functionRenamed((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->varsChanged(); break;
        case 3: _t->functionsChanged(); break;
        case 4: _t->flagsChanged(); break;
        case 5: _t->commentsChanged((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1]))); break;
        case 6: _t->registersChanged(); break;
        case 7: _t->instructionChanged((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1]))); break;
        case 8: _t->breakpointsChanged((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1]))); break;
        case 9: _t->refreshCodeViews(); break;
        case 10: _t->stackChanged(); break;
        case 11: _t->codeRebased(); break;
        case 12: _t->switchedThread(); break;
        case 13: _t->switchedProcess(); break;
        case 14: _t->classNew((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->classDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->classRenamed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 17: _t->classAttrsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->debugProcessFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->attachedRemote((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->projectSaved((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 21: _t->ioCacheChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->writeModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->ioModeChanged(); break;
        case 24: _t->debugTaskStateChanged(); break;
        case 25: _t->asmOptionsChanged(); break;
        case 26: _t->graphOptionsChanged(); break;
        case 27: _t->seekChanged((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1]))); break;
        case 28: _t->addressRangeSelectionChanged((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<RVA>>(_a[2]))); break;
        case 29: _t->toggleDebugView(); break;
        case 30: _t->newMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: _t->newDebugMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 32: _t->showMemoryWidgetRequested(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)()>(_a, &IaitoCore::refreshAll, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)(const RVA , const QString & )>(_a, &IaitoCore::functionRenamed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)()>(_a, &IaitoCore::varsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)()>(_a, &IaitoCore::functionsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)()>(_a, &IaitoCore::flagsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)(RVA )>(_a, &IaitoCore::commentsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)()>(_a, &IaitoCore::registersChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)(RVA )>(_a, &IaitoCore::instructionChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)(RVA )>(_a, &IaitoCore::breakpointsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)()>(_a, &IaitoCore::refreshCodeViews, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)()>(_a, &IaitoCore::stackChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)()>(_a, &IaitoCore::codeRebased, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)()>(_a, &IaitoCore::switchedThread, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)()>(_a, &IaitoCore::switchedProcess, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)(const QString & )>(_a, &IaitoCore::classNew, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)(const QString & )>(_a, &IaitoCore::classDeleted, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)(const QString & , const QString & )>(_a, &IaitoCore::classRenamed, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)(const QString & )>(_a, &IaitoCore::classAttrsChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)(int )>(_a, &IaitoCore::debugProcessFinished, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)(bool )>(_a, &IaitoCore::attachedRemote, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)(bool , const QString & )>(_a, &IaitoCore::projectSaved, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)(bool )>(_a, &IaitoCore::ioCacheChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)(bool )>(_a, &IaitoCore::writeModeChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)()>(_a, &IaitoCore::ioModeChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)()>(_a, &IaitoCore::debugTaskStateChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)()>(_a, &IaitoCore::asmOptionsChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)()>(_a, &IaitoCore::graphOptionsChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)(RVA )>(_a, &IaitoCore::seekChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)(RVA , RVA )>(_a, &IaitoCore::addressRangeSelectionChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)()>(_a, &IaitoCore::toggleDebugView, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)(const QString & )>(_a, &IaitoCore::newMessage, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)(const QString & )>(_a, &IaitoCore::newDebugMessage, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoCore::*)()>(_a, &IaitoCore::showMemoryWidgetRequested, 32))
            return;
    }
}

const QMetaObject *IaitoCore::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IaitoCore::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9IaitoCoreE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int IaitoCore::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 33;
    }
    return _id;
}

// SIGNAL 0
void IaitoCore::refreshAll()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void IaitoCore::functionRenamed(const RVA _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void IaitoCore::varsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void IaitoCore::functionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void IaitoCore::flagsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void IaitoCore::commentsChanged(RVA _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void IaitoCore::registersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void IaitoCore::instructionChanged(RVA _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void IaitoCore::breakpointsChanged(RVA _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void IaitoCore::refreshCodeViews()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void IaitoCore::stackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void IaitoCore::codeRebased()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void IaitoCore::switchedThread()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void IaitoCore::switchedProcess()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void IaitoCore::classNew(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void IaitoCore::classDeleted(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void IaitoCore::classRenamed(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2);
}

// SIGNAL 17
void IaitoCore::classAttrsChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void IaitoCore::debugProcessFinished(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void IaitoCore::attachedRemote(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void IaitoCore::projectSaved(bool _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1, _t2);
}

// SIGNAL 21
void IaitoCore::ioCacheChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void IaitoCore::writeModeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void IaitoCore::ioModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void IaitoCore::debugTaskStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void IaitoCore::asmOptionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void IaitoCore::graphOptionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void IaitoCore::seekChanged(RVA _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1);
}

// SIGNAL 28
void IaitoCore::addressRangeSelectionChanged(RVA _t1, RVA _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1, _t2);
}

// SIGNAL 29
void IaitoCore::toggleDebugView()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void IaitoCore::newMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 30, nullptr, _t1);
}

// SIGNAL 31
void IaitoCore::newDebugMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 31, nullptr, _t1);
}

// SIGNAL 32
void IaitoCore::showMemoryWidgetRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}
QT_WARNING_POP
