/********************************************************************************
** Form generated from reading UI file 'CommentsDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COMMENTSDIALOG_H
#define UI_COMMENTSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_CommentsDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QPlainTextEdit *textEdit;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CommentsDialog)
    {
        if (CommentsDialog->objectName().isEmpty())
            CommentsDialog->setObjectName("CommentsDialog");
        CommentsDialog->resize(480, 180);
        verticalLayout_2 = new QVBoxLayout(CommentsDialog);
        verticalLayout_2->setSpacing(8);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(12, 12, 12, 12);
        textEdit = new QPlainTextEdit(CommentsDialog);
        textEdit->setObjectName("textEdit");
        textEdit->setMinimumSize(QSize(360, 96));
        textEdit->setTabChangesFocus(true);

        verticalLayout_2->addWidget(textEdit);

        buttonBox = new QDialogButtonBox(CommentsDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(CommentsDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CommentsDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CommentsDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CommentsDialog);
    } // setupUi

    void retranslateUi(QDialog *CommentsDialog)
    {
        CommentsDialog->setWindowTitle(QCoreApplication::translate("CommentsDialog", "Comment", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CommentsDialog: public Ui_CommentsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COMMENTSDIALOG_H
