/****************************************************************************
** Meta object code from reading C++ file 'IaitoGraphView.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/widgets/IaitoGraphView.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'IaitoGraphView.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14IaitoGraphViewE_t {};
} // unnamed namespace

template <> constexpr inline auto IaitoGraphView::qt_create_metaobjectdata<qt_meta_tag_ZN14IaitoGraphViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IaitoGraphView",
        "viewRefreshed",
        "",
        "viewZoomed",
        "graphMoved",
        "resized",
        "refreshView",
        "updateColors",
        "fontsUpdatedSlot",
        "zoom",
        "QPointF",
        "mouseRelativePos",
        "velocity",
        "setZoom",
        "scale",
        "zoomIn",
        "zoomOut",
        "zoomReset",
        "showExportDialog"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'viewRefreshed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'viewZoomed'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'graphMoved'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resized'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refreshView'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateColors'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fontsUpdatedSlot'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoom'
        QtMocHelpers::SlotData<void(QPointF, double)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { QMetaType::Double, 12 },
        }}),
        // Slot 'setZoom'
        QtMocHelpers::SlotData<void(QPointF, double)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { QMetaType::Double, 14 },
        }}),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomReset'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showExportDialog'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IaitoGraphView, qt_meta_tag_ZN14IaitoGraphViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IaitoGraphView::staticMetaObject = { {
    QMetaObject::SuperData::link<GraphView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14IaitoGraphViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14IaitoGraphViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14IaitoGraphViewE_t>.metaTypes,
    nullptr
} };

void IaitoGraphView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IaitoGraphView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->viewRefreshed(); break;
        case 1: _t->viewZoomed(); break;
        case 2: _t->graphMoved(); break;
        case 3: _t->resized(); break;
        case 4: _t->refreshView(); break;
        case 5: _t->updateColors(); break;
        case 6: _t->fontsUpdatedSlot(); break;
        case 7: _t->zoom((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 8: _t->setZoom((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 9: _t->zoomIn(); break;
        case 10: _t->zoomOut(); break;
        case 11: _t->zoomReset(); break;
        case 12: _t->showExportDialog(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IaitoGraphView::*)()>(_a, &IaitoGraphView::viewRefreshed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoGraphView::*)()>(_a, &IaitoGraphView::viewZoomed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoGraphView::*)()>(_a, &IaitoGraphView::graphMoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IaitoGraphView::*)()>(_a, &IaitoGraphView::resized, 3))
            return;
    }
}

const QMetaObject *IaitoGraphView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IaitoGraphView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14IaitoGraphViewE_t>.strings))
        return static_cast<void*>(this);
    return GraphView::qt_metacast(_clname);
}

int IaitoGraphView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GraphView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void IaitoGraphView::viewRefreshed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void IaitoGraphView::viewZoomed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void IaitoGraphView::graphMoved()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void IaitoGraphView::resized()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
