/****************************************************************************
** Meta object code from reading C++ file 'HexdumpWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/widgets/HexdumpWidget.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'HexdumpWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13HexdumpWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto HexdumpWidget::qt_create_metaobjectdata<qt_meta_tag_ZN13HexdumpWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "HexdumpWidget",
        "initParsing",
        "",
        "onSeekChanged",
        "RVA",
        "addr",
        "onHexSelectionChanged",
        "HexWidget::Selection",
        "selection",
        "selectionChanged",
        "applyAddressRangeSelection",
        "start",
        "end",
        "on_parseArchComboBox_currentTextChanged",
        "arg1",
        "on_parseBitsComboBox_currentTextChanged",
        "on_parseTypeComboBox_currentTextChanged",
        "on_parseEndianComboBox_currentTextChanged",
        "on_valueEndian_currentIndexChanged",
        "index",
        "fontsUpdated",
        "on_hexSideTab_2_currentChanged",
        "on_copyMD5_clicked",
        "on_copySHA1_clicked",
        "on_copySHA256_clicked",
        "on_copyCRC32_clicked"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'initParsing'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onSeekChanged'
        QtMocHelpers::SlotData<void(RVA)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'onHexSelectionChanged'
        QtMocHelpers::SlotData<void(HexWidget::Selection)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void(HexWidget::Selection)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'applyAddressRangeSelection'
        QtMocHelpers::SlotData<void(RVA, RVA)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 11 }, { 0x80000000 | 4, 12 },
        }}),
        // Slot 'on_parseArchComboBox_currentTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'on_parseBitsComboBox_currentTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'on_parseTypeComboBox_currentTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'on_parseEndianComboBox_currentTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'on_valueEndian_currentIndexChanged'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'fontsUpdated'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_hexSideTab_2_currentChanged'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'on_copyMD5_clicked'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_copySHA1_clicked'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_copySHA256_clicked'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_copyCRC32_clicked'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HexdumpWidget, qt_meta_tag_ZN13HexdumpWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject HexdumpWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<MemoryDockWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13HexdumpWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13HexdumpWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13HexdumpWidgetE_t>.metaTypes,
    nullptr
} };

void HexdumpWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HexdumpWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->initParsing(); break;
        case 1: _t->onSeekChanged((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1]))); break;
        case 2: _t->onHexSelectionChanged((*reinterpret_cast<std::add_pointer_t<HexWidget::Selection>>(_a[1]))); break;
        case 3: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<HexWidget::Selection>>(_a[1]))); break;
        case 4: _t->applyAddressRangeSelection((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<RVA>>(_a[2]))); break;
        case 5: _t->on_parseArchComboBox_currentTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->on_parseBitsComboBox_currentTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->on_parseTypeComboBox_currentTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->on_parseEndianComboBox_currentTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->on_valueEndian_currentIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->fontsUpdated(); break;
        case 11: _t->on_hexSideTab_2_currentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->on_copyMD5_clicked(); break;
        case 13: _t->on_copySHA1_clicked(); break;
        case 14: _t->on_copySHA256_clicked(); break;
        case 15: _t->on_copyCRC32_clicked(); break;
        default: ;
        }
    }
}

const QMetaObject *HexdumpWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HexdumpWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13HexdumpWidgetE_t>.strings))
        return static_cast<void*>(this);
    return MemoryDockWidget::qt_metacast(_clname);
}

int HexdumpWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MemoryDockWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}
QT_WARNING_POP
