/********************************************************************************
** Form generated from reading UI file 'AsmOptionsWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ASMOPTIONSWIDGET_H
#define UI_ASMOPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_AsmOptionsWidget
{
public:
    QAction *actionSaveAsDefault;
    QVBoxLayout *verticalLayout;
    QTabWidget *asmOptionsTab;
    QWidget *asmStyleTab;
    QVBoxLayout *verticalLayout_4;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_2;
    QGroupBox *disassemblyGroupBox;
    QGridLayout *gridLayout;
    QLabel *label;
    QComboBox *asmComboBox;
    QLabel *syntaxLabel;
    QComboBox *syntaxComboBox;
    QLabel *caseLabel;
    QComboBox *caseComboBox;
    QCheckBox *offsetCheckBox;
    QHBoxLayout *addrBaseLayout;
    QLabel *addrBaseLabel;
    QComboBox *addrBaseComboBox;
    QLabel *relOffsetLabel;
    QHBoxLayout *horizontalLayout;
    QCheckBox *relOffsetCheckBox;
    QCheckBox *relOffFlagsCheckBox;
    QComboBox *relToComboBox;
    QCheckBox *bytesCheckBox;
    QLabel *nbytesLabel;
    QSpinBox *nbytesSpinBox;
    QCheckBox *realnameCheckBox;
    QCheckBox *bblineCheckBox;
    QLabel *asmTabsLabel;
    QSpinBox *asmTabsSpinBox;
    QLabel *asmTabsOffLabel;
    QSpinBox *asmTabsOffSpinBox;
    QCheckBox *indentCheckBox;
    QCheckBox *lbytesCheckBox;
    QCheckBox *bytespaceCheckBox;
    QGroupBox *commentsGroupBox;
    QGridLayout *gridLayout_5;
    QLabel *label_2;
    QComboBox *commentsComboBox;
    QCheckBox *describeCheckBox;
    QCheckBox *xrefCheckBox;
    QCheckBox *refptrCheckBox;
    QLabel *cmtcolLabel;
    QSpinBox *cmtcolSpinBox;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout_5;
    QCheckBox *slowCheckBox;
    QCheckBox *linesCheckBox;
    QCheckBox *fcnlinesCheckBox;
    QCheckBox *flgoffCheckBox;
    QCheckBox *emuCheckBox;
    QCheckBox *emuStrCheckBox;
    QCheckBox *sizeCheckBox;
    QCheckBox *varsumCheckBox;
    QCheckBox *varsubCheckBox;
    QCheckBox *varsubOnlyCheckBox;
    QSpacerItem *verticalSpacer_4;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *AsmOptionsWidget)
    {
        if (AsmOptionsWidget->objectName().isEmpty())
            AsmOptionsWidget->setObjectName("AsmOptionsWidget");
        actionSaveAsDefault = new QAction(AsmOptionsWidget);
        actionSaveAsDefault->setObjectName("actionSaveAsDefault");
        verticalLayout = new QVBoxLayout(AsmOptionsWidget);
        verticalLayout->setObjectName("verticalLayout");
        asmOptionsTab = new QTabWidget(AsmOptionsWidget);
        asmOptionsTab->setObjectName("asmOptionsTab");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(asmOptionsTab->sizePolicy().hasHeightForWidth());
        asmOptionsTab->setSizePolicy(sizePolicy);
        asmStyleTab = new QWidget();
        asmStyleTab->setObjectName("asmStyleTab");
        verticalLayout_4 = new QVBoxLayout(asmStyleTab);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(2, 2, 2, 2);
        scrollArea = new QScrollArea(asmStyleTab);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setFrameShape(QFrame::NoFrame);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        verticalLayout_2 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(2, 2, 2, 2);
        disassemblyGroupBox = new QGroupBox(scrollAreaWidgetContents);
        disassemblyGroupBox->setObjectName("disassemblyGroupBox");
        disassemblyGroupBox->setFlat(true);
        gridLayout = new QGridLayout(disassemblyGroupBox);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(disassemblyGroupBox);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        asmComboBox = new QComboBox(disassemblyGroupBox);
        asmComboBox->addItem(QString());
        asmComboBox->addItem(QString());
        asmComboBox->addItem(QString());
        asmComboBox->setObjectName("asmComboBox");

        gridLayout->addWidget(asmComboBox, 0, 1, 1, 1);

        syntaxLabel = new QLabel(disassemblyGroupBox);
        syntaxLabel->setObjectName("syntaxLabel");

        gridLayout->addWidget(syntaxLabel, 1, 0, 1, 1);

        syntaxComboBox = new QComboBox(disassemblyGroupBox);
        syntaxComboBox->setObjectName("syntaxComboBox");

        gridLayout->addWidget(syntaxComboBox, 1, 1, 1, 1);

        caseLabel = new QLabel(disassemblyGroupBox);
        caseLabel->setObjectName("caseLabel");

        gridLayout->addWidget(caseLabel, 2, 0, 1, 1);

        caseComboBox = new QComboBox(disassemblyGroupBox);
        caseComboBox->addItem(QString());
        caseComboBox->addItem(QString());
        caseComboBox->addItem(QString());
        caseComboBox->setObjectName("caseComboBox");

        gridLayout->addWidget(caseComboBox, 2, 1, 1, 1);

        offsetCheckBox = new QCheckBox(disassemblyGroupBox);
        offsetCheckBox->setObjectName("offsetCheckBox");

        gridLayout->addWidget(offsetCheckBox, 3, 0, 1, 1);

        addrBaseLayout = new QHBoxLayout();
        addrBaseLayout->setObjectName("addrBaseLayout");
        addrBaseLabel = new QLabel(disassemblyGroupBox);
        addrBaseLabel->setObjectName("addrBaseLabel");

        addrBaseLayout->addWidget(addrBaseLabel);

        addrBaseComboBox = new QComboBox(disassemblyGroupBox);
        addrBaseComboBox->setObjectName("addrBaseComboBox");

        addrBaseLayout->addWidget(addrBaseComboBox);


        gridLayout->addLayout(addrBaseLayout, 3, 1, 1, 1);

        relOffsetLabel = new QLabel(disassemblyGroupBox);
        relOffsetLabel->setObjectName("relOffsetLabel");

        gridLayout->addWidget(relOffsetLabel, 4, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        relOffsetCheckBox = new QCheckBox(disassemblyGroupBox);
        relOffsetCheckBox->setObjectName("relOffsetCheckBox");

        horizontalLayout->addWidget(relOffsetCheckBox);

        relOffFlagsCheckBox = new QCheckBox(disassemblyGroupBox);
        relOffFlagsCheckBox->setObjectName("relOffFlagsCheckBox");

        horizontalLayout->addWidget(relOffFlagsCheckBox);

        relToComboBox = new QComboBox(disassemblyGroupBox);
        relToComboBox->setObjectName("relToComboBox");
        relToComboBox->setEditable(true);

        horizontalLayout->addWidget(relToComboBox);


        gridLayout->addLayout(horizontalLayout, 4, 1, 1, 1);

        bytesCheckBox = new QCheckBox(disassemblyGroupBox);
        bytesCheckBox->setObjectName("bytesCheckBox");

        gridLayout->addWidget(bytesCheckBox, 5, 0, 1, 1);

        nbytesLabel = new QLabel(disassemblyGroupBox);
        nbytesLabel->setObjectName("nbytesLabel");

        gridLayout->addWidget(nbytesLabel, 6, 0, 1, 1);

        nbytesSpinBox = new QSpinBox(disassemblyGroupBox);
        nbytesSpinBox->setObjectName("nbytesSpinBox");

        gridLayout->addWidget(nbytesSpinBox, 6, 1, 1, 1);

        realnameCheckBox = new QCheckBox(disassemblyGroupBox);
        realnameCheckBox->setObjectName("realnameCheckBox");

        gridLayout->addWidget(realnameCheckBox, 7, 0, 1, 1);

        bblineCheckBox = new QCheckBox(disassemblyGroupBox);
        bblineCheckBox->setObjectName("bblineCheckBox");

        gridLayout->addWidget(bblineCheckBox, 8, 0, 1, 1);

        asmTabsLabel = new QLabel(disassemblyGroupBox);
        asmTabsLabel->setObjectName("asmTabsLabel");

        gridLayout->addWidget(asmTabsLabel, 9, 0, 1, 1);

        asmTabsSpinBox = new QSpinBox(disassemblyGroupBox);
        asmTabsSpinBox->setObjectName("asmTabsSpinBox");
        asmTabsSpinBox->setMaximum(100);
        asmTabsSpinBox->setSingleStep(5);

        gridLayout->addWidget(asmTabsSpinBox, 9, 1, 1, 1);

        asmTabsOffLabel = new QLabel(disassemblyGroupBox);
        asmTabsOffLabel->setObjectName("asmTabsOffLabel");

        gridLayout->addWidget(asmTabsOffLabel, 10, 0, 1, 1);

        asmTabsOffSpinBox = new QSpinBox(disassemblyGroupBox);
        asmTabsOffSpinBox->setObjectName("asmTabsOffSpinBox");
        asmTabsOffSpinBox->setMaximum(100);
        asmTabsOffSpinBox->setSingleStep(5);

        gridLayout->addWidget(asmTabsOffSpinBox, 10, 1, 1, 1);

        indentCheckBox = new QCheckBox(disassemblyGroupBox);
        indentCheckBox->setObjectName("indentCheckBox");

        gridLayout->addWidget(indentCheckBox, 11, 0, 1, 1);

        lbytesCheckBox = new QCheckBox(disassemblyGroupBox);
        lbytesCheckBox->setObjectName("lbytesCheckBox");

        gridLayout->addWidget(lbytesCheckBox, 12, 0, 1, 1);

        bytespaceCheckBox = new QCheckBox(disassemblyGroupBox);
        bytespaceCheckBox->setObjectName("bytespaceCheckBox");

        gridLayout->addWidget(bytespaceCheckBox, 13, 0, 1, 1);


        verticalLayout_2->addWidget(disassemblyGroupBox);

        commentsGroupBox = new QGroupBox(scrollAreaWidgetContents);
        commentsGroupBox->setObjectName("commentsGroupBox");
        commentsGroupBox->setFlat(true);
        gridLayout_5 = new QGridLayout(commentsGroupBox);
        gridLayout_5->setObjectName("gridLayout_5");
        label_2 = new QLabel(commentsGroupBox);
        label_2->setObjectName("label_2");

        gridLayout_5->addWidget(label_2, 0, 0, 1, 1);

        commentsComboBox = new QComboBox(commentsGroupBox);
        commentsComboBox->addItem(QString());
        commentsComboBox->addItem(QString());
        commentsComboBox->addItem(QString());
        commentsComboBox->setObjectName("commentsComboBox");

        gridLayout_5->addWidget(commentsComboBox, 0, 1, 1, 1);

        describeCheckBox = new QCheckBox(commentsGroupBox);
        describeCheckBox->setObjectName("describeCheckBox");

        gridLayout_5->addWidget(describeCheckBox, 1, 0, 1, 1);

        xrefCheckBox = new QCheckBox(commentsGroupBox);
        xrefCheckBox->setObjectName("xrefCheckBox");

        gridLayout_5->addWidget(xrefCheckBox, 2, 0, 1, 1);

        refptrCheckBox = new QCheckBox(commentsGroupBox);
        refptrCheckBox->setObjectName("refptrCheckBox");

        gridLayout_5->addWidget(refptrCheckBox, 3, 0, 1, 1);

        cmtcolLabel = new QLabel(commentsGroupBox);
        cmtcolLabel->setObjectName("cmtcolLabel");

        gridLayout_5->addWidget(cmtcolLabel, 4, 0, 1, 1);

        cmtcolSpinBox = new QSpinBox(commentsGroupBox);
        cmtcolSpinBox->setObjectName("cmtcolSpinBox");
        cmtcolSpinBox->setMaximum(100);
        cmtcolSpinBox->setSingleStep(5);

        gridLayout_5->addWidget(cmtcolSpinBox, 4, 1, 1, 1);


        verticalLayout_2->addWidget(commentsGroupBox);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_4->addWidget(scrollArea);

        asmOptionsTab->addTab(asmStyleTab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        verticalLayout_5 = new QVBoxLayout(tab_2);
        verticalLayout_5->setObjectName("verticalLayout_5");
        slowCheckBox = new QCheckBox(tab_2);
        slowCheckBox->setObjectName("slowCheckBox");

        verticalLayout_5->addWidget(slowCheckBox);

        linesCheckBox = new QCheckBox(tab_2);
        linesCheckBox->setObjectName("linesCheckBox");

        verticalLayout_5->addWidget(linesCheckBox);

        fcnlinesCheckBox = new QCheckBox(tab_2);
        fcnlinesCheckBox->setObjectName("fcnlinesCheckBox");

        verticalLayout_5->addWidget(fcnlinesCheckBox);

        flgoffCheckBox = new QCheckBox(tab_2);
        flgoffCheckBox->setObjectName("flgoffCheckBox");

        verticalLayout_5->addWidget(flgoffCheckBox);

        emuCheckBox = new QCheckBox(tab_2);
        emuCheckBox->setObjectName("emuCheckBox");

        verticalLayout_5->addWidget(emuCheckBox);

        emuStrCheckBox = new QCheckBox(tab_2);
        emuStrCheckBox->setObjectName("emuStrCheckBox");

        verticalLayout_5->addWidget(emuStrCheckBox);

        sizeCheckBox = new QCheckBox(tab_2);
        sizeCheckBox->setObjectName("sizeCheckBox");

        verticalLayout_5->addWidget(sizeCheckBox);

        varsumCheckBox = new QCheckBox(tab_2);
        varsumCheckBox->setObjectName("varsumCheckBox");

        verticalLayout_5->addWidget(varsumCheckBox);

        varsubCheckBox = new QCheckBox(tab_2);
        varsubCheckBox->setObjectName("varsubCheckBox");

        verticalLayout_5->addWidget(varsubCheckBox);

        varsubOnlyCheckBox = new QCheckBox(tab_2);
        varsubOnlyCheckBox->setObjectName("varsubOnlyCheckBox");

        verticalLayout_5->addWidget(varsubOnlyCheckBox);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_4);

        asmOptionsTab->addTab(tab_2, QString());

        verticalLayout->addWidget(asmOptionsTab);

        buttonBox = new QDialogButtonBox(AsmOptionsWidget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::RestoreDefaults);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(AsmOptionsWidget);

        asmOptionsTab->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(AsmOptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *AsmOptionsWidget)
    {
        AsmOptionsWidget->setWindowTitle(QCoreApplication::translate("AsmOptionsWidget", "Disassembly", nullptr));
        actionSaveAsDefault->setText(QCoreApplication::translate("AsmOptionsWidget", "Save as Default", nullptr));
        disassemblyGroupBox->setTitle(QCoreApplication::translate("AsmOptionsWidget", "Disassembly", nullptr));
        label->setText(QCoreApplication::translate("AsmOptionsWidget", "Disassembly:", nullptr));
        asmComboBox->setItemText(0, QCoreApplication::translate("AsmOptionsWidget", "Normal", nullptr));
        asmComboBox->setItemText(1, QCoreApplication::translate("AsmOptionsWidget", "ESIL", nullptr));
        asmComboBox->setItemText(2, QCoreApplication::translate("AsmOptionsWidget", "Pseudocode", nullptr));

        syntaxLabel->setText(QCoreApplication::translate("AsmOptionsWidget", "Syntax:", nullptr));
#if QT_CONFIG(tooltip)
        syntaxLabel->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.syntax", nullptr));
#endif // QT_CONFIG(tooltip)
        caseLabel->setText(QCoreApplication::translate("AsmOptionsWidget", "Case:", nullptr));
        caseComboBox->setItemText(0, QCoreApplication::translate("AsmOptionsWidget", "Lowercase", nullptr));
        caseComboBox->setItemText(1, QCoreApplication::translate("AsmOptionsWidget", "Uppercase", nullptr));
        caseComboBox->setItemText(2, QCoreApplication::translate("AsmOptionsWidget", "Capitalize", nullptr));

        offsetCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Show addresses", nullptr));
#if QT_CONFIG(tooltip)
        offsetCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.addr", nullptr));
#endif // QT_CONFIG(tooltip)
        addrBaseLabel->setText(QCoreApplication::translate("AsmOptionsWidget", "Address base:", nullptr));
#if QT_CONFIG(tooltip)
        addrBaseLabel->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.addr.base", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        addrBaseComboBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.addr.base", nullptr));
#endif // QT_CONFIG(tooltip)
        relOffsetLabel->setText(QCoreApplication::translate("AsmOptionsWidget", "Relative offsets:", nullptr));
        relOffsetCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Functions", nullptr));
#if QT_CONFIG(tooltip)
        relOffsetCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.reloff", nullptr));
#endif // QT_CONFIG(tooltip)
        relOffFlagsCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Flags", nullptr));
#if QT_CONFIG(tooltip)
        relOffFlagsCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.reloff.flags", nullptr));
#endif // QT_CONFIG(tooltip)
        bytesCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Show instruction bytes", nullptr));
#if QT_CONFIG(tooltip)
        bytesCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.bytes", nullptr));
#endif // QT_CONFIG(tooltip)
        nbytesLabel->setText(QCoreApplication::translate("AsmOptionsWidget", "Bytes to show:", nullptr));
#if QT_CONFIG(tooltip)
        nbytesLabel->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.nbytes", nullptr));
#endif // QT_CONFIG(tooltip)
        realnameCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Show real flag names", nullptr));
#if QT_CONFIG(tooltip)
        realnameCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.flags.real", nullptr));
#endif // QT_CONFIG(tooltip)
        bblineCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Empty line after basic blocks", nullptr));
#if QT_CONFIG(tooltip)
        bblineCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.lines.bb", nullptr));
#endif // QT_CONFIG(tooltip)
        asmTabsLabel->setText(QCoreApplication::translate("AsmOptionsWidget", "Assembly tabs:", nullptr));
#if QT_CONFIG(tooltip)
        asmTabsLabel->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.tabs", nullptr));
#endif // QT_CONFIG(tooltip)
        asmTabsOffLabel->setText(QCoreApplication::translate("AsmOptionsWidget", "Pre-assembly tabs:", nullptr));
#if QT_CONFIG(tooltip)
        asmTabsOffLabel->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.tabs.off", nullptr));
#endif // QT_CONFIG(tooltip)
        indentCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Indent by refline depth", nullptr));
#if QT_CONFIG(tooltip)
        indentCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.indent", nullptr));
#endif // QT_CONFIG(tooltip)
        lbytesCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Left-align bytes", nullptr));
#if QT_CONFIG(tooltip)
        lbytesCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.lbytes", nullptr));
#endif // QT_CONFIG(tooltip)
        bytespaceCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Space between bytes", nullptr));
#if QT_CONFIG(tooltip)
        bytespaceCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.bytes.space", nullptr));
#endif // QT_CONFIG(tooltip)
        commentsGroupBox->setTitle(QCoreApplication::translate("AsmOptionsWidget", "Comments", nullptr));
        label_2->setText(QCoreApplication::translate("AsmOptionsWidget", "Comments:", nullptr));
        commentsComboBox->setItemText(0, QCoreApplication::translate("AsmOptionsWidget", "Normal", nullptr));
        commentsComboBox->setItemText(1, QCoreApplication::translate("AsmOptionsWidget", "Above instructions", nullptr));
        commentsComboBox->setItemText(2, QCoreApplication::translate("AsmOptionsWidget", "Off", nullptr));

        describeCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Opcode description", nullptr));
#if QT_CONFIG(tooltip)
        describeCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.describe", nullptr));
#endif // QT_CONFIG(tooltip)
        xrefCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Show x-refs", nullptr));
#if QT_CONFIG(tooltip)
        xrefCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.xrefs", nullptr));
#endif // QT_CONFIG(tooltip)
        refptrCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Show pointer refs", nullptr));
#if QT_CONFIG(tooltip)
        refptrCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.refptr", nullptr));
#endif // QT_CONFIG(tooltip)
        cmtcolLabel->setText(QCoreApplication::translate("AsmOptionsWidget", "Comment column:", nullptr));
#if QT_CONFIG(tooltip)
        cmtcolLabel->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.cmt.col", nullptr));
#endif // QT_CONFIG(tooltip)
        asmOptionsTab->setTabText(asmOptionsTab->indexOf(asmStyleTab), QCoreApplication::translate("AsmOptionsWidget", "Style", nullptr));
        slowCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Slow analysis", nullptr));
#if QT_CONFIG(tooltip)
        slowCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.slow", nullptr));
#endif // QT_CONFIG(tooltip)
        linesCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Show jump lines", nullptr));
#if QT_CONFIG(tooltip)
        linesCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.lines", nullptr));
#endif // QT_CONFIG(tooltip)
        fcnlinesCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Function boundary lines", nullptr));
#if QT_CONFIG(tooltip)
        fcnlinesCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.lines.fcn", nullptr));
#endif // QT_CONFIG(tooltip)
        flgoffCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Offset before flags", nullptr));
#if QT_CONFIG(tooltip)
        flgoffCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.flags.off", nullptr));
#endif // QT_CONFIG(tooltip)
        emuCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "ESIL emulation", nullptr));
#if QT_CONFIG(tooltip)
        emuCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.emu", nullptr));
#endif // QT_CONFIG(tooltip)
        emuStrCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Emulation strings only", nullptr));
#if QT_CONFIG(tooltip)
        emuStrCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "emu.str", nullptr));
#endif // QT_CONFIG(tooltip)
        sizeCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Show opcode size", nullptr));
#if QT_CONFIG(tooltip)
        sizeCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.size", nullptr));
#endif // QT_CONFIG(tooltip)
        varsumCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Variables summary", nullptr));
#if QT_CONFIG(tooltip)
        varsumCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.var.summary", nullptr));
#endif // QT_CONFIG(tooltip)
        varsubCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Substitute variables", nullptr));
#if QT_CONFIG(tooltip)
        varsubCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.sub.var", nullptr));
#endif // QT_CONFIG(tooltip)
        varsubOnlyCheckBox->setText(QCoreApplication::translate("AsmOptionsWidget", "Substitute full var expressions", nullptr));
#if QT_CONFIG(tooltip)
        varsubOnlyCheckBox->setToolTip(QCoreApplication::translate("AsmOptionsWidget", "asm.sub.varonly", nullptr));
#endif // QT_CONFIG(tooltip)
        asmOptionsTab->setTabText(asmOptionsTab->indexOf(tab_2), QCoreApplication::translate("AsmOptionsWidget", "Metadata", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AsmOptionsWidget: public Ui_AsmOptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ASMOPTIONSWIDGET_H
