/****************************************************************************
** Meta object code from reading C++ file 'ColorPicker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/widgets/ColorPicker.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ColorPicker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18ColorPickerHelpers23ColorPickWidgetAbstractE_t {};
} // unnamed namespace

template <> constexpr inline auto ColorPickerHelpers::ColorPickWidgetAbstract::qt_create_metaobjectdata<qt_meta_tag_ZN18ColorPickerHelpers23ColorPickWidgetAbstractE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ColorPickerHelpers::ColorPickWidgetAbstract",
        "colorChanged",
        "",
        "QColor",
        "color",
        "setColor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void(const QColor &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'setColor'
        QtMocHelpers::SlotData<void(const QColor &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ColorPickWidgetAbstract, qt_meta_tag_ZN18ColorPickerHelpers23ColorPickWidgetAbstractE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ColorPickerHelpers::ColorPickWidgetAbstract::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColorPickerHelpers23ColorPickWidgetAbstractE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColorPickerHelpers23ColorPickWidgetAbstractE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ColorPickerHelpers23ColorPickWidgetAbstractE_t>.metaTypes,
    nullptr
} };

void ColorPickerHelpers::ColorPickWidgetAbstract::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ColorPickWidgetAbstract *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->colorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 1: _t->setColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ColorPickWidgetAbstract::*)(const QColor & )>(_a, &ColorPickWidgetAbstract::colorChanged, 0))
            return;
    }
}

const QMetaObject *ColorPickerHelpers::ColorPickWidgetAbstract::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ColorPickerHelpers::ColorPickWidgetAbstract::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColorPickerHelpers23ColorPickWidgetAbstractE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int ColorPickerHelpers::ColorPickWidgetAbstract::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void ColorPickerHelpers::ColorPickWidgetAbstract::colorChanged(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN11ColorPickerE_t {};
} // unnamed namespace

template <> constexpr inline auto ColorPicker::qt_create_metaobjectdata<qt_meta_tag_ZN11ColorPickerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ColorPicker",
        "setColor",
        "",
        "QColor",
        "color",
        "colorChannelChanged",
        "updateColor",
        "startPickingFromScreen",
        "stopPickingFromScreen"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setColor'
        QtMocHelpers::SlotData<void(const QColor &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'colorChannelChanged'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateColor'
        QtMocHelpers::SlotData<void(const QColor &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'startPickingFromScreen'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopPickingFromScreen'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ColorPicker, qt_meta_tag_ZN11ColorPickerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ColorPicker::staticMetaObject = { {
    QMetaObject::SuperData::link<ColorPickerHelpers::ColorPickWidgetAbstract::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ColorPickerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ColorPickerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ColorPickerE_t>.metaTypes,
    nullptr
} };

void ColorPicker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ColorPicker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 1: _t->colorChannelChanged(); break;
        case 2: _t->updateColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 3: _t->startPickingFromScreen(); break;
        case 4: _t->stopPickingFromScreen(); break;
        default: ;
        }
    }
}

const QMetaObject *ColorPicker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ColorPicker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ColorPickerE_t>.strings))
        return static_cast<void*>(this);
    return ColorPickerHelpers::ColorPickWidgetAbstract::qt_metacast(_clname);
}

int ColorPicker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ColorPickerHelpers::ColorPickWidgetAbstract::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN18ColorPickerHelpers17ColorPickerWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto ColorPickerHelpers::ColorPickerWidget::qt_create_metaobjectdata<qt_meta_tag_ZN18ColorPickerHelpers17ColorPickerWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ColorPickerHelpers::ColorPickerWidget"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ColorPickerWidget, qt_meta_tag_ZN18ColorPickerHelpers17ColorPickerWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ColorPickerHelpers::ColorPickerWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<ColorPickWidgetAbstract::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColorPickerHelpers17ColorPickerWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColorPickerHelpers17ColorPickerWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ColorPickerHelpers17ColorPickerWidgetE_t>.metaTypes,
    nullptr
} };

void ColorPickerHelpers::ColorPickerWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ColorPickerWidget *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ColorPickerHelpers::ColorPickerWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ColorPickerHelpers::ColorPickerWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColorPickerHelpers17ColorPickerWidgetE_t>.strings))
        return static_cast<void*>(this);
    return ColorPickWidgetAbstract::qt_metacast(_clname);
}

int ColorPickerHelpers::ColorPickerWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ColorPickWidgetAbstract::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN18ColorPickerHelpers15ColorShowWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto ColorPickerHelpers::ColorShowWidget::qt_create_metaobjectdata<qt_meta_tag_ZN18ColorPickerHelpers15ColorShowWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ColorPickerHelpers::ColorShowWidget"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ColorShowWidget, qt_meta_tag_ZN18ColorPickerHelpers15ColorShowWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ColorPickerHelpers::ColorShowWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<ColorPickWidgetAbstract::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColorPickerHelpers15ColorShowWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColorPickerHelpers15ColorShowWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ColorPickerHelpers15ColorShowWidgetE_t>.metaTypes,
    nullptr
} };

void ColorPickerHelpers::ColorShowWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ColorShowWidget *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ColorPickerHelpers::ColorShowWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ColorPickerHelpers::ColorShowWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColorPickerHelpers15ColorShowWidgetE_t>.strings))
        return static_cast<void*>(this);
    return ColorPickWidgetAbstract::qt_metacast(_clname);
}

int ColorPickerHelpers::ColorShowWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ColorPickWidgetAbstract::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN18ColorPickerHelpers13ColorPickAreaE_t {};
} // unnamed namespace

template <> constexpr inline auto ColorPickerHelpers::ColorPickArea::qt_create_metaobjectdata<qt_meta_tag_ZN18ColorPickerHelpers13ColorPickAreaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ColorPickerHelpers::ColorPickArea"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ColorPickArea, qt_meta_tag_ZN18ColorPickerHelpers13ColorPickAreaE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ColorPickerHelpers::ColorPickArea::staticMetaObject = { {
    QMetaObject::SuperData::link<ColorPickerWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColorPickerHelpers13ColorPickAreaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColorPickerHelpers13ColorPickAreaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ColorPickerHelpers13ColorPickAreaE_t>.metaTypes,
    nullptr
} };

void ColorPickerHelpers::ColorPickArea::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ColorPickArea *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ColorPickerHelpers::ColorPickArea::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ColorPickerHelpers::ColorPickArea::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColorPickerHelpers13ColorPickAreaE_t>.strings))
        return static_cast<void*>(this);
    return ColorPickerWidget::qt_metacast(_clname);
}

int ColorPickerHelpers::ColorPickArea::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ColorPickerWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN18ColorPickerHelpers15AlphaChannelBarE_t {};
} // unnamed namespace

template <> constexpr inline auto ColorPickerHelpers::AlphaChannelBar::qt_create_metaobjectdata<qt_meta_tag_ZN18ColorPickerHelpers15AlphaChannelBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ColorPickerHelpers::AlphaChannelBar"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AlphaChannelBar, qt_meta_tag_ZN18ColorPickerHelpers15AlphaChannelBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ColorPickerHelpers::AlphaChannelBar::staticMetaObject = { {
    QMetaObject::SuperData::link<ColorPickerWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColorPickerHelpers15AlphaChannelBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColorPickerHelpers15AlphaChannelBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ColorPickerHelpers15AlphaChannelBarE_t>.metaTypes,
    nullptr
} };

void ColorPickerHelpers::AlphaChannelBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AlphaChannelBar *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ColorPickerHelpers::AlphaChannelBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ColorPickerHelpers::AlphaChannelBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColorPickerHelpers15AlphaChannelBarE_t>.strings))
        return static_cast<void*>(this);
    return ColorPickerWidget::qt_metacast(_clname);
}

int ColorPickerHelpers::AlphaChannelBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ColorPickerWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN18ColorPickerHelpers13ColorValueBarE_t {};
} // unnamed namespace

template <> constexpr inline auto ColorPickerHelpers::ColorValueBar::qt_create_metaobjectdata<qt_meta_tag_ZN18ColorPickerHelpers13ColorValueBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ColorPickerHelpers::ColorValueBar"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ColorValueBar, qt_meta_tag_ZN18ColorPickerHelpers13ColorValueBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ColorPickerHelpers::ColorValueBar::staticMetaObject = { {
    QMetaObject::SuperData::link<ColorPickerWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColorPickerHelpers13ColorValueBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColorPickerHelpers13ColorValueBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ColorPickerHelpers13ColorValueBarE_t>.metaTypes,
    nullptr
} };

void ColorPickerHelpers::ColorValueBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ColorValueBar *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ColorPickerHelpers::ColorValueBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ColorPickerHelpers::ColorValueBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColorPickerHelpers13ColorValueBarE_t>.strings))
        return static_cast<void*>(this);
    return ColorPickerWidget::qt_metacast(_clname);
}

int ColorPickerHelpers::ColorValueBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ColorPickerWidget::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
