/********************************************************************************
** Form generated from reading UI file 'DebugOptionsWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DEBUGOPTIONSWIDGET_H
#define UI_DEBUGOPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_DebugOptionsWidget
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *pluginLabel;
    QComboBox *pluginComboBox;
    QLabel *esilstackAddr;
    QLineEdit *stackAddr;
    QLabel *esilStackSize;
    QLineEdit *stackSize;
    QCheckBox *esilBreakOnInvalid;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *DebugOptionsWidget)
    {
        if (DebugOptionsWidget->objectName().isEmpty())
            DebugOptionsWidget->setObjectName("DebugOptionsWidget");
        verticalLayout = new QVBoxLayout(DebugOptionsWidget);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout->setLabelAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        pluginLabel = new QLabel(DebugOptionsWidget);
        pluginLabel->setObjectName("pluginLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, pluginLabel);

        pluginComboBox = new QComboBox(DebugOptionsWidget);
        pluginComboBox->setObjectName("pluginComboBox");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, pluginComboBox);

        esilstackAddr = new QLabel(DebugOptionsWidget);
        esilstackAddr->setObjectName("esilstackAddr");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, esilstackAddr);

        stackAddr = new QLineEdit(DebugOptionsWidget);
        stackAddr->setObjectName("stackAddr");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(stackAddr->sizePolicy().hasHeightForWidth());
        stackAddr->setSizePolicy(sizePolicy);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, stackAddr);

        esilStackSize = new QLabel(DebugOptionsWidget);
        esilStackSize->setObjectName("esilStackSize");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, esilStackSize);

        stackSize = new QLineEdit(DebugOptionsWidget);
        stackSize->setObjectName("stackSize");
        sizePolicy.setHeightForWidth(stackSize->sizePolicy().hasHeightForWidth());
        stackSize->setSizePolicy(sizePolicy);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, stackSize);

        esilBreakOnInvalid = new QCheckBox(DebugOptionsWidget);
        esilBreakOnInvalid->setObjectName("esilBreakOnInvalid");

        formLayout->setWidget(4, QFormLayout::ItemRole::SpanningRole, esilBreakOnInvalid);


        verticalLayout->addLayout(formLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(DebugOptionsWidget);

        QMetaObject::connectSlotsByName(DebugOptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *DebugOptionsWidget)
    {
        DebugOptionsWidget->setWindowTitle(QCoreApplication::translate("DebugOptionsWidget", "Debug", nullptr));
        pluginLabel->setText(QCoreApplication::translate("DebugOptionsWidget", "Debug Plugin:", nullptr));
        esilstackAddr->setText(QCoreApplication::translate("DebugOptionsWidget", "ESIL stack address:", nullptr));
        esilStackSize->setText(QCoreApplication::translate("DebugOptionsWidget", "ESIL stack size:", nullptr));
        esilBreakOnInvalid->setText(QCoreApplication::translate("DebugOptionsWidget", "Break esil execution when instruction is invalid (esil.breakoninvalid)", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DebugOptionsWidget: public Ui_DebugOptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DEBUGOPTIONSWIDGET_H
