/********************************************************************************
** Form generated from reading UI file 'HexdumpWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_HEXDUMPWIDGET_H
#define UI_HEXDUMPWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "HexWidget.h"

QT_BEGIN_NAMESPACE

class Ui_HexdumpWidget
{
public:
    QWidget *dockWidgetContents;
    QVBoxLayout *horizontalLayout;
    QSplitter *splitter;
    HexWidget *hexTextView;
    QTabWidget *hexSideTab_2;
    QWidget *tabDIsasm_2;
    QVBoxLayout *verticalLayout_23;
    QVBoxLayout *verticalLayout_16;
    QHBoxLayout *horizontalLayout_17;
    QComboBox *parseTypeComboBox;
    QLabel *label_6;
    QComboBox *parseEndianComboBox;
    QFrame *hexSideFrame_2;
    QHBoxLayout *horizontalLayout_21;
    QLabel *hexArchLabel_2;
    QComboBox *parseArchComboBox;
    QLabel *hexBitsLabel_2;
    QComboBox *parseBitsComboBox;
    QPlainTextEdit *hexDisasTextEdit;
    QWidget *tabHistogram_2;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *labelSHA256;
    QLineEdit *bytesMD5;
    QLabel *labelSHA1;
    QToolButton *copySHA256;
    QToolButton *copySHA1;
    QLineEdit *bytesCRC32;
    QToolButton *copyCRC32;
    QLineEdit *bytesEntropy;
    QLabel *labelEntropy;
    QLineEdit *bytesSHA1;
    QLabel *labelMD5;
    QLabel *labelCRC32;
    QToolButton *copyMD5;
    QLineEdit *bytesSHA256;
    QSpacerItem *verticalSpacer;
    QWidget *tab;
    QWidget *verticalLayoutWidget;
    QVBoxLayout *verticalLayout_2;
    QComboBox *valueEndian;
    QGridLayout *gridLayout_2;
    QLineEdit *v_uint24;
    QLabel *labelSHA1_2;
    QLabel *labelEntropy_2;
    QLineEdit *v_float32;
    QLineEdit *v_double;
    QLabel *labelEntropy_3;
    QLineEdit *v_int16;
    QLineEdit *v_uint48;
    QLineEdit *v_int24;
    QLineEdit *v_int32;
    QLineEdit *v_uint64;
    QLabel *labelMD5_2;
    QLineEdit *v_uint16;
    QLineEdit *v_uint32;
    QLineEdit *v_int48;
    QLineEdit *v_int64;
    QLineEdit *v_int8;
    QLabel *labelCRC32_2;
    QLabel *labelDouble;
    QLabel *labelSHA256_2;
    QLineEdit *v_uint8;
    QLabel *labelFloat32;
    QWidget *tabFormat;
    QVBoxLayout *verticalLayoutFormat;
    QHBoxLayout *horizontalLayoutFormat;
    QComboBox *formatStructComboBox;
    QLineEdit *formatInlineEdit;
    QPlainTextEdit *formatOutput;
    QWidget *tabHistogram;
    QWidget *verticalLayoutWidget_2;
    QVBoxLayout *verticalLayout_3;
    QComboBox *comboBox;
    QTextEdit *histogram;
    QToolButton *openSideViewB;

    void setupUi(QDockWidget *HexdumpWidget)
    {
        if (HexdumpWidget->objectName().isEmpty())
            HexdumpWidget->setObjectName("HexdumpWidget");
        HexdumpWidget->resize(959, 807);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(HexdumpWidget->sizePolicy().hasHeightForWidth());
        HexdumpWidget->setSizePolicy(sizePolicy);
        HexdumpWidget->setWindowTitle(QString::fromUtf8("Hexdump"));
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        horizontalLayout = new QVBoxLayout(dockWidgetContents);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(-1, -1, 0, -1);
        splitter = new QSplitter(dockWidgetContents);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Horizontal);
        hexTextView = new HexWidget(splitter);
        hexTextView->setObjectName("hexTextView");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(1);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(hexTextView->sizePolicy().hasHeightForWidth());
        hexTextView->setSizePolicy(sizePolicy1);
        hexTextView->setFrameShape(QFrame::Shape::NoFrame);
        hexTextView->setWidgetResizable(true);
        splitter->addWidget(hexTextView);
        hexSideTab_2 = new QTabWidget(splitter);
        hexSideTab_2->setObjectName("hexSideTab_2");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(hexSideTab_2->sizePolicy().hasHeightForWidth());
        hexSideTab_2->setSizePolicy(sizePolicy2);
        hexSideTab_2->setTabPosition(QTabWidget::TabPosition::North);
        hexSideTab_2->setUsesScrollButtons(true);
        hexSideTab_2->setDocumentMode(false);
        tabDIsasm_2 = new QWidget();
        tabDIsasm_2->setObjectName("tabDIsasm_2");
        verticalLayout_23 = new QVBoxLayout(tabDIsasm_2);
        verticalLayout_23->setSpacing(6);
        verticalLayout_23->setObjectName("verticalLayout_23");
        verticalLayout_23->setContentsMargins(0, 0, 0, 0);
        verticalLayout_16 = new QVBoxLayout();
        verticalLayout_16->setSpacing(5);
        verticalLayout_16->setObjectName("verticalLayout_16");
        verticalLayout_16->setContentsMargins(-1, -1, 0, -1);
        horizontalLayout_17 = new QHBoxLayout();
        horizontalLayout_17->setObjectName("horizontalLayout_17");
        horizontalLayout_17->setContentsMargins(-1, 0, -1, -1);
        parseTypeComboBox = new QComboBox(tabDIsasm_2);
        parseTypeComboBox->setObjectName("parseTypeComboBox");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(parseTypeComboBox->sizePolicy().hasHeightForWidth());
        parseTypeComboBox->setSizePolicy(sizePolicy3);

        horizontalLayout_17->addWidget(parseTypeComboBox);

        label_6 = new QLabel(tabDIsasm_2);
        label_6->setObjectName("label_6");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(label_6->sizePolicy().hasHeightForWidth());
        label_6->setSizePolicy(sizePolicy4);

        horizontalLayout_17->addWidget(label_6);

        parseEndianComboBox = new QComboBox(tabDIsasm_2);
        parseEndianComboBox->addItem(QString());
        parseEndianComboBox->addItem(QString());
        parseEndianComboBox->setObjectName("parseEndianComboBox");
        parseEndianComboBox->setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy::AdjustToContents);

        horizontalLayout_17->addWidget(parseEndianComboBox);


        verticalLayout_16->addLayout(horizontalLayout_17);

        hexSideFrame_2 = new QFrame(tabDIsasm_2);
        hexSideFrame_2->setObjectName("hexSideFrame_2");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(hexSideFrame_2->sizePolicy().hasHeightForWidth());
        hexSideFrame_2->setSizePolicy(sizePolicy5);
        hexSideFrame_2->setMinimumSize(QSize(0, 0));
        hexSideFrame_2->setFrameShape(QFrame::Shape::NoFrame);
        hexSideFrame_2->setFrameShadow(QFrame::Shadow::Plain);
        hexSideFrame_2->setLineWidth(0);
        horizontalLayout_21 = new QHBoxLayout(hexSideFrame_2);
        horizontalLayout_21->setObjectName("horizontalLayout_21");
        horizontalLayout_21->setSizeConstraint(QLayout::SizeConstraint::SetMinimumSize);
        horizontalLayout_21->setContentsMargins(5, 0, 5, 5);
        hexArchLabel_2 = new QLabel(hexSideFrame_2);
        hexArchLabel_2->setObjectName("hexArchLabel_2");
        sizePolicy4.setHeightForWidth(hexArchLabel_2->sizePolicy().hasHeightForWidth());
        hexArchLabel_2->setSizePolicy(sizePolicy4);

        horizontalLayout_21->addWidget(hexArchLabel_2);

        parseArchComboBox = new QComboBox(hexSideFrame_2);
        parseArchComboBox->setObjectName("parseArchComboBox");
        sizePolicy3.setHeightForWidth(parseArchComboBox->sizePolicy().hasHeightForWidth());
        parseArchComboBox->setSizePolicy(sizePolicy3);
        parseArchComboBox->setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy::AdjustToContents);
        parseArchComboBox->setFrame(false);

        horizontalLayout_21->addWidget(parseArchComboBox);

        hexBitsLabel_2 = new QLabel(hexSideFrame_2);
        hexBitsLabel_2->setObjectName("hexBitsLabel_2");
        sizePolicy4.setHeightForWidth(hexBitsLabel_2->sizePolicy().hasHeightForWidth());
        hexBitsLabel_2->setSizePolicy(sizePolicy4);

        horizontalLayout_21->addWidget(hexBitsLabel_2);

        parseBitsComboBox = new QComboBox(hexSideFrame_2);
        parseBitsComboBox->addItem(QString());
        parseBitsComboBox->addItem(QString());
        parseBitsComboBox->addItem(QString());
        parseBitsComboBox->setObjectName("parseBitsComboBox");
        parseBitsComboBox->setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy::AdjustToContents);

        horizontalLayout_21->addWidget(parseBitsComboBox);


        verticalLayout_16->addWidget(hexSideFrame_2);

        hexDisasTextEdit = new QPlainTextEdit(tabDIsasm_2);
        hexDisasTextEdit->setObjectName("hexDisasTextEdit");
        sizePolicy2.setHeightForWidth(hexDisasTextEdit->sizePolicy().hasHeightForWidth());
        hexDisasTextEdit->setSizePolicy(sizePolicy2);
        QFont font;
        font.setFamilies({QString::fromUtf8("Anonymous Pro")});
        font.setPointSize(13);
        hexDisasTextEdit->setFont(font);
        hexDisasTextEdit->setFrameShape(QFrame::Shape::NoFrame);
        hexDisasTextEdit->setLineWidth(0);
        hexDisasTextEdit->setReadOnly(true);

        verticalLayout_16->addWidget(hexDisasTextEdit);


        verticalLayout_23->addLayout(verticalLayout_16);

        hexSideTab_2->addTab(tabDIsasm_2, QString());
        tabHistogram_2 = new QWidget();
        tabHistogram_2->setObjectName("tabHistogram_2");
        sizePolicy.setHeightForWidth(tabHistogram_2->sizePolicy().hasHeightForWidth());
        tabHistogram_2->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(tabHistogram_2);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        gridLayout->setSizeConstraint(QLayout::SizeConstraint::SetDefaultConstraint);
        gridLayout->setHorizontalSpacing(8);
        gridLayout->setVerticalSpacing(10);
        gridLayout->setContentsMargins(-1, -1, 0, -1);
        labelSHA256 = new QLabel(tabHistogram_2);
        labelSHA256->setObjectName("labelSHA256");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(labelSHA256->sizePolicy().hasHeightForWidth());
        labelSHA256->setSizePolicy(sizePolicy6);
        labelSHA256->setMidLineWidth(4);

        gridLayout->addWidget(labelSHA256, 3, 0, 1, 1);

        bytesMD5 = new QLineEdit(tabHistogram_2);
        bytesMD5->setObjectName("bytesMD5");
        sizePolicy5.setHeightForWidth(bytesMD5->sizePolicy().hasHeightForWidth());
        bytesMD5->setSizePolicy(sizePolicy5);
        bytesMD5->setFrame(true);
        bytesMD5->setAlignment(Qt::AlignmentFlag::AlignJustify|Qt::AlignmentFlag::AlignVCenter);
        bytesMD5->setReadOnly(true);

        gridLayout->addWidget(bytesMD5, 1, 1, 1, 1);

        labelSHA1 = new QLabel(tabHistogram_2);
        labelSHA1->setObjectName("labelSHA1");
        sizePolicy6.setHeightForWidth(labelSHA1->sizePolicy().hasHeightForWidth());
        labelSHA1->setSizePolicy(sizePolicy6);

        gridLayout->addWidget(labelSHA1, 2, 0, 1, 1);

        copySHA256 = new QToolButton(tabHistogram_2);
        copySHA256->setObjectName("copySHA256");
        copySHA256->setLayoutDirection(Qt::LayoutDirection::RightToLeft);
        copySHA256->setText(QString::fromUtf8(""));

        gridLayout->addWidget(copySHA256, 3, 2, 1, 1, Qt::AlignmentFlag::AlignRight);

        copySHA1 = new QToolButton(tabHistogram_2);
        copySHA1->setObjectName("copySHA1");
#if QT_CONFIG(tooltip)
        copySHA1->setToolTip(QString::fromUtf8("Copy SHA1"));
#endif // QT_CONFIG(tooltip)
        copySHA1->setLayoutDirection(Qt::LayoutDirection::RightToLeft);
        copySHA1->setText(QString::fromUtf8(""));

        gridLayout->addWidget(copySHA1, 2, 2, 1, 1);

        bytesCRC32 = new QLineEdit(tabHistogram_2);
        bytesCRC32->setObjectName("bytesCRC32");
        bytesCRC32->setFrame(true);
        bytesCRC32->setAlignment(Qt::AlignmentFlag::AlignJustify|Qt::AlignmentFlag::AlignVCenter);
        bytesCRC32->setReadOnly(true);

        gridLayout->addWidget(bytesCRC32, 4, 1, 1, 1);

        copyCRC32 = new QToolButton(tabHistogram_2);
        copyCRC32->setObjectName("copyCRC32");
        copyCRC32->setLayoutDirection(Qt::LayoutDirection::RightToLeft);
        copyCRC32->setText(QString::fromUtf8(""));

        gridLayout->addWidget(copyCRC32, 4, 2, 1, 1, Qt::AlignmentFlag::AlignRight);

        bytesEntropy = new QLineEdit(tabHistogram_2);
        bytesEntropy->setObjectName("bytesEntropy");
        sizePolicy5.setHeightForWidth(bytesEntropy->sizePolicy().hasHeightForWidth());
        bytesEntropy->setSizePolicy(sizePolicy5);
        bytesEntropy->setFrame(true);
        bytesEntropy->setAlignment(Qt::AlignmentFlag::AlignJustify|Qt::AlignmentFlag::AlignVCenter);
        bytesEntropy->setReadOnly(true);

        gridLayout->addWidget(bytesEntropy, 5, 1, 1, 2);

        labelEntropy = new QLabel(tabHistogram_2);
        labelEntropy->setObjectName("labelEntropy");
        sizePolicy6.setHeightForWidth(labelEntropy->sizePolicy().hasHeightForWidth());
        labelEntropy->setSizePolicy(sizePolicy6);

        gridLayout->addWidget(labelEntropy, 5, 0, 1, 1, Qt::AlignmentFlag::AlignLeft);

        bytesSHA1 = new QLineEdit(tabHistogram_2);
        bytesSHA1->setObjectName("bytesSHA1");
        sizePolicy5.setHeightForWidth(bytesSHA1->sizePolicy().hasHeightForWidth());
        bytesSHA1->setSizePolicy(sizePolicy5);
        bytesSHA1->setFrame(true);
        bytesSHA1->setAlignment(Qt::AlignmentFlag::AlignJustify|Qt::AlignmentFlag::AlignVCenter);
        bytesSHA1->setReadOnly(true);

        gridLayout->addWidget(bytesSHA1, 2, 1, 1, 1);

        labelMD5 = new QLabel(tabHistogram_2);
        labelMD5->setObjectName("labelMD5");
        sizePolicy6.setHeightForWidth(labelMD5->sizePolicy().hasHeightForWidth());
        labelMD5->setSizePolicy(sizePolicy6);

        gridLayout->addWidget(labelMD5, 1, 0, 1, 1);

        labelCRC32 = new QLabel(tabHistogram_2);
        labelCRC32->setObjectName("labelCRC32");
        sizePolicy6.setHeightForWidth(labelCRC32->sizePolicy().hasHeightForWidth());
        labelCRC32->setSizePolicy(sizePolicy6);

        gridLayout->addWidget(labelCRC32, 4, 0, 1, 1);

        copyMD5 = new QToolButton(tabHistogram_2);
        copyMD5->setObjectName("copyMD5");
#if QT_CONFIG(tooltip)
        copyMD5->setToolTip(QString::fromUtf8("Copy MD5"));
#endif // QT_CONFIG(tooltip)
        copyMD5->setLayoutDirection(Qt::LayoutDirection::RightToLeft);
        copyMD5->setText(QString::fromUtf8(""));

        gridLayout->addWidget(copyMD5, 1, 2, 1, 1);

        bytesSHA256 = new QLineEdit(tabHistogram_2);
        bytesSHA256->setObjectName("bytesSHA256");
        bytesSHA256->setFrame(true);
        bytesSHA256->setAlignment(Qt::AlignmentFlag::AlignJustify|Qt::AlignmentFlag::AlignVCenter);
        bytesSHA256->setReadOnly(true);

        gridLayout->addWidget(bytesSHA256, 3, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        hexSideTab_2->addTab(tabHistogram_2, QString());
        hexSideTab_2->setTabText(hexSideTab_2->indexOf(tabHistogram_2), QString::fromUtf8("Hash"));
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayoutWidget = new QWidget(tab);
        verticalLayoutWidget->setObjectName("verticalLayoutWidget");
        verticalLayoutWidget->setGeometry(QRect(10, 8, 261, 301));
        verticalLayout_2 = new QVBoxLayout(verticalLayoutWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        valueEndian = new QComboBox(verticalLayoutWidget);
        valueEndian->addItem(QString());
        valueEndian->addItem(QString());
        valueEndian->setObjectName("valueEndian");
        valueEndian->setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy::AdjustToContents);

        verticalLayout_2->addWidget(valueEndian);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setSizeConstraint(QLayout::SizeConstraint::SetDefaultConstraint);
        gridLayout_2->setHorizontalSpacing(8);
        gridLayout_2->setVerticalSpacing(10);
        gridLayout_2->setContentsMargins(-1, -1, 0, -1);
        v_uint24 = new QLineEdit(verticalLayoutWidget);
        v_uint24->setObjectName("v_uint24");
        v_uint24->setFrame(true);
        v_uint24->setAlignment(Qt::AlignmentFlag::AlignJustify|Qt::AlignmentFlag::AlignVCenter);
        v_uint24->setReadOnly(false);

        gridLayout_2->addWidget(v_uint24, 3, 2, 1, 1);

        labelSHA1_2 = new QLabel(verticalLayoutWidget);
        labelSHA1_2->setObjectName("labelSHA1_2");
        sizePolicy6.setHeightForWidth(labelSHA1_2->sizePolicy().hasHeightForWidth());
        labelSHA1_2->setSizePolicy(sizePolicy6);

        gridLayout_2->addWidget(labelSHA1_2, 2, 0, 1, 1);

        labelEntropy_2 = new QLabel(verticalLayoutWidget);
        labelEntropy_2->setObjectName("labelEntropy_2");
        sizePolicy6.setHeightForWidth(labelEntropy_2->sizePolicy().hasHeightForWidth());
        labelEntropy_2->setSizePolicy(sizePolicy6);

        gridLayout_2->addWidget(labelEntropy_2, 5, 0, 1, 1, Qt::AlignmentFlag::AlignLeft);

        v_float32 = new QLineEdit(verticalLayoutWidget);
        v_float32->setObjectName("v_float32");
        v_float32->setFrame(true);
        v_float32->setAlignment(Qt::AlignmentFlag::AlignJustify|Qt::AlignmentFlag::AlignVCenter);
        v_float32->setReadOnly(true);

        gridLayout_2->addWidget(v_float32, 7, 1, 1, 2);

        v_double = new QLineEdit(verticalLayoutWidget);
        v_double->setObjectName("v_double");
        v_double->setFrame(true);
        v_double->setAlignment(Qt::AlignmentFlag::AlignJustify|Qt::AlignmentFlag::AlignVCenter);
        v_double->setReadOnly(true);

        gridLayout_2->addWidget(v_double, 8, 1, 1, 2);

        labelEntropy_3 = new QLabel(verticalLayoutWidget);
        labelEntropy_3->setObjectName("labelEntropy_3");
        sizePolicy6.setHeightForWidth(labelEntropy_3->sizePolicy().hasHeightForWidth());
        labelEntropy_3->setSizePolicy(sizePolicy6);

        gridLayout_2->addWidget(labelEntropy_3, 6, 0, 1, 1);

        v_int16 = new QLineEdit(verticalLayoutWidget);
        v_int16->setObjectName("v_int16");
        sizePolicy5.setHeightForWidth(v_int16->sizePolicy().hasHeightForWidth());
        v_int16->setSizePolicy(sizePolicy5);
        v_int16->setFrame(true);
        v_int16->setAlignment(Qt::AlignmentFlag::AlignJustify|Qt::AlignmentFlag::AlignVCenter);
        v_int16->setReadOnly(false);

        gridLayout_2->addWidget(v_int16, 2, 1, 1, 1);

        v_uint48 = new QLineEdit(verticalLayoutWidget);
        v_uint48->setObjectName("v_uint48");
        v_uint48->setFrame(true);
        v_uint48->setAlignment(Qt::AlignmentFlag::AlignJustify|Qt::AlignmentFlag::AlignVCenter);
        v_uint48->setReadOnly(false);

        gridLayout_2->addWidget(v_uint48, 5, 2, 1, 1);

        v_int24 = new QLineEdit(verticalLayoutWidget);
        v_int24->setObjectName("v_int24");
        v_int24->setFrame(true);
        v_int24->setAlignment(Qt::AlignmentFlag::AlignJustify|Qt::AlignmentFlag::AlignVCenter);
        v_int24->setReadOnly(false);

        gridLayout_2->addWidget(v_int24, 3, 1, 1, 1);

        v_int32 = new QLineEdit(verticalLayoutWidget);
        v_int32->setObjectName("v_int32");
        v_int32->setFrame(true);
        v_int32->setAlignment(Qt::AlignmentFlag::AlignJustify|Qt::AlignmentFlag::AlignVCenter);
        v_int32->setReadOnly(false);

        gridLayout_2->addWidget(v_int32, 4, 1, 1, 1);

        v_uint64 = new QLineEdit(verticalLayoutWidget);
        v_uint64->setObjectName("v_uint64");
        v_uint64->setFrame(true);
        v_uint64->setAlignment(Qt::AlignmentFlag::AlignJustify|Qt::AlignmentFlag::AlignVCenter);
        v_uint64->setReadOnly(false);

        gridLayout_2->addWidget(v_uint64, 6, 2, 1, 1);

        labelMD5_2 = new QLabel(verticalLayoutWidget);
        labelMD5_2->setObjectName("labelMD5_2");
        sizePolicy6.setHeightForWidth(labelMD5_2->sizePolicy().hasHeightForWidth());
        labelMD5_2->setSizePolicy(sizePolicy6);

        gridLayout_2->addWidget(labelMD5_2, 1, 0, 1, 1);

        v_uint16 = new QLineEdit(verticalLayoutWidget);
        v_uint16->setObjectName("v_uint16");
        sizePolicy5.setHeightForWidth(v_uint16->sizePolicy().hasHeightForWidth());
        v_uint16->setSizePolicy(sizePolicy5);
        v_uint16->setFrame(true);
        v_uint16->setAlignment(Qt::AlignmentFlag::AlignJustify|Qt::AlignmentFlag::AlignVCenter);
        v_uint16->setReadOnly(false);

        gridLayout_2->addWidget(v_uint16, 2, 2, 1, 1);

        v_uint32 = new QLineEdit(verticalLayoutWidget);
        v_uint32->setObjectName("v_uint32");
        v_uint32->setFrame(true);
        v_uint32->setAlignment(Qt::AlignmentFlag::AlignJustify|Qt::AlignmentFlag::AlignVCenter);
        v_uint32->setReadOnly(false);

        gridLayout_2->addWidget(v_uint32, 4, 2, 1, 1);

        v_int48 = new QLineEdit(verticalLayoutWidget);
        v_int48->setObjectName("v_int48");
        v_int48->setFrame(true);
        v_int48->setAlignment(Qt::AlignmentFlag::AlignJustify|Qt::AlignmentFlag::AlignVCenter);
        v_int48->setReadOnly(false);

        gridLayout_2->addWidget(v_int48, 5, 1, 1, 1);

        v_int64 = new QLineEdit(verticalLayoutWidget);
        v_int64->setObjectName("v_int64");
        v_int64->setFrame(true);
        v_int64->setAlignment(Qt::AlignmentFlag::AlignJustify|Qt::AlignmentFlag::AlignVCenter);
        v_int64->setReadOnly(false);

        gridLayout_2->addWidget(v_int64, 6, 1, 1, 1);

        v_int8 = new QLineEdit(verticalLayoutWidget);
        v_int8->setObjectName("v_int8");
        sizePolicy5.setHeightForWidth(v_int8->sizePolicy().hasHeightForWidth());
        v_int8->setSizePolicy(sizePolicy5);
        v_int8->setFrame(true);
        v_int8->setAlignment(Qt::AlignmentFlag::AlignJustify|Qt::AlignmentFlag::AlignVCenter);
        v_int8->setReadOnly(false);

        gridLayout_2->addWidget(v_int8, 1, 1, 1, 1);

        labelCRC32_2 = new QLabel(verticalLayoutWidget);
        labelCRC32_2->setObjectName("labelCRC32_2");
        sizePolicy6.setHeightForWidth(labelCRC32_2->sizePolicy().hasHeightForWidth());
        labelCRC32_2->setSizePolicy(sizePolicy6);

        gridLayout_2->addWidget(labelCRC32_2, 4, 0, 1, 1);

        labelDouble = new QLabel(verticalLayoutWidget);
        labelDouble->setObjectName("labelDouble");
        sizePolicy6.setHeightForWidth(labelDouble->sizePolicy().hasHeightForWidth());
        labelDouble->setSizePolicy(sizePolicy6);

        gridLayout_2->addWidget(labelDouble, 8, 0, 1, 1);

        labelSHA256_2 = new QLabel(verticalLayoutWidget);
        labelSHA256_2->setObjectName("labelSHA256_2");
        sizePolicy6.setHeightForWidth(labelSHA256_2->sizePolicy().hasHeightForWidth());
        labelSHA256_2->setSizePolicy(sizePolicy6);
        labelSHA256_2->setMidLineWidth(4);

        gridLayout_2->addWidget(labelSHA256_2, 3, 0, 1, 1);

        v_uint8 = new QLineEdit(verticalLayoutWidget);
        v_uint8->setObjectName("v_uint8");
        sizePolicy5.setHeightForWidth(v_uint8->sizePolicy().hasHeightForWidth());
        v_uint8->setSizePolicy(sizePolicy5);
        v_uint8->setFrame(true);
        v_uint8->setAlignment(Qt::AlignmentFlag::AlignJustify|Qt::AlignmentFlag::AlignVCenter);
        v_uint8->setReadOnly(false);

        gridLayout_2->addWidget(v_uint8, 1, 2, 1, 1);

        labelFloat32 = new QLabel(verticalLayoutWidget);
        labelFloat32->setObjectName("labelFloat32");
        sizePolicy6.setHeightForWidth(labelFloat32->sizePolicy().hasHeightForWidth());
        labelFloat32->setSizePolicy(sizePolicy6);

        gridLayout_2->addWidget(labelFloat32, 7, 0, 1, 1);


        verticalLayout_2->addLayout(gridLayout_2);

        hexSideTab_2->addTab(tab, QString());
        tabFormat = new QWidget();
        tabFormat->setObjectName("tabFormat");
        verticalLayoutFormat = new QVBoxLayout(tabFormat);
        verticalLayoutFormat->setObjectName("verticalLayoutFormat");
        horizontalLayoutFormat = new QHBoxLayout();
        horizontalLayoutFormat->setObjectName("horizontalLayoutFormat");
        formatStructComboBox = new QComboBox(tabFormat);
        formatStructComboBox->setObjectName("formatStructComboBox");

        horizontalLayoutFormat->addWidget(formatStructComboBox);

        formatInlineEdit = new QLineEdit(tabFormat);
        formatInlineEdit->setObjectName("formatInlineEdit");

        horizontalLayoutFormat->addWidget(formatInlineEdit);


        verticalLayoutFormat->addLayout(horizontalLayoutFormat);

        formatOutput = new QPlainTextEdit(tabFormat);
        formatOutput->setObjectName("formatOutput");
        formatOutput->setLineWrapMode(QPlainTextEdit::LineWrapMode::NoWrap);
        formatOutput->setReadOnly(true);

        verticalLayoutFormat->addWidget(formatOutput);

        hexSideTab_2->addTab(tabFormat, QString());
        hexSideTab_2->setTabText(hexSideTab_2->indexOf(tabFormat), QString::fromUtf8("Format"));
        tabHistogram = new QWidget();
        tabHistogram->setObjectName("tabHistogram");
        verticalLayoutWidget_2 = new QWidget(tabHistogram);
        verticalLayoutWidget_2->setObjectName("verticalLayoutWidget_2");
        verticalLayoutWidget_2->setGeometry(QRect(9, 10, 271, 321));
        verticalLayout_3 = new QVBoxLayout(verticalLayoutWidget_2);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        comboBox = new QComboBox(verticalLayoutWidget_2);
        comboBox->addItem(QString());
        comboBox->addItem(QString());
        comboBox->addItem(QString());
        comboBox->addItem(QString());
        comboBox->setObjectName("comboBox");

        verticalLayout_3->addWidget(comboBox);

        histogram = new QTextEdit(verticalLayoutWidget_2);
        histogram->setObjectName("histogram");
        QFont font1;
        font1.setFamilies({QString::fromUtf8("Courier New")});
        font1.setPointSize(9);
        histogram->setFont(font1);
        histogram->viewport()->setProperty("cursor", QVariant(QCursor(Qt::CursorShape::CrossCursor)));
        histogram->setLineWrapMode(QTextEdit::LineWrapMode::WidgetWidth);
        histogram->setReadOnly(true);
        histogram->setHtml(QString::fromUtf8("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><meta charset=\"utf-8\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"hr { height: 1px; border-width: 0; }\n"
"li.unchecked::marker { content: \"\\2610\"; }\n"
"li.checked::marker { content: \"\\2612\"; }\n"
"</style></head><body style=\" font-family:'Courier New'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p></body></html>"));
        histogram->setAcceptRichText(false);

        verticalLayout_3->addWidget(histogram);

        hexSideTab_2->addTab(tabHistogram, QString());
        splitter->addWidget(hexSideTab_2);
        openSideViewB = new QToolButton(splitter);
        openSideViewB->setObjectName("openSideViewB");
        sizePolicy4.setHeightForWidth(openSideViewB->sizePolicy().hasHeightForWidth());
        openSideViewB->setSizePolicy(sizePolicy4);
        openSideViewB->setMaximumSize(QSize(24, 16777215));
        openSideViewB->setStyleSheet(QString::fromUtf8(""));
        openSideViewB->setText(QString::fromUtf8(""));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/img/icons/previous.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        openSideViewB->setIcon(icon);
        openSideViewB->setIconSize(QSize(16, 12));
        openSideViewB->setAutoRaise(true);
        openSideViewB->setArrowType(Qt::ArrowType::NoArrow);
        splitter->addWidget(openSideViewB);

        horizontalLayout->addWidget(splitter);

        HexdumpWidget->setWidget(dockWidgetContents);

        retranslateUi(HexdumpWidget);

        hexSideTab_2->setCurrentIndex(2);


        QMetaObject::connectSlotsByName(HexdumpWidget);
    } // setupUi

    void retranslateUi(QDockWidget *HexdumpWidget)
    {
        label_6->setText(QCoreApplication::translate("HexdumpWidget", "Endian", nullptr));
        parseEndianComboBox->setItemText(0, QCoreApplication::translate("HexdumpWidget", "Little", nullptr));
        parseEndianComboBox->setItemText(1, QCoreApplication::translate("HexdumpWidget", "Big", nullptr));

        hexArchLabel_2->setText(QCoreApplication::translate("HexdumpWidget", "Arch", nullptr));
        hexBitsLabel_2->setText(QCoreApplication::translate("HexdumpWidget", "Bits", nullptr));
        parseBitsComboBox->setItemText(0, QCoreApplication::translate("HexdumpWidget", "16", nullptr));
        parseBitsComboBox->setItemText(1, QCoreApplication::translate("HexdumpWidget", "32", nullptr));
        parseBitsComboBox->setItemText(2, QCoreApplication::translate("HexdumpWidget", "64", nullptr));

        hexDisasTextEdit->setPlainText(QString());
        hexSideTab_2->setTabText(hexSideTab_2->indexOf(tabDIsasm_2), QCoreApplication::translate("HexdumpWidget", "Parsing", nullptr));
        labelSHA256->setText(QCoreApplication::translate("HexdumpWidget", "SHA256:", nullptr));
        labelSHA1->setText(QCoreApplication::translate("HexdumpWidget", "SHA1:", nullptr));
#if QT_CONFIG(tooltip)
        copySHA256->setToolTip(QCoreApplication::translate("HexdumpWidget", "Copy SHA256", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        copyCRC32->setToolTip(QCoreApplication::translate("HexdumpWidget", "Copy CRC32", nullptr));
#endif // QT_CONFIG(tooltip)
        labelEntropy->setText(QCoreApplication::translate("HexdumpWidget", "Entropy:", nullptr));
        labelMD5->setText(QCoreApplication::translate("HexdumpWidget", "MD5:", nullptr));
        labelCRC32->setText(QCoreApplication::translate("HexdumpWidget", "CRC32:", nullptr));
        valueEndian->setItemText(0, QCoreApplication::translate("HexdumpWidget", "Little Endian", nullptr));
        valueEndian->setItemText(1, QCoreApplication::translate("HexdumpWidget", "Big Endian", nullptr));

        labelSHA1_2->setText(QCoreApplication::translate("HexdumpWidget", "int16", nullptr));
        labelEntropy_2->setText(QCoreApplication::translate("HexdumpWidget", "int48", nullptr));
        labelEntropy_3->setText(QCoreApplication::translate("HexdumpWidget", "int64", nullptr));
        labelMD5_2->setText(QCoreApplication::translate("HexdumpWidget", "int8", nullptr));
        labelCRC32_2->setText(QCoreApplication::translate("HexdumpWidget", "int32", nullptr));
        labelDouble->setText(QCoreApplication::translate("HexdumpWidget", "double", nullptr));
        labelSHA256_2->setText(QCoreApplication::translate("HexdumpWidget", "int24", nullptr));
        labelFloat32->setText(QCoreApplication::translate("HexdumpWidget", "float32", nullptr));
        hexSideTab_2->setTabText(hexSideTab_2->indexOf(tab), QCoreApplication::translate("HexdumpWidget", "Values", nullptr));
        comboBox->setItemText(0, QCoreApplication::translate("HexdumpWidget", "pr", nullptr));
        comboBox->setItemText(1, QCoreApplication::translate("HexdumpWidget", "pb", nullptr));
        comboBox->setItemText(2, QCoreApplication::translate("HexdumpWidget", "p8", nullptr));
        comboBox->setItemText(3, QCoreApplication::translate("HexdumpWidget", "prc", nullptr));

        hexSideTab_2->setTabText(hexSideTab_2->indexOf(tabHistogram), QCoreApplication::translate("HexdumpWidget", "Art", nullptr));
        (void)HexdumpWidget;
    } // retranslateUi

};

namespace Ui {
    class HexdumpWidget: public Ui_HexdumpWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_HEXDUMPWIDGET_H
