/********************************************************************************
** Form generated from reading UI file 'SettingsDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGSDIALOG_H
#define UI_SETTINGSDIALOG_H

#include <QtCore/QVariant>
#include <QtSvgWidgets/QSvgWidget>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_SettingsDialog
{
public:
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *leftPanelLayout;
    QSvgWidget *logoSvgWidget;
    QTreeWidget *configCategories;
    QVBoxLayout *verticalLayout;
    QStackedWidget *configPanel;
    QDialogButtonBox *saveButtons;

    void setupUi(QDialog *SettingsDialog)
    {
        if (SettingsDialog->objectName().isEmpty())
            SettingsDialog->setObjectName("SettingsDialog");
        horizontalLayout = new QHBoxLayout(SettingsDialog);
        horizontalLayout->setObjectName("horizontalLayout");
        leftPanelLayout = new QVBoxLayout();
        leftPanelLayout->setObjectName("leftPanelLayout");
        logoSvgWidget = new QSvgWidget(SettingsDialog);
        logoSvgWidget->setObjectName("logoSvgWidget");
        logoSvgWidget->setMinimumSize(QSize(96, 96));
        logoSvgWidget->setMaximumSize(QSize(96, 96));

        leftPanelLayout->addWidget(logoSvgWidget, 0, Qt::AlignHCenter);

        configCategories = new QTreeWidget(SettingsDialog);
        configCategories->setObjectName("configCategories");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(configCategories->sizePolicy().hasHeightForWidth());
        configCategories->setSizePolicy(sizePolicy);
        configCategories->setMaximumSize(QSize(175, 16777215));
        configCategories->setRootIsDecorated(false);
        configCategories->header()->setVisible(false);

        leftPanelLayout->addWidget(configCategories);


        horizontalLayout->addLayout(leftPanelLayout);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        configPanel = new QStackedWidget(SettingsDialog);
        configPanel->setObjectName("configPanel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(configPanel->sizePolicy().hasHeightForWidth());
        configPanel->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(configPanel);

        saveButtons = new QDialogButtonBox(SettingsDialog);
        saveButtons->setObjectName("saveButtons");
        saveButtons->setStandardButtons(QDialogButtonBox::Ok);

        verticalLayout->addWidget(saveButtons);


        horizontalLayout->addLayout(verticalLayout);


        retranslateUi(SettingsDialog);

        QMetaObject::connectSlotsByName(SettingsDialog);
    } // setupUi

    void retranslateUi(QDialog *SettingsDialog)
    {
        SettingsDialog->setWindowTitle(QCoreApplication::translate("SettingsDialog", "Settings", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SettingsDialog: public Ui_SettingsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SETTINGSDIALOG_H
