/****************************************************************************
** Meta object code from reading C++ file 'DisassemblyContextMenu.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/menus/DisassemblyContextMenu.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DisassemblyContextMenu.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22DisassemblyContextMenuE_t {};
} // unnamed namespace

template <> constexpr inline auto DisassemblyContextMenu::qt_create_metaobjectdata<qt_meta_tag_ZN22DisassemblyContextMenuE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DisassemblyContextMenu",
        "copy",
        "",
        "copyBytes",
        "setOffset",
        "RVA",
        "offset",
        "setSelectionRange",
        "start",
        "byteCount",
        "setCanCopy",
        "enabled",
        "setDeepLinkView",
        "view",
        "setCurHighlightedWord",
        "text",
        "aboutToShowSlot",
        "aboutToHideSlot",
        "on_actionEditFunction_triggered",
        "on_actionEditInstruction_triggered",
        "on_actionNopInstruction_triggered",
        "on_actionJmpReverse_triggered",
        "on_actionEditBytes_triggered",
        "showReverseJmpQuery",
        "on_actionCopy_triggered",
        "on_actionCopyAddr_triggered",
        "on_actionCopyInstruction_triggered",
        "on_actionCopyInstructionBytes_triggered",
        "on_actionCopyFunctionDisasm_triggered",
        "on_actionCopyFunctionBytes_triggered",
        "on_actionCopyDeepLink_triggered",
        "on_actionCopyBytes_triggered",
        "on_actionAddComment_triggered",
        "on_actionAnalyzeFunction_triggered",
        "on_actionRename_triggered",
        "on_actionSetFunctionVarTypes_triggered",
        "on_actionXRefs_triggered",
        "on_actionXRefsForVariables_triggered",
        "on_actionDisplayOptions_triggered",
        "on_actionDeleteComment_triggered",
        "on_actionDeleteFlag_triggered",
        "on_actionDeleteFunction_triggered",
        "on_actionAddBreakpoint_triggered",
        "on_actionAdvancedBreakpoint_triggered",
        "on_actionContinueUntil_triggered",
        "on_actionSetPC_triggered",
        "on_actionEditAnnotation_triggered",
        "on_actionSetToCode_triggered",
        "on_actionSetAsString_triggered",
        "on_actionSetAsStringRemove_triggered",
        "on_actionSetAsStringAdvanced_triggered",
        "on_actionSetToData_triggered",
        "on_actionSetToDataEx_triggered",
        "on_actionStructureOffsetMenu_triggered",
        "QAction*",
        "action",
        "on_actionLinkType_triggered",
        "on_actionRelativeTo_triggered",
        "on_actionAddrBase_triggered"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'copy'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'copyBytes'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setOffset'
        QtMocHelpers::SlotData<void(RVA)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'setSelectionRange'
        QtMocHelpers::SlotData<void(RVA, int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 8 }, { QMetaType::Int, 9 },
        }}),
        // Slot 'setCanCopy'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setDeepLinkView'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'setCurHighlightedWord'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'aboutToShowSlot'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'aboutToHideSlot'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionEditFunction_triggered'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionEditInstruction_triggered'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionNopInstruction_triggered'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionJmpReverse_triggered'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionEditBytes_triggered'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showReverseJmpQuery'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionCopy_triggered'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionCopyAddr_triggered'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionCopyInstruction_triggered'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionCopyInstructionBytes_triggered'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionCopyFunctionDisasm_triggered'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionCopyFunctionBytes_triggered'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionCopyDeepLink_triggered'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionCopyBytes_triggered'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionAddComment_triggered'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionAnalyzeFunction_triggered'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionRename_triggered'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSetFunctionVarTypes_triggered'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionXRefs_triggered'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionXRefsForVariables_triggered'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionDisplayOptions_triggered'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionDeleteComment_triggered'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionDeleteFlag_triggered'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionDeleteFunction_triggered'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionAddBreakpoint_triggered'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionAdvancedBreakpoint_triggered'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionContinueUntil_triggered'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSetPC_triggered'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionEditAnnotation_triggered'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSetToCode_triggered'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSetAsString_triggered'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSetAsStringRemove_triggered'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSetAsStringAdvanced_triggered'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSetToData_triggered'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSetToDataEx_triggered'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionStructureOffsetMenu_triggered'
        QtMocHelpers::SlotData<void(QAction *)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 54, 55 },
        }}),
        // Slot 'on_actionLinkType_triggered'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionRelativeTo_triggered'
        QtMocHelpers::SlotData<void(QAction *)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 54, 55 },
        }}),
        // Slot 'on_actionAddrBase_triggered'
        QtMocHelpers::SlotData<void(QAction *)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 54, 55 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DisassemblyContextMenu, qt_meta_tag_ZN22DisassemblyContextMenuE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DisassemblyContextMenu::staticMetaObject = { {
    QMetaObject::SuperData::link<QMenu::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22DisassemblyContextMenuE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22DisassemblyContextMenuE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22DisassemblyContextMenuE_t>.metaTypes,
    nullptr
} };

void DisassemblyContextMenu::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DisassemblyContextMenu *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->copy(); break;
        case 1: _t->copyBytes(); break;
        case 2: _t->setOffset((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1]))); break;
        case 3: _t->setSelectionRange((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->setCanCopy((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->setDeepLinkView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->setCurHighlightedWord((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->aboutToShowSlot(); break;
        case 8: _t->aboutToHideSlot(); break;
        case 9: _t->on_actionEditFunction_triggered(); break;
        case 10: _t->on_actionEditInstruction_triggered(); break;
        case 11: _t->on_actionNopInstruction_triggered(); break;
        case 12: _t->on_actionJmpReverse_triggered(); break;
        case 13: _t->on_actionEditBytes_triggered(); break;
        case 14: _t->showReverseJmpQuery(); break;
        case 15: _t->on_actionCopy_triggered(); break;
        case 16: _t->on_actionCopyAddr_triggered(); break;
        case 17: _t->on_actionCopyInstruction_triggered(); break;
        case 18: _t->on_actionCopyInstructionBytes_triggered(); break;
        case 19: _t->on_actionCopyFunctionDisasm_triggered(); break;
        case 20: _t->on_actionCopyFunctionBytes_triggered(); break;
        case 21: _t->on_actionCopyDeepLink_triggered(); break;
        case 22: _t->on_actionCopyBytes_triggered(); break;
        case 23: _t->on_actionAddComment_triggered(); break;
        case 24: _t->on_actionAnalyzeFunction_triggered(); break;
        case 25: _t->on_actionRename_triggered(); break;
        case 26: _t->on_actionSetFunctionVarTypes_triggered(); break;
        case 27: _t->on_actionXRefs_triggered(); break;
        case 28: _t->on_actionXRefsForVariables_triggered(); break;
        case 29: _t->on_actionDisplayOptions_triggered(); break;
        case 30: _t->on_actionDeleteComment_triggered(); break;
        case 31: _t->on_actionDeleteFlag_triggered(); break;
        case 32: _t->on_actionDeleteFunction_triggered(); break;
        case 33: _t->on_actionAddBreakpoint_triggered(); break;
        case 34: _t->on_actionAdvancedBreakpoint_triggered(); break;
        case 35: _t->on_actionContinueUntil_triggered(); break;
        case 36: _t->on_actionSetPC_triggered(); break;
        case 37: _t->on_actionEditAnnotation_triggered(); break;
        case 38: _t->on_actionSetToCode_triggered(); break;
        case 39: _t->on_actionSetAsString_triggered(); break;
        case 40: _t->on_actionSetAsStringRemove_triggered(); break;
        case 41: _t->on_actionSetAsStringAdvanced_triggered(); break;
        case 42: _t->on_actionSetToData_triggered(); break;
        case 43: _t->on_actionSetToDataEx_triggered(); break;
        case 44: _t->on_actionStructureOffsetMenu_triggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 45: _t->on_actionLinkType_triggered(); break;
        case 46: _t->on_actionRelativeTo_triggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 47: _t->on_actionAddrBase_triggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 44:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 46:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 47:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DisassemblyContextMenu::*)()>(_a, &DisassemblyContextMenu::copy, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisassemblyContextMenu::*)()>(_a, &DisassemblyContextMenu::copyBytes, 1))
            return;
    }
}

const QMetaObject *DisassemblyContextMenu::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DisassemblyContextMenu::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22DisassemblyContextMenuE_t>.strings))
        return static_cast<void*>(this);
    return QMenu::qt_metacast(_clname);
}

int DisassemblyContextMenu::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMenu::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 48)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 48;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 48)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 48;
    }
    return _id;
}

// SIGNAL 0
void DisassemblyContextMenu::copy()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DisassemblyContextMenu::copyBytes()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
