/********************************************************************************
** Form generated from reading UI file 'ZignaturesWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ZIGNATURESWIDGET_H
#define UI_ZIGNATURESWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/IaitoTreeView.h"

QT_BEGIN_NAMESPACE

class Ui_ZignaturesWidget
{
public:
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout;
    IaitoTreeView *zignaturesTreeView;

    void setupUi(QDockWidget *ZignaturesWidget)
    {
        if (ZignaturesWidget->objectName().isEmpty())
            ZignaturesWidget->setObjectName("ZignaturesWidget");
        ZignaturesWidget->resize(400, 300);
        ZignaturesWidget->setWindowTitle(QString::fromUtf8("Zignatures"));
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        verticalLayout = new QVBoxLayout(dockWidgetContents);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        zignaturesTreeView = new IaitoTreeView(dockWidgetContents);
        zignaturesTreeView->setObjectName("zignaturesTreeView");
        zignaturesTreeView->setStyleSheet(QString::fromUtf8("IaitoTreeView::item\n"
"{\n"
"    padding-top: 1px;\n"
"    padding-bottom: 1px;\n"
"}"));
        zignaturesTreeView->setFrameShape(QFrame::NoFrame);
        zignaturesTreeView->setLineWidth(0);
        zignaturesTreeView->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        zignaturesTreeView->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
        zignaturesTreeView->setAutoScroll(true);
        zignaturesTreeView->setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);
        zignaturesTreeView->setIndentation(8);
        zignaturesTreeView->setSortingEnabled(true);

        verticalLayout->addWidget(zignaturesTreeView);

        ZignaturesWidget->setWidget(dockWidgetContents);

        retranslateUi(ZignaturesWidget);

        QMetaObject::connectSlotsByName(ZignaturesWidget);
    } // setupUi

    void retranslateUi(QDockWidget *ZignaturesWidget)
    {
        (void)ZignaturesWidget;
    } // retranslateUi

};

namespace Ui {
    class ZignaturesWidget: public Ui_ZignaturesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ZIGNATURESWIDGET_H
