/********************************************************************************
** Form generated from reading UI file 'DecompilerWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DECOMPILERWIDGET_H
#define UI_DECOMPILERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_DecompilerWidget
{
public:
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout;
    QPlainTextEdit *textEdit;
    QHBoxLayout *horizontalLayout;
    QHBoxLayout *progressLayout;
    QLabel *progressLabel;
    QPushButton *decompileButton;
    QPushButton *cancelButton;
    QSpacerItem *horizontalSpacer;
    QLabel *decompilerLabel;
    QComboBox *decompilerComboBox;
    QComboBox *optionsComboBox;
    QPushButton *sourceEditFileButton;
    QPushButton *sourceOpenDirButton;
    QPushButton *sourceEditMapButton;
    QPushButton *sourceDirSourceButton;

    void setupUi(QDockWidget *DecompilerWidget)
    {
        if (DecompilerWidget->objectName().isEmpty())
            DecompilerWidget->setObjectName("DecompilerWidget");
        DecompilerWidget->resize(555, 393);
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        verticalLayout = new QVBoxLayout(dockWidgetContents);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        textEdit = new QPlainTextEdit(dockWidgetContents);
        textEdit->setObjectName("textEdit");
        textEdit->setLineWrapMode(QPlainTextEdit::NoWrap);
        textEdit->setReadOnly(true);

        verticalLayout->addWidget(textEdit);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        progressLayout = new QHBoxLayout();
        progressLayout->setObjectName("progressLayout");
        progressLayout->setContentsMargins(8, -1, -1, -1);
        progressLabel = new QLabel(dockWidgetContents);
        progressLabel->setObjectName("progressLabel");

        progressLayout->addWidget(progressLabel);

        decompileButton = new QPushButton(dockWidgetContents);
        decompileButton->setObjectName("decompileButton");
        decompileButton->setVisible(false);

        progressLayout->addWidget(decompileButton);

        cancelButton = new QPushButton(dockWidgetContents);
        cancelButton->setObjectName("cancelButton");
        cancelButton->setVisible(false);

        progressLayout->addWidget(cancelButton);


        horizontalLayout->addLayout(progressLayout);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        decompilerLabel = new QLabel(dockWidgetContents);
        decompilerLabel->setObjectName("decompilerLabel");

        horizontalLayout->addWidget(decompilerLabel);

        decompilerComboBox = new QComboBox(dockWidgetContents);
        decompilerComboBox->setObjectName("decompilerComboBox");

        horizontalLayout->addWidget(decompilerComboBox);

        optionsComboBox = new QComboBox(dockWidgetContents);
        optionsComboBox->setObjectName("optionsComboBox");

        horizontalLayout->addWidget(optionsComboBox);

        sourceEditFileButton = new QPushButton(dockWidgetContents);
        sourceEditFileButton->setObjectName("sourceEditFileButton");

        horizontalLayout->addWidget(sourceEditFileButton);

        sourceOpenDirButton = new QPushButton(dockWidgetContents);
        sourceOpenDirButton->setObjectName("sourceOpenDirButton");

        horizontalLayout->addWidget(sourceOpenDirButton);

        sourceEditMapButton = new QPushButton(dockWidgetContents);
        sourceEditMapButton->setObjectName("sourceEditMapButton");

        horizontalLayout->addWidget(sourceEditMapButton);

        sourceDirSourceButton = new QPushButton(dockWidgetContents);
        sourceDirSourceButton->setObjectName("sourceDirSourceButton");

        horizontalLayout->addWidget(sourceDirSourceButton);


        verticalLayout->addLayout(horizontalLayout);

        DecompilerWidget->setWidget(dockWidgetContents);

        retranslateUi(DecompilerWidget);

        QMetaObject::connectSlotsByName(DecompilerWidget);
    } // setupUi

    void retranslateUi(QDockWidget *DecompilerWidget)
    {
        DecompilerWidget->setWindowTitle(QCoreApplication::translate("DecompilerWidget", "Decompiler", nullptr));
        progressLabel->setText(QCoreApplication::translate("DecompilerWidget", "Decompiling...", nullptr));
        decompileButton->setText(QCoreApplication::translate("DecompilerWidget", "Decompile", nullptr));
        cancelButton->setText(QCoreApplication::translate("DecompilerWidget", "Cancel", nullptr));
        decompilerLabel->setText(QCoreApplication::translate("DecompilerWidget", "Decompiler:", nullptr));
#if QT_CONFIG(tooltip)
        optionsComboBox->setToolTip(QCoreApplication::translate("DecompilerWidget", "Decompiler options. Click an entry to set a new value.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        sourceEditFileButton->setToolTip(QCoreApplication::translate("DecompilerWidget", "Edit the source file for the current source line.", nullptr));
#endif // QT_CONFIG(tooltip)
        sourceEditFileButton->setText(QCoreApplication::translate("DecompilerWidget", "Edit file", nullptr));
#if QT_CONFIG(tooltip)
        sourceOpenDirButton->setToolTip(QCoreApplication::translate("DecompilerWidget", "Open the directory containing the current source file.", nullptr));
#endif // QT_CONFIG(tooltip)
        sourceOpenDirButton->setText(QCoreApplication::translate("DecompilerWidget", "Open dir", nullptr));
#if QT_CONFIG(tooltip)
        sourceEditMapButton->setToolTip(QCoreApplication::translate("DecompilerWidget", "Edit source line mappings for this function.", nullptr));
#endif // QT_CONFIG(tooltip)
        sourceEditMapButton->setText(QCoreApplication::translate("DecompilerWidget", "Edit map", nullptr));
#if QT_CONFIG(tooltip)
        sourceDirSourceButton->setToolTip(QCoreApplication::translate("DecompilerWidget", "Select a source file or directory for dir.source.", nullptr));
#endif // QT_CONFIG(tooltip)
        sourceDirSourceButton->setText(QCoreApplication::translate("DecompilerWidget", "dir.source", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DecompilerWidget: public Ui_DecompilerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DECOMPILERWIDGET_H
