/********************************************************************************
** Form generated from reading UI file 'SaveProjectDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SAVEPROJECTDIALOG_H
#define UI_SAVEPROJECTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_SaveProjectDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *nameLabel;
    QLineEdit *nameEdit;
    QFrame *line;
    QHBoxLayout *horizontalLayout_2;
    QLabel *nameLabel_2;
    QLineEdit *projectsDirEdit;
    QPushButton *selectProjectsDirButton;
    QCheckBox *filesCheckBox;
    QCheckBox *gitCheckBox;
    QCheckBox *zipCheckBox;
    QCheckBox *newCheckBox;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SaveProjectDialog)
    {
        if (SaveProjectDialog->objectName().isEmpty())
            SaveProjectDialog->setObjectName("SaveProjectDialog");
        SaveProjectDialog->resize(506, 227);
        verticalLayout = new QVBoxLayout(SaveProjectDialog);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        nameLabel = new QLabel(SaveProjectDialog);
        nameLabel->setObjectName("nameLabel");

        horizontalLayout->addWidget(nameLabel);

        nameEdit = new QLineEdit(SaveProjectDialog);
        nameEdit->setObjectName("nameEdit");

        horizontalLayout->addWidget(nameEdit);


        verticalLayout->addLayout(horizontalLayout);

        line = new QFrame(SaveProjectDialog);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        nameLabel_2 = new QLabel(SaveProjectDialog);
        nameLabel_2->setObjectName("nameLabel_2");

        horizontalLayout_2->addWidget(nameLabel_2);

        projectsDirEdit = new QLineEdit(SaveProjectDialog);
        projectsDirEdit->setObjectName("projectsDirEdit");
        projectsDirEdit->setReadOnly(false);

        horizontalLayout_2->addWidget(projectsDirEdit);

        selectProjectsDirButton = new QPushButton(SaveProjectDialog);
        selectProjectsDirButton->setObjectName("selectProjectsDirButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(selectProjectsDirButton->sizePolicy().hasHeightForWidth());
        selectProjectsDirButton->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(selectProjectsDirButton);


        verticalLayout->addLayout(horizontalLayout_2);

        filesCheckBox = new QCheckBox(SaveProjectDialog);
        filesCheckBox->setObjectName("filesCheckBox");

        verticalLayout->addWidget(filesCheckBox);

        gitCheckBox = new QCheckBox(SaveProjectDialog);
        gitCheckBox->setObjectName("gitCheckBox");

        verticalLayout->addWidget(gitCheckBox);

        zipCheckBox = new QCheckBox(SaveProjectDialog);
        zipCheckBox->setObjectName("zipCheckBox");

        verticalLayout->addWidget(zipCheckBox);

        newCheckBox = new QCheckBox(SaveProjectDialog);
        newCheckBox->setObjectName("newCheckBox");

        verticalLayout->addWidget(newCheckBox);

        buttonBox = new QDialogButtonBox(SaveProjectDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Save);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(SaveProjectDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SaveProjectDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SaveProjectDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(SaveProjectDialog);
    } // setupUi

    void retranslateUi(QDialog *SaveProjectDialog)
    {
        SaveProjectDialog->setWindowTitle(QCoreApplication::translate("SaveProjectDialog", "Save Project", nullptr));
        nameLabel->setText(QCoreApplication::translate("SaveProjectDialog", "Project name (prj.name):", nullptr));
        nameLabel_2->setText(QCoreApplication::translate("SaveProjectDialog", "Projects path (dir.projects):", nullptr));
        selectProjectsDirButton->setText(QCoreApplication::translate("SaveProjectDialog", "Select", nullptr));
        filesCheckBox->setText(QCoreApplication::translate("SaveProjectDialog", "Save the target binary inside the project directory (prj.files)", nullptr));
        gitCheckBox->setText(QCoreApplication::translate("SaveProjectDialog", "Project is a git repo and saving is committing (prj.git)", nullptr));
        zipCheckBox->setText(QCoreApplication::translate("SaveProjectDialog", "Use ZIP format for project files (prj.zip)", nullptr));
        newCheckBox->setText(QCoreApplication::translate("SaveProjectDialog", "Use new binary project format (prj.new)", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SaveProjectDialog: public Ui_SaveProjectDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SAVEPROJECTDIALOG_H
