/********************************************************************************
** Form generated from reading UI file 'GraphOptionsWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GRAPHOPTIONSWIDGET_H
#define UI_GRAPHOPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_GraphOptionsWidget
{
public:
    QVBoxLayout *verticalLayout_3;
    QGroupBox *GraphBlockOptions;
    QVBoxLayout *verticalLayout_9;
    QCheckBox *blockEntryCheckBox;
    QCheckBox *blockShadowCheckBox;
    QCheckBox *graphOffsetCheckBox;
    QHBoxLayout *horizontalLayout;
    QLabel *maxColsLabel;
    QSpinBox *maxColsSpinBox;
    QGroupBox *LayoutBlock;
    QGridLayout *gridLayout_2;
    QSpinBox *horizontalBlockSpacing;
    QLabel *label_4;
    QSpinBox *horizontalEdgeSpacing;
    QLabel *label_3;
    QSpinBox *verticalEdgeSpacing;
    QSpinBox *verticalBlockSpacing;
    QLabel *label;
    QLabel *label_2;
    QGroupBox *BitmapExportBlock;
    QVBoxLayout *verticalLayout_10;
    QCheckBox *checkTransparent;
    QHBoxLayout *horizontalLayout_2;
    QLabel *bitmapGraphScaleLabel;
    QDoubleSpinBox *bitmapGraphScale;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *GraphOptionsWidget)
    {
        if (GraphOptionsWidget->objectName().isEmpty())
            GraphOptionsWidget->setObjectName("GraphOptionsWidget");
        verticalLayout_3 = new QVBoxLayout(GraphOptionsWidget);
        verticalLayout_3->setObjectName("verticalLayout_3");
        GraphBlockOptions = new QGroupBox(GraphOptionsWidget);
        GraphBlockOptions->setObjectName("GraphBlockOptions");
        GraphBlockOptions->setFlat(true);
        verticalLayout_9 = new QVBoxLayout(GraphBlockOptions);
        verticalLayout_9->setObjectName("verticalLayout_9");
        verticalLayout_9->setContentsMargins(-1, 8, -1, -1);
        blockEntryCheckBox = new QCheckBox(GraphBlockOptions);
        blockEntryCheckBox->setObjectName("blockEntryCheckBox");

        verticalLayout_9->addWidget(blockEntryCheckBox);

        blockShadowCheckBox = new QCheckBox(GraphBlockOptions);
        blockShadowCheckBox->setObjectName("blockShadowCheckBox");

        verticalLayout_9->addWidget(blockShadowCheckBox);

        graphOffsetCheckBox = new QCheckBox(GraphBlockOptions);
        graphOffsetCheckBox->setObjectName("graphOffsetCheckBox");

        verticalLayout_9->addWidget(graphOffsetCheckBox);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        maxColsLabel = new QLabel(GraphBlockOptions);
        maxColsLabel->setObjectName("maxColsLabel");

        horizontalLayout->addWidget(maxColsLabel);

        maxColsSpinBox = new QSpinBox(GraphBlockOptions);
        maxColsSpinBox->setObjectName("maxColsSpinBox");
        maxColsSpinBox->setMinimum(25);
        maxColsSpinBox->setMaximum(256);
        maxColsSpinBox->setValue(100);

        horizontalLayout->addWidget(maxColsSpinBox);


        verticalLayout_9->addLayout(horizontalLayout);


        verticalLayout_3->addWidget(GraphBlockOptions);

        LayoutBlock = new QGroupBox(GraphOptionsWidget);
        LayoutBlock->setObjectName("LayoutBlock");
        LayoutBlock->setFlat(true);
        gridLayout_2 = new QGridLayout(LayoutBlock);
        gridLayout_2->setObjectName("gridLayout_2");
        horizontalBlockSpacing = new QSpinBox(LayoutBlock);
        horizontalBlockSpacing->setObjectName("horizontalBlockSpacing");
        horizontalBlockSpacing->setMaximum(400);
        horizontalBlockSpacing->setSingleStep(10);
        horizontalBlockSpacing->setValue(10);

        gridLayout_2->addWidget(horizontalBlockSpacing, 1, 1, 1, 1);

        label_4 = new QLabel(LayoutBlock);
        label_4->setObjectName("label_4");

        gridLayout_2->addWidget(label_4, 0, 2, 1, 1);

        horizontalEdgeSpacing = new QSpinBox(LayoutBlock);
        horizontalEdgeSpacing->setObjectName("horizontalEdgeSpacing");
        horizontalEdgeSpacing->setMinimum(1);
        horizontalEdgeSpacing->setMaximum(400);
        horizontalEdgeSpacing->setSingleStep(5);
        horizontalEdgeSpacing->setValue(10);

        gridLayout_2->addWidget(horizontalEdgeSpacing, 2, 1, 1, 1);

        label_3 = new QLabel(LayoutBlock);
        label_3->setObjectName("label_3");

        gridLayout_2->addWidget(label_3, 0, 1, 1, 1);

        verticalEdgeSpacing = new QSpinBox(LayoutBlock);
        verticalEdgeSpacing->setObjectName("verticalEdgeSpacing");
        verticalEdgeSpacing->setMinimum(1);
        verticalEdgeSpacing->setMaximum(400);
        verticalEdgeSpacing->setSingleStep(5);
        verticalEdgeSpacing->setValue(10);

        gridLayout_2->addWidget(verticalEdgeSpacing, 2, 2, 1, 1);

        verticalBlockSpacing = new QSpinBox(LayoutBlock);
        verticalBlockSpacing->setObjectName("verticalBlockSpacing");
        verticalBlockSpacing->setMaximum(400);
        verticalBlockSpacing->setSingleStep(10);
        verticalBlockSpacing->setValue(40);

        gridLayout_2->addWidget(verticalBlockSpacing, 1, 2, 1, 1);

        label = new QLabel(LayoutBlock);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 1, 0, 1, 1);

        label_2 = new QLabel(LayoutBlock);
        label_2->setObjectName("label_2");

        gridLayout_2->addWidget(label_2, 2, 0, 1, 1);


        verticalLayout_3->addWidget(LayoutBlock);

        BitmapExportBlock = new QGroupBox(GraphOptionsWidget);
        BitmapExportBlock->setObjectName("BitmapExportBlock");
        BitmapExportBlock->setFlat(true);
        verticalLayout_10 = new QVBoxLayout(BitmapExportBlock);
        verticalLayout_10->setObjectName("verticalLayout_10");
        verticalLayout_10->setContentsMargins(-1, 8, -1, -1);
        checkTransparent = new QCheckBox(BitmapExportBlock);
        checkTransparent->setObjectName("checkTransparent");

        verticalLayout_10->addWidget(checkTransparent);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        bitmapGraphScaleLabel = new QLabel(BitmapExportBlock);
        bitmapGraphScaleLabel->setObjectName("bitmapGraphScaleLabel");

        horizontalLayout_2->addWidget(bitmapGraphScaleLabel);

        bitmapGraphScale = new QDoubleSpinBox(BitmapExportBlock);
        bitmapGraphScale->setObjectName("bitmapGraphScale");
        bitmapGraphScale->setDecimals(0);
        bitmapGraphScale->setMinimum(100.000000000000000);
        bitmapGraphScale->setMaximum(30000.000000000000000);
        bitmapGraphScale->setSingleStep(50.000000000000000);

        horizontalLayout_2->addWidget(bitmapGraphScale);


        verticalLayout_10->addLayout(horizontalLayout_2);


        verticalLayout_3->addWidget(BitmapExportBlock);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        QWidget::setTabOrder(blockEntryCheckBox, blockShadowCheckBox);
        QWidget::setTabOrder(blockShadowCheckBox, graphOffsetCheckBox);
        QWidget::setTabOrder(graphOffsetCheckBox, maxColsSpinBox);
        QWidget::setTabOrder(maxColsSpinBox, horizontalBlockSpacing);
        QWidget::setTabOrder(horizontalBlockSpacing, verticalBlockSpacing);
        QWidget::setTabOrder(verticalBlockSpacing, horizontalEdgeSpacing);
        QWidget::setTabOrder(horizontalEdgeSpacing, verticalEdgeSpacing);
        QWidget::setTabOrder(verticalEdgeSpacing, checkTransparent);
        QWidget::setTabOrder(checkTransparent, bitmapGraphScale);

        retranslateUi(GraphOptionsWidget);

        QMetaObject::connectSlotsByName(GraphOptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *GraphOptionsWidget)
    {
        GraphOptionsWidget->setWindowTitle(QCoreApplication::translate("GraphOptionsWidget", "Graph", nullptr));
        GraphBlockOptions->setTitle(QCoreApplication::translate("GraphOptionsWidget", "Graph Block Options", nullptr));
#if QT_CONFIG(tooltip)
        blockEntryCheckBox->setToolTip(QCoreApplication::translate("GraphOptionsWidget", "The address of the first instruction of a graph block is shown in the header of the respective graph block", nullptr));
#endif // QT_CONFIG(tooltip)
        blockEntryCheckBox->setText(QCoreApplication::translate("GraphOptionsWidget", "Show address of the first instruction in each graph block", nullptr));
#if QT_CONFIG(tooltip)
        blockShadowCheckBox->setToolTip(QCoreApplication::translate("GraphOptionsWidget", "Draw a drop shadow behind each basic block in the graph view", nullptr));
#endif // QT_CONFIG(tooltip)
        blockShadowCheckBox->setText(QCoreApplication::translate("GraphOptionsWidget", "Show drop shadow behind each graph block", nullptr));
        graphOffsetCheckBox->setText(QCoreApplication::translate("GraphOptionsWidget", "Show offset for each instruction (graph.addr)", nullptr));
        maxColsLabel->setText(QCoreApplication::translate("GraphOptionsWidget", "Maximum Line Length:", nullptr));
        LayoutBlock->setTitle(QCoreApplication::translate("GraphOptionsWidget", "Graph Layout Options", nullptr));
        label_4->setText(QCoreApplication::translate("GraphOptionsWidget", "Vertical", nullptr));
        label_3->setText(QCoreApplication::translate("GraphOptionsWidget", "Horizontal", nullptr));
        label->setText(QCoreApplication::translate("GraphOptionsWidget", "Block spacing:", nullptr));
        label_2->setText(QCoreApplication::translate("GraphOptionsWidget", "Edge spacing", nullptr));
        BitmapExportBlock->setTitle(QCoreApplication::translate("GraphOptionsWidget", "Bitmap Export Options", nullptr));
        checkTransparent->setText(QCoreApplication::translate("GraphOptionsWidget", "Export Transparent Bitmap Graphs", nullptr));
        bitmapGraphScaleLabel->setText(QCoreApplication::translate("GraphOptionsWidget", "Graph Bitmap Export Scale: ", nullptr));
        bitmapGraphScale->setSuffix(QCoreApplication::translate("GraphOptionsWidget", "%", nullptr));
    } // retranslateUi

};

namespace Ui {
    class GraphOptionsWidget: public Ui_GraphOptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_GRAPHOPTIONSWIDGET_H
