/********************************************************************************
** Form generated from reading UI file 'EditVariablesDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITVARIABLESDIALOG_H
#define UI_EDITVARIABLESDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_EditVariablesDialog
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *label_2;
    QComboBox *dropdownLocalVars;
    QLineEdit *nameEdit;
    QLabel *nameLabel;
    QLabel *labelSetTypeTo;
    QComboBox *typeComboBox;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *EditVariablesDialog)
    {
        if (EditVariablesDialog->objectName().isEmpty())
            EditVariablesDialog->setObjectName("EditVariablesDialog");
        EditVariablesDialog->resize(435, 137);
        verticalLayout = new QVBoxLayout(EditVariablesDialog);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label_2 = new QLabel(EditVariablesDialog);
        label_2->setObjectName("label_2");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_2);

        dropdownLocalVars = new QComboBox(EditVariablesDialog);
        dropdownLocalVars->setObjectName("dropdownLocalVars");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, dropdownLocalVars);

        nameEdit = new QLineEdit(EditVariablesDialog);
        nameEdit->setObjectName("nameEdit");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, nameEdit);

        nameLabel = new QLabel(EditVariablesDialog);
        nameLabel->setObjectName("nameLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, nameLabel);

        labelSetTypeTo = new QLabel(EditVariablesDialog);
        labelSetTypeTo->setObjectName("labelSetTypeTo");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, labelSetTypeTo);

        typeComboBox = new QComboBox(EditVariablesDialog);
        typeComboBox->setObjectName("typeComboBox");
        typeComboBox->setEditable(true);
        typeComboBox->setMaxVisibleItems(15);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, typeComboBox);


        verticalLayout->addLayout(formLayout);

        buttonBox = new QDialogButtonBox(EditVariablesDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(EditVariablesDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, EditVariablesDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, EditVariablesDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(EditVariablesDialog);
    } // setupUi

    void retranslateUi(QDialog *EditVariablesDialog)
    {
        EditVariablesDialog->setWindowTitle(QCoreApplication::translate("EditVariablesDialog", "Dialog", nullptr));
        label_2->setText(QCoreApplication::translate("EditVariablesDialog", "Modify:", nullptr));
        nameLabel->setText(QCoreApplication::translate("EditVariablesDialog", "Name:", nullptr));
        labelSetTypeTo->setText(QCoreApplication::translate("EditVariablesDialog", "Type:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class EditVariablesDialog: public Ui_EditVariablesDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_EDITVARIABLESDIALOG_H
