/********************************************************************************
** Form generated from reading UI file 'CustomCommandWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CUSTOMCOMMANDWIDGET_H
#define UI_CUSTOMCOMMANDWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CustomCommandWidget
{
public:
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *hLayoutInput;
    QLineEdit *commandLineEdit;
    QPushButton *runButton;
    QCheckBox *wrapCheckBox;
    QCheckBox *scrollTopCheckBox;
    QComboBox *intervalComboBox;
    QPlainTextEdit *outputTextEdit;

    void setupUi(QDockWidget *CustomCommandWidget)
    {
        if (CustomCommandWidget->objectName().isEmpty())
            CustomCommandWidget->setObjectName("CustomCommandWidget");
        CustomCommandWidget->resize(400, 300);
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        verticalLayout = new QVBoxLayout(dockWidgetContents);
        verticalLayout->setSpacing(5);
        verticalLayout->setObjectName("verticalLayout");
        hLayoutInput = new QHBoxLayout();
        hLayoutInput->setObjectName("hLayoutInput");
        commandLineEdit = new QLineEdit(dockWidgetContents);
        commandLineEdit->setObjectName("commandLineEdit");

        hLayoutInput->addWidget(commandLineEdit);

        runButton = new QPushButton(dockWidgetContents);
        runButton->setObjectName("runButton");

        hLayoutInput->addWidget(runButton);

        wrapCheckBox = new QCheckBox(dockWidgetContents);
        wrapCheckBox->setObjectName("wrapCheckBox");
        wrapCheckBox->setChecked(false);

        hLayoutInput->addWidget(wrapCheckBox);

        scrollTopCheckBox = new QCheckBox(dockWidgetContents);
        scrollTopCheckBox->setObjectName("scrollTopCheckBox");
        scrollTopCheckBox->setChecked(false);

        hLayoutInput->addWidget(scrollTopCheckBox);

        intervalComboBox = new QComboBox(dockWidgetContents);
        intervalComboBox->addItem(QString());
        intervalComboBox->addItem(QString());
        intervalComboBox->addItem(QString());
        intervalComboBox->addItem(QString());
        intervalComboBox->addItem(QString());
        intervalComboBox->addItem(QString());
        intervalComboBox->addItem(QString());
        intervalComboBox->addItem(QString());
        intervalComboBox->addItem(QString());
        intervalComboBox->setObjectName("intervalComboBox");

        hLayoutInput->addWidget(intervalComboBox);


        verticalLayout->addLayout(hLayoutInput);

        outputTextEdit = new QPlainTextEdit(dockWidgetContents);
        outputTextEdit->setObjectName("outputTextEdit");
        outputTextEdit->setReadOnly(true);
        outputTextEdit->setLineWrapMode(QPlainTextEdit::NoWrap);
        outputTextEdit->setTextInteractionFlags(Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);
        QFont font;
        font.setFamilies({QString::fromUtf8("Monospace")});
        outputTextEdit->setFont(font);

        verticalLayout->addWidget(outputTextEdit);

        CustomCommandWidget->setWidget(dockWidgetContents);

        retranslateUi(CustomCommandWidget);

        QMetaObject::connectSlotsByName(CustomCommandWidget);
    } // setupUi

    void retranslateUi(QDockWidget *CustomCommandWidget)
    {
        CustomCommandWidget->setWindowTitle(QCoreApplication::translate("CustomCommandWidget", "Custom Command", nullptr));
        commandLineEdit->setPlaceholderText(QCoreApplication::translate("CustomCommandWidget", "Enter command", nullptr));
        runButton->setText(QCoreApplication::translate("CustomCommandWidget", "Run", nullptr));
        wrapCheckBox->setText(QCoreApplication::translate("CustomCommandWidget", "Wrap Lines", nullptr));
        scrollTopCheckBox->setText(QCoreApplication::translate("CustomCommandWidget", "Scroll to Top", nullptr));
        intervalComboBox->setItemText(0, QCoreApplication::translate("CustomCommandWidget", "0", nullptr));
        intervalComboBox->setItemText(1, QCoreApplication::translate("CustomCommandWidget", "0.1", nullptr));
        intervalComboBox->setItemText(2, QCoreApplication::translate("CustomCommandWidget", "0.5", nullptr));
        intervalComboBox->setItemText(3, QCoreApplication::translate("CustomCommandWidget", "1", nullptr));
        intervalComboBox->setItemText(4, QCoreApplication::translate("CustomCommandWidget", "2", nullptr));
        intervalComboBox->setItemText(5, QCoreApplication::translate("CustomCommandWidget", "5", nullptr));
        intervalComboBox->setItemText(6, QCoreApplication::translate("CustomCommandWidget", "10", nullptr));
        intervalComboBox->setItemText(7, QCoreApplication::translate("CustomCommandWidget", "30", nullptr));
        intervalComboBox->setItemText(8, QCoreApplication::translate("CustomCommandWidget", "60", nullptr));

#if QT_CONFIG(tooltip)
        intervalComboBox->setToolTip(QCoreApplication::translate("CustomCommandWidget", "Auto-run interval (seconds); 0 disables", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class CustomCommandWidget: public Ui_CustomCommandWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CUSTOMCOMMANDWIDGET_H
