/********************************************************************************
** Form generated from reading UI file 'NewFileDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWFILEDIALOG_H
#define UI_NEWFILEDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableView>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "ClickableSvgWidget.h"

QT_BEGIN_NAMESPACE

class Ui_NewFileDialog
{
public:
    QAction *actionRemove_item;
    QAction *actionClear_all;
    QAction *actionRemove_project;
    QVBoxLayout *verticalLayout;
    QVBoxLayout *verticalLayout_6;
    ClickableSvgWidget *logoSvgWidget;
    QVBoxLayout *verticalLayout_3;
    QFrame *frame;
    QVBoxLayout *verticalLayout_2;
    QTabWidget *tabWidget;
    QWidget *filesTab;
    QVBoxLayout *verticalLayout_4;
    QGridLayout *gridLayout;
    QPushButton *selectFileButton;
    QLineEdit *newFileEdit;
    QComboBox *ioPlugin;
    QListWidget *recentsListWidget;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *checkBox_FilelessOpen;
    QPushButton *loadFileButton;
    QWidget *shellcodeTab;
    QVBoxLayout *shellcodeLayout;
    QHBoxLayout *baseAddressLayout;
    QLabel *baseAddressLabel;
    QLineEdit *baseAddressLineEdit;
    QPlainTextEdit *shellcodeText;
    QHBoxLayout *shellcodeLayout_1;
    QSpacerItem *shellcodeSpacer;
    QPushButton *shellcodeButton;
    QWidget *projectsTab;
    QVBoxLayout *verticalLayout_5;
    QGridLayout *gridLayout_2;
    QPushButton *selectProjectsDirButton;
    QLineEdit *projectsDirEdit;
    QListWidget *projectsListWidget;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *importProjectButton;
    QPushButton *exportProjectButton;
    QSpacerItem *horizontalSpacer_3;
    QPushButton *loadProjectButton;
    QWidget *attachTab;
    QVBoxLayout *attachLayout;
    QLineEdit *attachFilterEdit;
    QTreeView *attachProcView;
    QHBoxLayout *attachBottomLayout;
    QCheckBox *interruptCheckBox;
    QSpacerItem *attachSpacer;
    QPushButton *refreshProcessesButton;
    QPushButton *attachButton;
    QWidget *sha256Tab;
    QVBoxLayout *sha256Layout;
    QLineEdit *sha256FilterEdit;
    QTableView *sha256TableView;
    QHBoxLayout *sha256BottomLayout;
    QPushButton *sha256ScanButton;
    QSpacerItem *sha256Spacer;
    QPushButton *sha256LookupButton;
    QPushButton *sha256DeleteButton;
    QPushButton *sha256OpenButton;

    void setupUi(QDialog *NewFileDialog)
    {
        if (NewFileDialog->objectName().isEmpty())
            NewFileDialog->setObjectName("NewFileDialog");
        NewFileDialog->resize(451, 599);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(NewFileDialog->sizePolicy().hasHeightForWidth());
        NewFileDialog->setSizePolicy(sizePolicy);
        actionRemove_item = new QAction(NewFileDialog);
        actionRemove_item->setObjectName("actionRemove_item");
        actionClear_all = new QAction(NewFileDialog);
        actionClear_all->setObjectName("actionClear_all");
        actionRemove_project = new QAction(NewFileDialog);
        actionRemove_project->setObjectName("actionRemove_project");
        verticalLayout = new QVBoxLayout(NewFileDialog);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout_6 = new QVBoxLayout();
        verticalLayout_6->setObjectName("verticalLayout_6");
        verticalLayout_6->setContentsMargins(2, 2, 2, 2);
        logoSvgWidget = new ClickableSvgWidget(NewFileDialog);
        logoSvgWidget->setObjectName("logoSvgWidget");
        logoSvgWidget->setMinimumSize(QSize(88, 88));
        logoSvgWidget->setMaximumSize(QSize(88, 88));

        verticalLayout_6->addWidget(logoSvgWidget, 0, Qt::AlignmentFlag::AlignHCenter);


        verticalLayout->addLayout(verticalLayout_6);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setSpacing(10);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(-1, 0, 0, -1);
        frame = new QFrame(NewFileDialog);
        frame->setObjectName("frame");
        sizePolicy.setHeightForWidth(frame->sizePolicy().hasHeightForWidth());
        frame->setSizePolicy(sizePolicy);
        frame->setMinimumSize(QSize(0, 0));
        frame->setFrameShape(QFrame::Shape::NoFrame);
        frame->setFrameShadow(QFrame::Shadow::Plain);
        verticalLayout_2 = new QVBoxLayout(frame);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        tabWidget = new QTabWidget(frame);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setStyleSheet(QString::fromUtf8("QTabWidget::tab-bar { alignment: center }"));
        filesTab = new QWidget();
        filesTab->setObjectName("filesTab");
        verticalLayout_4 = new QVBoxLayout(filesTab);
        verticalLayout_4->setObjectName("verticalLayout_4");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        gridLayout->setSizeConstraint(QLayout::SizeConstraint::SetDefaultConstraint);
        gridLayout->setHorizontalSpacing(5);
        selectFileButton = new QPushButton(filesTab);
        selectFileButton->setObjectName("selectFileButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(selectFileButton->sizePolicy().hasHeightForWidth());
        selectFileButton->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(selectFileButton, 0, 2, 1, 1);

        newFileEdit = new QLineEdit(filesTab);
        newFileEdit->setObjectName("newFileEdit");
        newFileEdit->setFrame(false);

        gridLayout->addWidget(newFileEdit, 0, 1, 1, 1);

        ioPlugin = new QComboBox(filesTab);
        ioPlugin->setObjectName("ioPlugin");

        gridLayout->addWidget(ioPlugin, 0, 0, 1, 1);


        verticalLayout_4->addLayout(gridLayout);

        recentsListWidget = new QListWidget(filesTab);
        recentsListWidget->setObjectName("recentsListWidget");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(1);
        sizePolicy2.setHeightForWidth(recentsListWidget->sizePolicy().hasHeightForWidth());
        recentsListWidget->setSizePolicy(sizePolicy2);
        recentsListWidget->setContextMenuPolicy(Qt::ContextMenuPolicy::ActionsContextMenu);
        recentsListWidget->setFrameShape(QFrame::Shape::NoFrame);
        recentsListWidget->setFrameShadow(QFrame::Shadow::Plain);
        recentsListWidget->setLineWidth(0);
        recentsListWidget->setIconSize(QSize(48, 48));
        recentsListWidget->setVerticalScrollMode(QAbstractItemView::ScrollMode::ScrollPerPixel);
        recentsListWidget->setResizeMode(QListView::ResizeMode::Adjust);
        recentsListWidget->setSpacing(5);
        recentsListWidget->setViewMode(QListView::ViewMode::ListMode);
        recentsListWidget->setUniformItemSizes(false);
        recentsListWidget->setWordWrap(false);
        recentsListWidget->setSelectionRectVisible(true);
        recentsListWidget->setSortingEnabled(false);

        verticalLayout_4->addWidget(recentsListWidget);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        checkBox_FilelessOpen = new QCheckBox(filesTab);
        checkBox_FilelessOpen->setObjectName("checkBox_FilelessOpen");

        horizontalLayout->addWidget(checkBox_FilelessOpen);

        loadFileButton = new QPushButton(filesTab);
        loadFileButton->setObjectName("loadFileButton");

        horizontalLayout->addWidget(loadFileButton);


        verticalLayout_4->addLayout(horizontalLayout);

        tabWidget->addTab(filesTab, QString());
        shellcodeTab = new QWidget();
        shellcodeTab->setObjectName("shellcodeTab");
        shellcodeLayout = new QVBoxLayout(shellcodeTab);
        shellcodeLayout->setObjectName("shellcodeLayout");
        baseAddressLayout = new QHBoxLayout();
        baseAddressLayout->setObjectName("baseAddressLayout");
        baseAddressLabel = new QLabel(shellcodeTab);
        baseAddressLabel->setObjectName("baseAddressLabel");
        baseAddressLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        baseAddressLayout->addWidget(baseAddressLabel);

        baseAddressLineEdit = new QLineEdit(shellcodeTab);
        baseAddressLineEdit->setObjectName("baseAddressLineEdit");
        baseAddressLineEdit->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        baseAddressLayout->addWidget(baseAddressLineEdit);


        shellcodeLayout->addLayout(baseAddressLayout);

        shellcodeText = new QPlainTextEdit(shellcodeTab);
        shellcodeText->setObjectName("shellcodeText");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(1);
        sizePolicy3.setVerticalStretch(1);
        sizePolicy3.setHeightForWidth(shellcodeText->sizePolicy().hasHeightForWidth());
        shellcodeText->setSizePolicy(sizePolicy3);

        shellcodeLayout->addWidget(shellcodeText);

        shellcodeLayout_1 = new QHBoxLayout();
        shellcodeLayout_1->setObjectName("shellcodeLayout_1");
        shellcodeSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        shellcodeLayout_1->addItem(shellcodeSpacer);

        shellcodeButton = new QPushButton(shellcodeTab);
        shellcodeButton->setObjectName("shellcodeButton");

        shellcodeLayout_1->addWidget(shellcodeButton);


        shellcodeLayout->addLayout(shellcodeLayout_1);

        tabWidget->addTab(shellcodeTab, QString());
        projectsTab = new QWidget();
        projectsTab->setObjectName("projectsTab");
        verticalLayout_5 = new QVBoxLayout(projectsTab);
        verticalLayout_5->setObjectName("verticalLayout_5");
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setSizeConstraint(QLayout::SizeConstraint::SetDefaultConstraint);
        gridLayout_2->setHorizontalSpacing(5);
        selectProjectsDirButton = new QPushButton(projectsTab);
        selectProjectsDirButton->setObjectName("selectProjectsDirButton");
        sizePolicy1.setHeightForWidth(selectProjectsDirButton->sizePolicy().hasHeightForWidth());
        selectProjectsDirButton->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(selectProjectsDirButton, 1, 1, 1, 1);

        projectsDirEdit = new QLineEdit(projectsTab);
        projectsDirEdit->setObjectName("projectsDirEdit");
        projectsDirEdit->setFrame(false);
        projectsDirEdit->setReadOnly(true);

        gridLayout_2->addWidget(projectsDirEdit, 1, 0, 1, 1);


        verticalLayout_5->addLayout(gridLayout_2);

        projectsListWidget = new QListWidget(projectsTab);
        projectsListWidget->setObjectName("projectsListWidget");
        sizePolicy2.setHeightForWidth(projectsListWidget->sizePolicy().hasHeightForWidth());
        projectsListWidget->setSizePolicy(sizePolicy2);
        projectsListWidget->setContextMenuPolicy(Qt::ContextMenuPolicy::ActionsContextMenu);
        projectsListWidget->setFrameShape(QFrame::Shape::NoFrame);
        projectsListWidget->setFrameShadow(QFrame::Shadow::Plain);
        projectsListWidget->setLineWidth(0);
        projectsListWidget->setIconSize(QSize(48, 48));
        projectsListWidget->setVerticalScrollMode(QAbstractItemView::ScrollMode::ScrollPerPixel);
        projectsListWidget->setResizeMode(QListView::ResizeMode::Adjust);
        projectsListWidget->setSpacing(5);
        projectsListWidget->setViewMode(QListView::ViewMode::ListMode);
        projectsListWidget->setUniformItemSizes(false);
        projectsListWidget->setWordWrap(false);
        projectsListWidget->setSelectionRectVisible(true);

        verticalLayout_5->addWidget(projectsListWidget);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        importProjectButton = new QPushButton(projectsTab);
        importProjectButton->setObjectName("importProjectButton");

        horizontalLayout_2->addWidget(importProjectButton);

        exportProjectButton = new QPushButton(projectsTab);
        exportProjectButton->setObjectName("exportProjectButton");

        horizontalLayout_2->addWidget(exportProjectButton);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);

        loadProjectButton = new QPushButton(projectsTab);
        loadProjectButton->setObjectName("loadProjectButton");

        horizontalLayout_2->addWidget(loadProjectButton);


        verticalLayout_5->addLayout(horizontalLayout_2);

        tabWidget->addTab(projectsTab, QString());
        attachTab = new QWidget();
        attachTab->setObjectName("attachTab");
        attachLayout = new QVBoxLayout(attachTab);
        attachLayout->setObjectName("attachLayout");
        attachFilterEdit = new QLineEdit(attachTab);
        attachFilterEdit->setObjectName("attachFilterEdit");

        attachLayout->addWidget(attachFilterEdit);

        attachProcView = new QTreeView(attachTab);
        attachProcView->setObjectName("attachProcView");
        sizePolicy2.setHeightForWidth(attachProcView->sizePolicy().hasHeightForWidth());
        attachProcView->setSizePolicy(sizePolicy2);
        attachProcView->setFrameShape(QFrame::Shape::NoFrame);
        attachProcView->setRootIsDecorated(false);
        attachProcView->setSortingEnabled(true);
        attachProcView->setAllColumnsShowFocus(true);

        attachLayout->addWidget(attachProcView);

        attachBottomLayout = new QHBoxLayout();
        attachBottomLayout->setObjectName("attachBottomLayout");
        interruptCheckBox = new QCheckBox(attachTab);
        interruptCheckBox->setObjectName("interruptCheckBox");
        interruptCheckBox->setChecked(true);

        attachBottomLayout->addWidget(interruptCheckBox);

        attachSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        attachBottomLayout->addItem(attachSpacer);

        refreshProcessesButton = new QPushButton(attachTab);
        refreshProcessesButton->setObjectName("refreshProcessesButton");

        attachBottomLayout->addWidget(refreshProcessesButton);

        attachButton = new QPushButton(attachTab);
        attachButton->setObjectName("attachButton");
        attachButton->setEnabled(false);

        attachBottomLayout->addWidget(attachButton);


        attachLayout->addLayout(attachBottomLayout);

        tabWidget->addTab(attachTab, QString());
        sha256Tab = new QWidget();
        sha256Tab->setObjectName("sha256Tab");
        sha256Layout = new QVBoxLayout(sha256Tab);
        sha256Layout->setObjectName("sha256Layout");
        sha256FilterEdit = new QLineEdit(sha256Tab);
        sha256FilterEdit->setObjectName("sha256FilterEdit");

        sha256Layout->addWidget(sha256FilterEdit);

        sha256TableView = new QTableView(sha256Tab);
        sha256TableView->setObjectName("sha256TableView");
        sizePolicy2.setHeightForWidth(sha256TableView->sizePolicy().hasHeightForWidth());
        sha256TableView->setSizePolicy(sizePolicy2);
        sha256TableView->setFrameShape(QFrame::Shape::NoFrame);
        sha256TableView->setSortingEnabled(true);

        sha256Layout->addWidget(sha256TableView);

        sha256BottomLayout = new QHBoxLayout();
        sha256BottomLayout->setObjectName("sha256BottomLayout");
        sha256ScanButton = new QPushButton(sha256Tab);
        sha256ScanButton->setObjectName("sha256ScanButton");

        sha256BottomLayout->addWidget(sha256ScanButton);

        sha256Spacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        sha256BottomLayout->addItem(sha256Spacer);

        sha256LookupButton = new QPushButton(sha256Tab);
        sha256LookupButton->setObjectName("sha256LookupButton");

        sha256BottomLayout->addWidget(sha256LookupButton);

        sha256DeleteButton = new QPushButton(sha256Tab);
        sha256DeleteButton->setObjectName("sha256DeleteButton");

        sha256BottomLayout->addWidget(sha256DeleteButton);

        sha256OpenButton = new QPushButton(sha256Tab);
        sha256OpenButton->setObjectName("sha256OpenButton");

        sha256BottomLayout->addWidget(sha256OpenButton);


        sha256Layout->addLayout(sha256BottomLayout);

        tabWidget->addTab(sha256Tab, QString());

        verticalLayout_2->addWidget(tabWidget);


        verticalLayout_3->addWidget(frame);


        verticalLayout->addLayout(verticalLayout_3);


        retranslateUi(NewFileDialog);

        tabWidget->setCurrentIndex(0);
        loadFileButton->setDefault(true);


        QMetaObject::connectSlotsByName(NewFileDialog);
    } // setupUi

    void retranslateUi(QDialog *NewFileDialog)
    {
        NewFileDialog->setWindowTitle(QCoreApplication::translate("NewFileDialog", "Iaito", nullptr));
        actionRemove_item->setText(QCoreApplication::translate("NewFileDialog", "Remove item", nullptr));
        actionClear_all->setText(QCoreApplication::translate("NewFileDialog", "Clear all", nullptr));
        actionRemove_project->setText(QCoreApplication::translate("NewFileDialog", "Delete project", nullptr));
        selectFileButton->setText(QCoreApplication::translate("NewFileDialog", "Select", nullptr));
        checkBox_FilelessOpen->setText(QCoreApplication::translate("NewFileDialog", "Don't open any file", nullptr));
        loadFileButton->setText(QCoreApplication::translate("NewFileDialog", "Start", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(filesTab), QCoreApplication::translate("NewFileDialog", "File", nullptr));
        baseAddressLabel->setText(QCoreApplication::translate("NewFileDialog", "Base address:", nullptr));
        baseAddressLineEdit->setPlaceholderText(QCoreApplication::translate("NewFileDialog", "0x0000_0000", nullptr));
        shellcodeButton->setText(QCoreApplication::translate("NewFileDialog", "Start", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(shellcodeTab), QCoreApplication::translate("NewFileDialog", "Hex", nullptr));
        selectProjectsDirButton->setText(QCoreApplication::translate("NewFileDialog", "Select", nullptr));
        importProjectButton->setText(QCoreApplication::translate("NewFileDialog", "Import", nullptr));
        exportProjectButton->setText(QCoreApplication::translate("NewFileDialog", "Export", nullptr));
        loadProjectButton->setText(QCoreApplication::translate("NewFileDialog", "Start", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(projectsTab), QCoreApplication::translate("NewFileDialog", "Project", nullptr));
        attachFilterEdit->setPlaceholderText(QCoreApplication::translate("NewFileDialog", "Filter processes...", nullptr));
        interruptCheckBox->setText(QCoreApplication::translate("NewFileDialog", "Break on attach", nullptr));
        refreshProcessesButton->setText(QCoreApplication::translate("NewFileDialog", "Refresh", nullptr));
        attachButton->setText(QCoreApplication::translate("NewFileDialog", "Attach", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(attachTab), QCoreApplication::translate("NewFileDialog", "Attach", nullptr));
        sha256FilterEdit->setPlaceholderText(QCoreApplication::translate("NewFileDialog", "Filter by name or hash...", nullptr));
        sha256ScanButton->setText(QCoreApplication::translate("NewFileDialog", "Scan folder...", nullptr));
        sha256LookupButton->setText(QCoreApplication::translate("NewFileDialog", "Lookup", nullptr));
        sha256DeleteButton->setText(QCoreApplication::translate("NewFileDialog", "Delete", nullptr));
        sha256OpenButton->setText(QCoreApplication::translate("NewFileDialog", "Open", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(sha256Tab), QCoreApplication::translate("NewFileDialog", "Sha256", nullptr));
    } // retranslateUi

};

namespace Ui {
    class NewFileDialog: public Ui_NewFileDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NEWFILEDIALOG_H
