/********************************************************************************
** Form generated from reading UI file 'MainWindow.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINWINDOW_H
#define UI_MAINWINDOW_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMenu>
#include <QtWidgets/QMenuBar>
#include <QtWidgets/QToolBar>

QT_BEGIN_NAMESPACE

class Ui_MainWindow
{
public:
    QAction *actionDefault;
    QAction *actionZen;
    QAction *actionAbout;
    QAction *actionIssue;
    QAction *actionR2pm;
    QAction *actionNew;
    QAction *actionClose;
    QAction *actionSave_workspace;
    QAction *actionBook;
    QAction *actionFortune;
    QAction *actionWebsite;
    QAction *actionCheckForUpdates;
    QAction *actionMap;
    QAction *actionManageAddressSpace;
    QAction *actionSave;
    QAction *actionCut;
    QAction *actionCopy;
    QAction *actionPaste;
    QAction *actionDelete;
    QAction *actionSelect_all;
    QAction *actionFind;
    QAction *actionFind_next;
    QAction *actionFind_previous;
    QAction *actionBackward;
    QAction *actionForward;
    QAction *actionTheme;
    QAction *actionTabs;
    QAction *actionRefresh_Panels;
    QAction *actionTabs_on_Top;
    QAction *actionDark_Theme;
    QAction *actionLoad_workspace;
    QAction *actionWhite_Theme;
    QAction *actionBindiff;
    QAction *actionAnalysis;
    QAction *actionTest_menu;
    QAction *actionHexCopy_Hexpair;
    QAction *actionHexCopy_Text;
    QAction *actionHexCopy_ASCII;
    QAction *actionHexInsert_String;
    QAction *actionHexInsert_Hex;
    QAction *actionHexEdit;
    QAction *actionHexPaste;
    QAction *actionDisas_ShowHideBytes;
    QAction *actionDisasSwitch_case;
    QAction *actionDisasCopy_All;
    QAction *actionDisasCopy_Bytes;
    QAction *actionDisasCopy_Disasm;
    QAction *actionDisplayOptions;
    QAction *actionStart_Web_Server;
    QAction *action1column;
    QAction *action2columns;
    QAction *action4columns;
    QAction *action8columns;
    QAction *action16columns;
    QAction *action32columns;
    QAction *action64columns;
    QAction *actionSyntax_AT_T_Intel;
    QAction *actionFunctionsRename;
    QAction *actionFunctionsUndefine;
    QAction *actionDisasRename;
    QAction *actionDisasmUndefine;
    QAction *actionDisasAdd_comment;
    QAction *actionhide_bottomPannel;
    QAction *actionRun_Script;
    QAction *actionRunR2jsScript;
    QAction *actionScripts;
    QAction *actionReset_settings;
    QAction *actionQuit;
    QAction *actionExports;
    QAction *actionRefresh_contents;
    QAction *actionHighlight;
    QAction *actionDisplay_Esil;
    QAction *actionDisplay_Decompiler;
    QAction *actionDisplay_Offsets;
    QAction *actionSettings;
    QAction *actionPackageManagerPrefs;
    QAction *actionSaveAs;
    QAction *actionGraph;
    QAction *actionImportPDB;
    QAction *actionImportSymbols;
    QAction *actionAnalyze;
    QAction *actionAnalyzeFunction;
    QAction *actionAutonameAll;
    QAction *actionAnalysisSettings;
    QAction *actionSwitchJumpTable;
    QAction *actionExport_as_code;
    QAction *actionDump;
    QAction *actionImportDWARF;
    QAction *actionImportFLIRT;
    QAction *actionImportProjectArchive;
    QAction *actionExportDWARF;
    QAction *actionExportProjectArchive;
    QAction *actionExtraHexdump;
    QAction *actionExtraDecompiler;
    QAction *actionExtraDisassembly;
    QAction *actionExtraGraph;
    QAction *actionAddCustomCommand;
    QAction *actionGrouped_dock_dragging;
    QAction *actionZoomIn;
    QAction *actionZoomOut;
    QAction *actionZoomReset;
    QAction *actionCommitChanges;
    QAction *actionUndoWrite;
    QAction *actionRedoWrite;
    QAction *actionPatchInstruction;
    QAction *actionPatchString;
    QAction *actionPatchBytes;
    QAction *actionWriteMode;
    QAction *actionCacheMode;
    QAction *actionReadOnly;
    QAction *actionSaveLayout;
    QAction *actionManageLayouts;
    QAction *actionFiles;
    QAction *actionMaps;
    QAction *actionEntropy;
    QAction *actionBinaries;
    QAction *actionNavigation_Bar;
    QMenu *addExtraWidgets;
    QMenuBar *menuBar;
    QMenu *menuFile;
    QMenu *menuImport;
    QMenu *menuExport;
    QMenu *menuRun;
    QMenu *menuView;
    QMenu *menuZoom;
    QMenu *menuAnalysis;
    QMenu *menuHelp;
    QMenu *menuEdit;
    QMenu *menuSetMode;
    QMenu *menuCode;
    QMenu *menuPlugins;
    QMenu *menuTools;
    QMenu *menuWindows;
    QMenu *menuWindowLayout;
    QMenu *menuLayouts;
    QMenu *menuAddInfoWidgets;
    QMenu *menuAddIoWidgets;
    QMenu *menuAddDebugWidgets;
    QMenu *menuAddAnother;
    QMenu *menuDebug;
    QToolBar *mainToolBar;

    void setupUi(QMainWindow *MainWindow)
    {
        if (MainWindow->objectName().isEmpty())
            MainWindow->setObjectName("MainWindow");
        MainWindow->resize(1013, 606);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(MainWindow->sizePolicy().hasHeightForWidth());
        MainWindow->setSizePolicy(sizePolicy);
        MainWindow->setWindowTitle(QString::fromUtf8("iaito"));
        MainWindow->setStyleSheet(QString::fromUtf8(""));
        MainWindow->setDocumentMode(true);
        MainWindow->setDockNestingEnabled(true);
        actionDefault = new QAction(MainWindow);
        actionDefault->setObjectName("actionDefault");
        actionZen = new QAction(MainWindow);
        actionZen->setObjectName("actionZen");
        actionAbout = new QAction(MainWindow);
        actionAbout->setObjectName("actionAbout");
        actionIssue = new QAction(MainWindow);
        actionIssue->setObjectName("actionIssue");
        actionR2pm = new QAction(MainWindow);
        actionR2pm->setObjectName("actionR2pm");
        actionNew = new QAction(MainWindow);
        actionNew->setObjectName("actionNew");
        actionClose = new QAction(MainWindow);
        actionClose->setObjectName("actionClose");
        actionSave_workspace = new QAction(MainWindow);
        actionSave_workspace->setObjectName("actionSave_workspace");
        actionBook = new QAction(MainWindow);
        actionBook->setObjectName("actionBook");
        actionFortune = new QAction(MainWindow);
        actionFortune->setObjectName("actionFortune");
        actionWebsite = new QAction(MainWindow);
        actionWebsite->setObjectName("actionWebsite");
        actionCheckForUpdates = new QAction(MainWindow);
        actionCheckForUpdates->setObjectName("actionCheckForUpdates");
        actionMap = new QAction(MainWindow);
        actionMap->setObjectName("actionMap");
        actionManageAddressSpace = new QAction(MainWindow);
        actionManageAddressSpace->setObjectName("actionManageAddressSpace");
        actionSave = new QAction(MainWindow);
        actionSave->setObjectName("actionSave");
        actionCut = new QAction(MainWindow);
        actionCut->setObjectName("actionCut");
        actionCopy = new QAction(MainWindow);
        actionCopy->setObjectName("actionCopy");
        actionPaste = new QAction(MainWindow);
        actionPaste->setObjectName("actionPaste");
        actionDelete = new QAction(MainWindow);
        actionDelete->setObjectName("actionDelete");
        actionSelect_all = new QAction(MainWindow);
        actionSelect_all->setObjectName("actionSelect_all");
        actionFind = new QAction(MainWindow);
        actionFind->setObjectName("actionFind");
        actionFind_next = new QAction(MainWindow);
        actionFind_next->setObjectName("actionFind_next");
        actionFind_previous = new QAction(MainWindow);
        actionFind_previous->setObjectName("actionFind_previous");
        actionBackward = new QAction(MainWindow);
        actionBackward->setObjectName("actionBackward");
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/img/icons/arrow_left.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionBackward->setIcon(icon);
        actionForward = new QAction(MainWindow);
        actionForward->setObjectName("actionForward");
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/img/icons/arrow_right.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionForward->setIcon(icon1);
        actionTheme = new QAction(MainWindow);
        actionTheme->setObjectName("actionTheme");
        actionTheme->setCheckable(false);
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/img/icons/themes.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionTheme->setIcon(icon2);
        actionTheme->setAutoRepeat(false);
        actionTheme->setMenuRole(QAction::PreferencesRole);
        actionTabs = new QAction(MainWindow);
        actionTabs->setObjectName("actionTabs");
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/img/icons/tabs.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionTabs->setIcon(icon3);
        actionRefresh_Panels = new QAction(MainWindow);
        actionRefresh_Panels->setObjectName("actionRefresh_Panels");
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/img/icons/spin.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionRefresh_Panels->setIcon(icon4);
        actionTabs_on_Top = new QAction(MainWindow);
        actionTabs_on_Top->setObjectName("actionTabs_on_Top");
        actionTabs_on_Top->setCheckable(true);
        actionDark_Theme = new QAction(MainWindow);
        actionDark_Theme->setObjectName("actionDark_Theme");
        actionLoad_workspace = new QAction(MainWindow);
        actionLoad_workspace->setObjectName("actionLoad_workspace");
        actionWhite_Theme = new QAction(MainWindow);
        actionWhite_Theme->setObjectName("actionWhite_Theme");
        actionBindiff = new QAction(MainWindow);
        actionBindiff->setObjectName("actionBindiff");
        actionAnalysis = new QAction(MainWindow);
        actionAnalysis->setObjectName("actionAnalysis");
        actionTest_menu = new QAction(MainWindow);
        actionTest_menu->setObjectName("actionTest_menu");
        actionHexCopy_Hexpair = new QAction(MainWindow);
        actionHexCopy_Hexpair->setObjectName("actionHexCopy_Hexpair");
        actionHexCopy_Text = new QAction(MainWindow);
        actionHexCopy_Text->setObjectName("actionHexCopy_Text");
        actionHexCopy_ASCII = new QAction(MainWindow);
        actionHexCopy_ASCII->setObjectName("actionHexCopy_ASCII");
        actionHexInsert_String = new QAction(MainWindow);
        actionHexInsert_String->setObjectName("actionHexInsert_String");
        actionHexInsert_Hex = new QAction(MainWindow);
        actionHexInsert_Hex->setObjectName("actionHexInsert_Hex");
        actionHexEdit = new QAction(MainWindow);
        actionHexEdit->setObjectName("actionHexEdit");
        actionHexPaste = new QAction(MainWindow);
        actionHexPaste->setObjectName("actionHexPaste");
        actionDisas_ShowHideBytes = new QAction(MainWindow);
        actionDisas_ShowHideBytes->setObjectName("actionDisas_ShowHideBytes");
        actionDisasSwitch_case = new QAction(MainWindow);
        actionDisasSwitch_case->setObjectName("actionDisasSwitch_case");
        actionDisasCopy_All = new QAction(MainWindow);
        actionDisasCopy_All->setObjectName("actionDisasCopy_All");
        actionDisasCopy_Bytes = new QAction(MainWindow);
        actionDisasCopy_Bytes->setObjectName("actionDisasCopy_Bytes");
        actionDisasCopy_Disasm = new QAction(MainWindow);
        actionDisasCopy_Disasm->setObjectName("actionDisasCopy_Disasm");
        actionDisplayOptions = new QAction(MainWindow);
        actionDisplayOptions->setObjectName("actionDisplayOptions");
        actionStart_Web_Server = new QAction(MainWindow);
        actionStart_Web_Server->setObjectName("actionStart_Web_Server");
        actionStart_Web_Server->setCheckable(true);
        QIcon icon5;
        icon5.addFile(QString::fromUtf8(":/img/icons/cloud.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionStart_Web_Server->setIcon(icon5);
        action1column = new QAction(MainWindow);
        action1column->setObjectName("action1column");
        action2columns = new QAction(MainWindow);
        action2columns->setObjectName("action2columns");
        action4columns = new QAction(MainWindow);
        action4columns->setObjectName("action4columns");
        action8columns = new QAction(MainWindow);
        action8columns->setObjectName("action8columns");
        action16columns = new QAction(MainWindow);
        action16columns->setObjectName("action16columns");
        action32columns = new QAction(MainWindow);
        action32columns->setObjectName("action32columns");
        action64columns = new QAction(MainWindow);
        action64columns->setObjectName("action64columns");
        actionSyntax_AT_T_Intel = new QAction(MainWindow);
        actionSyntax_AT_T_Intel->setObjectName("actionSyntax_AT_T_Intel");
        actionFunctionsRename = new QAction(MainWindow);
        actionFunctionsRename->setObjectName("actionFunctionsRename");
        actionFunctionsUndefine = new QAction(MainWindow);
        actionFunctionsUndefine->setObjectName("actionFunctionsUndefine");
        actionDisasRename = new QAction(MainWindow);
        actionDisasRename->setObjectName("actionDisasRename");
        actionDisasmUndefine = new QAction(MainWindow);
        actionDisasmUndefine->setObjectName("actionDisasmUndefine");
        actionDisasAdd_comment = new QAction(MainWindow);
        actionDisasAdd_comment->setObjectName("actionDisasAdd_comment");
        actionhide_bottomPannel = new QAction(MainWindow);
        actionhide_bottomPannel->setObjectName("actionhide_bottomPannel");
        actionhide_bottomPannel->setCheckable(true);
        QIcon icon6;
        icon6.addFile(QString::fromUtf8(":/img/icons/down.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionhide_bottomPannel->setIcon(icon6);
        actionRun_Script = new QAction(MainWindow);
        actionRun_Script->setObjectName("actionRun_Script");
        actionRunR2jsScript = new QAction(MainWindow);
        actionRunR2jsScript->setObjectName("actionRunR2jsScript");
        actionScripts = new QAction(MainWindow);
        actionScripts->setObjectName("actionScripts");
        actionReset_settings = new QAction(MainWindow);
        actionReset_settings->setObjectName("actionReset_settings");
        actionQuit = new QAction(MainWindow);
        actionQuit->setObjectName("actionQuit");
        actionExports = new QAction(MainWindow);
        actionExports->setObjectName("actionExports");
        actionExports->setCheckable(true);
        actionRefresh_contents = new QAction(MainWindow);
        actionRefresh_contents->setObjectName("actionRefresh_contents");
        actionHighlight = new QAction(MainWindow);
        actionHighlight->setObjectName("actionHighlight");
        actionDisplay_Esil = new QAction(MainWindow);
        actionDisplay_Esil->setObjectName("actionDisplay_Esil");
        actionDisplay_Esil->setCheckable(true);
        actionDisplay_Decompiler = new QAction(MainWindow);
        actionDisplay_Decompiler->setObjectName("actionDisplay_Decompiler");
        actionDisplay_Decompiler->setCheckable(true);
        actionDisplay_Offsets = new QAction(MainWindow);
        actionDisplay_Offsets->setObjectName("actionDisplay_Offsets");
        actionDisplay_Offsets->setCheckable(true);
        actionDisplay_Offsets->setChecked(true);
        actionSettings = new QAction(MainWindow);
        actionSettings->setObjectName("actionSettings");
        actionPackageManagerPrefs = new QAction(MainWindow);
        actionPackageManagerPrefs->setObjectName("actionPackageManagerPrefs");
        actionSaveAs = new QAction(MainWindow);
        actionSaveAs->setObjectName("actionSaveAs");
        actionGraph = new QAction(MainWindow);
        actionGraph->setObjectName("actionGraph");
        actionGraph->setCheckable(true);
        actionImportPDB = new QAction(MainWindow);
        actionImportPDB->setObjectName("actionImportPDB");
        actionImportSymbols = new QAction(MainWindow);
        actionImportSymbols->setObjectName("actionImportSymbols");
        actionAnalyze = new QAction(MainWindow);
        actionAnalyze->setObjectName("actionAnalyze");
        actionAnalyzeFunction = new QAction(MainWindow);
        actionAnalyzeFunction->setObjectName("actionAnalyzeFunction");
        actionAutonameAll = new QAction(MainWindow);
        actionAutonameAll->setObjectName("actionAutonameAll");
        actionAnalysisSettings = new QAction(MainWindow);
        actionAnalysisSettings->setObjectName("actionAnalysisSettings");
        actionSwitchJumpTable = new QAction(MainWindow);
        actionSwitchJumpTable->setObjectName("actionSwitchJumpTable");
        actionExport_as_code = new QAction(MainWindow);
        actionExport_as_code->setObjectName("actionExport_as_code");
        actionDump = new QAction(MainWindow);
        actionDump->setObjectName("actionDump");
        actionImportDWARF = new QAction(MainWindow);
        actionImportDWARF->setObjectName("actionImportDWARF");
        actionImportFLIRT = new QAction(MainWindow);
        actionImportFLIRT->setObjectName("actionImportFLIRT");
        actionImportProjectArchive = new QAction(MainWindow);
        actionImportProjectArchive->setObjectName("actionImportProjectArchive");
        actionExportDWARF = new QAction(MainWindow);
        actionExportDWARF->setObjectName("actionExportDWARF");
        actionExportProjectArchive = new QAction(MainWindow);
        actionExportProjectArchive->setObjectName("actionExportProjectArchive");
        actionExtraHexdump = new QAction(MainWindow);
        actionExtraHexdump->setObjectName("actionExtraHexdump");
        actionExtraDecompiler = new QAction(MainWindow);
        actionExtraDecompiler->setObjectName("actionExtraDecompiler");
        actionExtraDisassembly = new QAction(MainWindow);
        actionExtraDisassembly->setObjectName("actionExtraDisassembly");
        actionExtraGraph = new QAction(MainWindow);
        actionExtraGraph->setObjectName("actionExtraGraph");
        actionAddCustomCommand = new QAction(MainWindow);
        actionAddCustomCommand->setObjectName("actionAddCustomCommand");
        actionGrouped_dock_dragging = new QAction(MainWindow);
        actionGrouped_dock_dragging->setObjectName("actionGrouped_dock_dragging");
        actionGrouped_dock_dragging->setCheckable(true);
        actionGrouped_dock_dragging->setChecked(true);
        actionZoomIn = new QAction(MainWindow);
        actionZoomIn->setObjectName("actionZoomIn");
        actionZoomIn->setShortcutContext(Qt::ApplicationShortcut);
        actionZoomOut = new QAction(MainWindow);
        actionZoomOut->setObjectName("actionZoomOut");
        actionZoomOut->setShortcutContext(Qt::ApplicationShortcut);
        actionZoomReset = new QAction(MainWindow);
        actionZoomReset->setObjectName("actionZoomReset");
        actionZoomReset->setShortcutContext(Qt::ApplicationShortcut);
        actionCommitChanges = new QAction(MainWindow);
        actionCommitChanges->setObjectName("actionCommitChanges");
        actionUndoWrite = new QAction(MainWindow);
        actionUndoWrite->setObjectName("actionUndoWrite");
        actionRedoWrite = new QAction(MainWindow);
        actionRedoWrite->setObjectName("actionRedoWrite");
        actionPatchInstruction = new QAction(MainWindow);
        actionPatchInstruction->setObjectName("actionPatchInstruction");
        actionPatchString = new QAction(MainWindow);
        actionPatchString->setObjectName("actionPatchString");
        actionPatchBytes = new QAction(MainWindow);
        actionPatchBytes->setObjectName("actionPatchBytes");
        actionWriteMode = new QAction(MainWindow);
        actionWriteMode->setObjectName("actionWriteMode");
        actionWriteMode->setCheckable(true);
        actionCacheMode = new QAction(MainWindow);
        actionCacheMode->setObjectName("actionCacheMode");
        actionCacheMode->setCheckable(true);
        actionReadOnly = new QAction(MainWindow);
        actionReadOnly->setObjectName("actionReadOnly");
        actionReadOnly->setCheckable(true);
        actionReadOnly->setChecked(true);
        actionSaveLayout = new QAction(MainWindow);
        actionSaveLayout->setObjectName("actionSaveLayout");
        actionManageLayouts = new QAction(MainWindow);
        actionManageLayouts->setObjectName("actionManageLayouts");
        actionFiles = new QAction(MainWindow);
        actionFiles->setObjectName("actionFiles");
        actionFiles->setEnabled(false);
        actionMaps = new QAction(MainWindow);
        actionMaps->setObjectName("actionMaps");
        actionMaps->setEnabled(false);
        actionEntropy = new QAction(MainWindow);
        actionEntropy->setObjectName("actionEntropy");
        actionEntropy->setEnabled(false);
        actionBinaries = new QAction(MainWindow);
        actionBinaries->setObjectName("actionBinaries");
        actionBinaries->setEnabled(false);
        actionNavigation_Bar = new QAction(MainWindow);
        actionNavigation_Bar->setObjectName("actionNavigation_Bar");
        actionNavigation_Bar->setEnabled(false);
        addExtraWidgets = new QMenu(MainWindow);
        addExtraWidgets->setObjectName("addExtraWidgets");
        MainWindow->setCentralWidget(addExtraWidgets);
        menuBar = new QMenuBar(MainWindow);
        menuBar->setObjectName("menuBar");
        menuBar->setGeometry(QRect(0, 0, 1013, 20));
        menuBar->setDefaultUp(false);
        menuBar->setNativeMenuBar(true);
        menuFile = new QMenu(menuBar);
        menuFile->setObjectName("menuFile");
        menuFile->setGeometry(QRect(2024, 127, 161, 311));
        menuImport = new QMenu(menuFile);
        menuImport->setObjectName("menuImport");
        menuExport = new QMenu(menuFile);
        menuExport->setObjectName("menuExport");
        menuRun = new QMenu(menuFile);
        menuRun->setObjectName("menuRun");
        menuView = new QMenu(menuBar);
        menuView->setObjectName("menuView");
        menuView->setProperty("tabsOnTop", QVariant(true));
        menuZoom = new QMenu(menuView);
        menuZoom->setObjectName("menuZoom");
        menuAnalysis = new QMenu(menuView);
        menuAnalysis->setObjectName("menuAnalysis");
        menuHelp = new QMenu(menuBar);
        menuHelp->setObjectName("menuHelp");
        menuEdit = new QMenu(menuBar);
        menuEdit->setObjectName("menuEdit");
        menuSetMode = new QMenu(menuEdit);
        menuSetMode->setObjectName("menuSetMode");
        menuCode = new QMenu(menuBar);
        menuCode->setObjectName("menuCode");
        menuPlugins = new QMenu(menuCode);
        menuPlugins->setObjectName("menuPlugins");
        menuTools = new QMenu(menuBar);
        menuTools->setObjectName("menuTools");
        menuWindows = new QMenu(menuBar);
        menuWindows->setObjectName("menuWindows");
        menuWindowLayout = new QMenu(menuWindows);
        menuWindowLayout->setObjectName("menuWindowLayout");
        menuLayouts = new QMenu(menuWindowLayout);
        menuLayouts->setObjectName("menuLayouts");
        menuAddInfoWidgets = new QMenu(menuWindows);
        menuAddInfoWidgets->setObjectName("menuAddInfoWidgets");
        menuAddIoWidgets = new QMenu(menuWindows);
        menuAddIoWidgets->setObjectName("menuAddIoWidgets");
        menuAddDebugWidgets = new QMenu(menuWindows);
        menuAddDebugWidgets->setObjectName("menuAddDebugWidgets");
        menuAddAnother = new QMenu(menuWindows);
        menuAddAnother->setObjectName("menuAddAnother");
        menuDebug = new QMenu(menuBar);
        menuDebug->setObjectName("menuDebug");
        MainWindow->setMenuBar(menuBar);
        mainToolBar = new QToolBar(MainWindow);
        mainToolBar->setObjectName("mainToolBar");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(mainToolBar->sizePolicy().hasHeightForWidth());
        mainToolBar->setSizePolicy(sizePolicy1);
        mainToolBar->setContextMenuPolicy(Qt::DefaultContextMenu);
        mainToolBar->setWindowTitle(QString::fromUtf8("Main toolbar"));
        mainToolBar->setMovable(false);
        mainToolBar->setIconSize(QSize(16, 16));
        mainToolBar->setToolButtonStyle(Qt::ToolButtonIconOnly);
        MainWindow->addToolBar(Qt::ToolBarArea::TopToolBarArea, mainToolBar);

        menuBar->addAction(menuFile->menuAction());
        menuBar->addAction(menuEdit->menuAction());
        menuBar->addAction(menuView->menuAction());
        menuBar->addAction(menuCode->menuAction());
        menuBar->addAction(menuDebug->menuAction());
        menuBar->addAction(menuTools->menuAction());
        menuBar->addAction(menuWindows->menuAction());
        menuBar->addAction(menuHelp->menuAction());
        menuFile->addAction(actionNew);
        menuFile->addAction(actionMap);
        menuFile->addAction(actionManageAddressSpace);
        menuFile->addSeparator();
        menuFile->addAction(actionSave);
        menuFile->addAction(actionSaveAs);
        menuFile->addSeparator();
        menuFile->addAction(menuImport->menuAction());
        menuFile->addAction(menuExport->menuAction());
        menuFile->addAction(menuRun->menuAction());
        menuFile->addSeparator();
        menuFile->addAction(actionCommitChanges);
        menuFile->addSeparator();
        menuFile->addAction(actionSettings);
        menuFile->addSeparator();
        menuFile->addAction(actionQuit);
        menuImport->addAction(actionMap);
        menuImport->addAction(actionImportPDB);
        menuImport->addAction(actionImportSymbols);
        menuImport->addAction(actionImportDWARF);
        menuImport->addAction(actionImportFLIRT);
        menuImport->addSeparator();
        menuImport->addAction(actionImportProjectArchive);
        menuExport->addAction(actionExport_as_code);
        menuExport->addAction(actionDump);
        menuExport->addAction(actionExportDWARF);
        menuExport->addSeparator();
        menuExport->addAction(actionExportProjectArchive);
        menuRun->addAction(actionRun_Script);
        menuRun->addAction(actionRunR2jsScript);
        menuRun->addSeparator();
        menuRun->addAction(actionScripts);
        menuView->addAction(actionHighlight);
        menuView->addSeparator();
        menuView->addAction(menuAnalysis->menuAction());
        menuView->addAction(menuAddInfoWidgets->menuAction());
        menuView->addAction(menuAddIoWidgets->menuAction());
        menuView->addSeparator();
        menuView->addAction(menuAddAnother->menuAction());
        menuView->addAction(menuZoom->menuAction());
        menuZoom->addAction(actionZoomIn);
        menuZoom->addAction(actionZoomOut);
        menuZoom->addSeparator();
        menuZoom->addAction(actionZoomReset);
        menuHelp->addAction(actionIssue);
        menuHelp->addAction(actionWebsite);
        menuHelp->addAction(actionBook);
        menuHelp->addAction(actionFortune);
        menuHelp->addAction(actionCheckForUpdates);
        menuHelp->addSeparator();
        menuHelp->addAction(actionAbout);
        menuEdit->addAction(actionBackward);
        menuEdit->addAction(actionForward);
        menuEdit->addSeparator();
        menuEdit->addAction(actionUndoWrite);
        menuEdit->addAction(actionRedoWrite);
        menuEdit->addSeparator();
        menuEdit->addAction(actionPatchInstruction);
        menuEdit->addAction(actionPatchString);
        menuEdit->addAction(actionPatchBytes);
        menuEdit->addSeparator();
        menuEdit->addAction(menuSetMode->menuAction());
        menuSetMode->addAction(actionWriteMode);
        menuSetMode->addAction(actionCacheMode);
        menuSetMode->addAction(actionReadOnly);
        menuCode->addAction(actionAnalyze);
        menuCode->addAction(actionAnalyzeFunction);
        menuCode->addAction(actionAutonameAll);
        menuCode->addSeparator();
        menuCode->addAction(actionSwitchJumpTable);
        menuCode->addSeparator();
        menuCode->addAction(actionAnalysisSettings);
        menuCode->addSeparator();
        menuCode->addAction(menuPlugins->menuAction());
        menuTools->addAction(actionStart_Web_Server);
        menuTools->addAction(actionPackageManagerPrefs);
        menuTools->addAction(actionScripts);
        menuWindows->addAction(actionRefresh_contents);
        menuWindows->addSeparator();
        menuWindows->addAction(menuWindowLayout->menuAction());
        menuWindows->addSeparator();
        menuWindows->addAction(actionTabs_on_Top);
        menuWindows->addAction(actionGrouped_dock_dragging);
        menuWindows->addSeparator();
        menuWindows->addAction(actionReset_settings);
        menuWindowLayout->addAction(actionDefault);
        menuWindowLayout->addAction(actionSaveLayout);
        menuWindowLayout->addAction(actionManageLayouts);
        menuWindowLayout->addSeparator();
        menuWindowLayout->addAction(menuLayouts->menuAction());
        menuAddAnother->addAction(actionExtraDecompiler);
        menuAddAnother->addAction(actionExtraDisassembly);
        menuAddAnother->addAction(actionExtraGraph);
        menuAddAnother->addAction(actionExtraHexdump);
        menuAddAnother->addSeparator();
        menuAddAnother->addAction(actionAddCustomCommand);
        mainToolBar->addAction(actionBackward);
        mainToolBar->addAction(actionForward);

        retranslateUi(MainWindow);

        QMetaObject::connectSlotsByName(MainWindow);
    } // setupUi

    void retranslateUi(QMainWindow *MainWindow)
    {
        actionDefault->setText(QCoreApplication::translate("MainWindow", "Reset to default layout", nullptr));
        actionZen->setText(QCoreApplication::translate("MainWindow", "Zen Mode", nullptr));
#if QT_CONFIG(tooltip)
        actionZen->setToolTip(QCoreApplication::translate("MainWindow", "Zen mode", nullptr));
#endif // QT_CONFIG(tooltip)
        actionAbout->setText(QCoreApplication::translate("MainWindow", "About", nullptr));
        actionIssue->setText(QCoreApplication::translate("MainWindow", "Report an issue", nullptr));
        actionR2pm->setText(QCoreApplication::translate("MainWindow", "r2pm", nullptr));
        actionNew->setText(QCoreApplication::translate("MainWindow", "Open...", nullptr));
        actionClose->setText(QCoreApplication::translate("MainWindow", "Close", nullptr));
        actionSave_workspace->setText(QCoreApplication::translate("MainWindow", "Save layout", nullptr));
#if QT_CONFIG(tooltip)
        actionSave_workspace->setToolTip(QCoreApplication::translate("MainWindow", "Save layout", nullptr));
#endif // QT_CONFIG(tooltip)
        actionBook->setText(QCoreApplication::translate("MainWindow", "Book", nullptr));
        actionFortune->setText(QCoreApplication::translate("MainWindow", "Fortunes", nullptr));
        actionWebsite->setText(QCoreApplication::translate("MainWindow", "Website", nullptr));
        actionCheckForUpdates->setText(QCoreApplication::translate("MainWindow", "Check for updates", nullptr));
        actionMap->setText(QCoreApplication::translate("MainWindow", "Map file at...", nullptr));
        actionManageAddressSpace->setText(QCoreApplication::translate("MainWindow", "Manage files...", nullptr));
#if QT_CONFIG(tooltip)
        actionManageAddressSpace->setToolTip(QCoreApplication::translate("MainWindow", "Manage files, maps, binaries, filesystems, and address space options", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        actionManageAddressSpace->setStatusTip(QCoreApplication::translate("MainWindow", "Open the address space manager", nullptr));
#endif // QT_CONFIG(statustip)
        actionSave->setText(QCoreApplication::translate("MainWindow", "Save Project", nullptr));
        actionCut->setText(QCoreApplication::translate("MainWindow", "Cut", nullptr));
        actionCopy->setText(QCoreApplication::translate("MainWindow", "Copy", nullptr));
        actionPaste->setText(QCoreApplication::translate("MainWindow", "Paste", nullptr));
        actionDelete->setText(QCoreApplication::translate("MainWindow", "Delete", nullptr));
        actionSelect_all->setText(QCoreApplication::translate("MainWindow", "Select all", nullptr));
#if QT_CONFIG(tooltip)
        actionSelect_all->setToolTip(QCoreApplication::translate("MainWindow", "Select all", nullptr));
#endif // QT_CONFIG(tooltip)
        actionFind->setText(QCoreApplication::translate("MainWindow", "Find", nullptr));
        actionFind_next->setText(QCoreApplication::translate("MainWindow", "Find next", nullptr));
#if QT_CONFIG(tooltip)
        actionFind_next->setToolTip(QCoreApplication::translate("MainWindow", "Find next", nullptr));
#endif // QT_CONFIG(tooltip)
        actionFind_previous->setText(QCoreApplication::translate("MainWindow", "Find previous", nullptr));
#if QT_CONFIG(tooltip)
        actionFind_previous->setToolTip(QCoreApplication::translate("MainWindow", "Find previous", nullptr));
#endif // QT_CONFIG(tooltip)
        actionBackward->setText(QCoreApplication::translate("MainWindow", "Undo Seek", nullptr));
#if QT_CONFIG(tooltip)
        actionBackward->setToolTip(QCoreApplication::translate("MainWindow", "Go back", nullptr));
#endif // QT_CONFIG(tooltip)
        actionForward->setText(QCoreApplication::translate("MainWindow", "Redo Seek", nullptr));
        actionTheme->setText(QCoreApplication::translate("MainWindow", "Theme", nullptr));
        actionTabs->setText(QCoreApplication::translate("MainWindow", "Tabs up/down", nullptr));
#if QT_CONFIG(tooltip)
        actionTabs->setToolTip(QCoreApplication::translate("MainWindow", "Tabs up/down", nullptr));
#endif // QT_CONFIG(tooltip)
        actionRefresh_Panels->setText(QCoreApplication::translate("MainWindow", "Refresh", nullptr));
        actionTabs_on_Top->setText(QCoreApplication::translate("MainWindow", "Show Tabs at the Top", nullptr));
#if QT_CONFIG(tooltip)
        actionTabs_on_Top->setToolTip(QCoreApplication::translate("MainWindow", "Toggle tab position", nullptr));
#endif // QT_CONFIG(tooltip)
        actionDark_Theme->setText(QCoreApplication::translate("MainWindow", "Dark Theme", nullptr));
        actionLoad_workspace->setText(QCoreApplication::translate("MainWindow", "Load layout", nullptr));
#if QT_CONFIG(tooltip)
        actionLoad_workspace->setToolTip(QCoreApplication::translate("MainWindow", "Load layout", nullptr));
#endif // QT_CONFIG(tooltip)
        actionWhite_Theme->setText(QCoreApplication::translate("MainWindow", "Default Theme", nullptr));
        actionBindiff->setText(QCoreApplication::translate("MainWindow", "Bindiff", nullptr));
        actionAnalysis->setText(QCoreApplication::translate("MainWindow", "Analysis", nullptr));
        actionTest_menu->setText(QCoreApplication::translate("MainWindow", "Test menu", nullptr));
        actionHexCopy_Hexpair->setText(QCoreApplication::translate("MainWindow", "Copy hexpair", nullptr));
#if QT_CONFIG(tooltip)
        actionHexCopy_Hexpair->setToolTip(QCoreApplication::translate("MainWindow", "Copy hexpair", nullptr));
#endif // QT_CONFIG(tooltip)
        actionHexCopy_Text->setText(QCoreApplication::translate("MainWindow", "Copy text", nullptr));
#if QT_CONFIG(tooltip)
        actionHexCopy_Text->setToolTip(QCoreApplication::translate("MainWindow", "Copy text", nullptr));
#endif // QT_CONFIG(tooltip)
        actionHexCopy_ASCII->setText(QCoreApplication::translate("MainWindow", "Copy ASCII", nullptr));
        actionHexInsert_String->setText(QCoreApplication::translate("MainWindow", "Insert string", nullptr));
#if QT_CONFIG(tooltip)
        actionHexInsert_String->setToolTip(QCoreApplication::translate("MainWindow", "Insert string", nullptr));
#endif // QT_CONFIG(tooltip)
        actionHexInsert_Hex->setText(QCoreApplication::translate("MainWindow", "Insert hex", nullptr));
#if QT_CONFIG(tooltip)
        actionHexInsert_Hex->setToolTip(QCoreApplication::translate("MainWindow", "Insert hex", nullptr));
#endif // QT_CONFIG(tooltip)
        actionHexEdit->setText(QCoreApplication::translate("MainWindow", "Edit", nullptr));
        actionHexPaste->setText(QCoreApplication::translate("MainWindow", "Paste", nullptr));
        actionDisas_ShowHideBytes->setText(QCoreApplication::translate("MainWindow", "Show/Hide bytes", nullptr));
        actionDisasSwitch_case->setText(QCoreApplication::translate("MainWindow", "Switch case", nullptr));
        actionDisasCopy_All->setText(QCoreApplication::translate("MainWindow", "Copy all", nullptr));
#if QT_CONFIG(tooltip)
        actionDisasCopy_All->setToolTip(QCoreApplication::translate("MainWindow", "Copy all", nullptr));
#endif // QT_CONFIG(tooltip)
        actionDisasCopy_Bytes->setText(QCoreApplication::translate("MainWindow", "Copy bytes", nullptr));
#if QT_CONFIG(tooltip)
        actionDisasCopy_Bytes->setToolTip(QCoreApplication::translate("MainWindow", "Copy bytes", nullptr));
#endif // QT_CONFIG(tooltip)
        actionDisasCopy_Disasm->setText(QCoreApplication::translate("MainWindow", "Copy disasm", nullptr));
#if QT_CONFIG(tooltip)
        actionDisasCopy_Disasm->setToolTip(QCoreApplication::translate("MainWindow", "Copy disasm", nullptr));
#endif // QT_CONFIG(tooltip)
        actionDisplayOptions->setText(QCoreApplication::translate("MainWindow", "Copy disasm", nullptr));
#if QT_CONFIG(tooltip)
        actionDisplayOptions->setToolTip(QCoreApplication::translate("MainWindow", "Copy disasm", nullptr));
#endif // QT_CONFIG(tooltip)
        actionStart_Web_Server->setText(QCoreApplication::translate("MainWindow", "Start web server", nullptr));
#if QT_CONFIG(tooltip)
        actionStart_Web_Server->setToolTip(QCoreApplication::translate("MainWindow", "Start web server", nullptr));
#endif // QT_CONFIG(tooltip)
        action1column->setText(QCoreApplication::translate("MainWindow", "1", nullptr));
        action2columns->setText(QCoreApplication::translate("MainWindow", "2", nullptr));
        action4columns->setText(QCoreApplication::translate("MainWindow", "4", nullptr));
        action8columns->setText(QCoreApplication::translate("MainWindow", "8", nullptr));
        action16columns->setText(QCoreApplication::translate("MainWindow", "16", nullptr));
        action32columns->setText(QCoreApplication::translate("MainWindow", "32", nullptr));
        action64columns->setText(QCoreApplication::translate("MainWindow", "64", nullptr));
        actionSyntax_AT_T_Intel->setText(QCoreApplication::translate("MainWindow", "Syntax AT&T/Intel", nullptr));
        actionFunctionsRename->setText(QCoreApplication::translate("MainWindow", "Rename", nullptr));
        actionFunctionsUndefine->setText(QCoreApplication::translate("MainWindow", "Undefine", nullptr));
        actionDisasRename->setText(QCoreApplication::translate("MainWindow", "Rename", nullptr));
        actionDisasmUndefine->setText(QCoreApplication::translate("MainWindow", "Undefine", nullptr));
        actionDisasAdd_comment->setText(QCoreApplication::translate("MainWindow", "Add comment", nullptr));
        actionhide_bottomPannel->setText(QCoreApplication::translate("MainWindow", "Show/Hide bottom pannel", nullptr));
#if QT_CONFIG(tooltip)
        actionhide_bottomPannel->setToolTip(QCoreApplication::translate("MainWindow", "Show/Hide bottom pannel", nullptr));
#endif // QT_CONFIG(tooltip)
        actionRun_Script->setText(QCoreApplication::translate("MainWindow", "Radare Script...", nullptr));
#if QT_CONFIG(tooltip)
        actionRun_Script->setToolTip(QCoreApplication::translate("MainWindow", "Run a radare2 script file once", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        actionRun_Script->setStatusTip(QCoreApplication::translate("MainWindow", "Select and execute a radare2 script file in the current session", nullptr));
#endif // QT_CONFIG(statustip)
        actionRunR2jsScript->setText(QCoreApplication::translate("MainWindow", "r2js script...", nullptr));
#if QT_CONFIG(tooltip)
        actionRunR2jsScript->setToolTip(QCoreApplication::translate("MainWindow", "Run an r2js script file once", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        actionRunR2jsScript->setStatusTip(QCoreApplication::translate("MainWindow", "Select and execute an r2js script file in the current session", nullptr));
#endif // QT_CONFIG(statustip)
        actionScripts->setText(QCoreApplication::translate("MainWindow", "Script Editor...", nullptr));
#if QT_CONFIG(tooltip)
        actionScripts->setToolTip(QCoreApplication::translate("MainWindow", "Open the script editor", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        actionScripts->setStatusTip(QCoreApplication::translate("MainWindow", "Edit, save, and run scripts with inline output", nullptr));
#endif // QT_CONFIG(statustip)
        actionReset_settings->setText(QCoreApplication::translate("MainWindow", "Factory reset", nullptr));
#if QT_CONFIG(tooltip)
        actionReset_settings->setToolTip(QCoreApplication::translate("MainWindow", "Reset application settings", nullptr));
#endif // QT_CONFIG(tooltip)
        actionQuit->setText(QCoreApplication::translate("MainWindow", "Quit", nullptr));
        actionExports->setText(QCoreApplication::translate("MainWindow", "Exports", nullptr));
#if QT_CONFIG(tooltip)
        actionExports->setToolTip(QCoreApplication::translate("MainWindow", "Show/Hide Exports panel", nullptr));
#endif // QT_CONFIG(tooltip)
        actionRefresh_contents->setText(QCoreApplication::translate("MainWindow", "Refresh Contents", nullptr));
#if QT_CONFIG(tooltip)
        actionRefresh_contents->setToolTip(QCoreApplication::translate("MainWindow", "Refresh contents", nullptr));
#endif // QT_CONFIG(tooltip)
        actionHighlight->setText(QCoreApplication::translate("MainWindow", "Highlight", nullptr));
#if QT_CONFIG(tooltip)
        actionHighlight->setToolTip(QCoreApplication::translate("MainWindow", "Highlight matching words in disassembly", nullptr));
#endif // QT_CONFIG(tooltip)
        actionDisplay_Esil->setText(QCoreApplication::translate("MainWindow", "Show ESIL rather than assembly", nullptr));
        actionDisplay_Decompiler->setText(QCoreApplication::translate("MainWindow", "Show pseudocode rather than assembly", nullptr));
        actionDisplay_Offsets->setText(QCoreApplication::translate("MainWindow", "Display offsets", nullptr));
        actionSettings->setText(QCoreApplication::translate("MainWindow", "Settings...", nullptr));
        actionPackageManagerPrefs->setText(QCoreApplication::translate("MainWindow", "Package Manager", nullptr));
        actionSaveAs->setText(QCoreApplication::translate("MainWindow", "Save Project...", nullptr));
        actionGraph->setText(QCoreApplication::translate("MainWindow", "Graph", nullptr));
        actionImportPDB->setText(QCoreApplication::translate("MainWindow", "PDB file...", nullptr));
        actionImportSymbols->setText(QCoreApplication::translate("MainWindow", "Binary symbols...", nullptr));
#if QT_CONFIG(tooltip)
        actionImportSymbols->setToolTip(QCoreApplication::translate("MainWindow", "Import symbols from another binary object file", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        actionImportSymbols->setStatusTip(QCoreApplication::translate("MainWindow", "Load another binary object with the obf command to import its symbols into the current session", nullptr));
#endif // QT_CONFIG(statustip)
        actionAnalyze->setText(QCoreApplication::translate("MainWindow", "Analyze Program", nullptr));
        actionAnalyzeFunction->setText(QCoreApplication::translate("MainWindow", "Analyze Function", nullptr));
#if QT_CONFIG(tooltip)
        actionAnalyzeFunction->setToolTip(QCoreApplication::translate("MainWindow", "Analyze the function at the current offset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        actionAnalyzeFunction->setStatusTip(QCoreApplication::translate("MainWindow", "Run af at the current seek position", nullptr));
#endif // QT_CONFIG(statustip)
        actionAutonameAll->setText(QCoreApplication::translate("MainWindow", "Autoname All", nullptr));
#if QT_CONFIG(tooltip)
        actionAutonameAll->setToolTip(QCoreApplication::translate("MainWindow", "Autoname all functions", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        actionAutonameAll->setStatusTip(QCoreApplication::translate("MainWindow", "Run aan to autoname all functions", nullptr));
#endif // QT_CONFIG(statustip)
        actionAnalysisSettings->setText(QCoreApplication::translate("MainWindow", "Analysis Settings", nullptr));
#if QT_CONFIG(tooltip)
        actionAnalysisSettings->setToolTip(QCoreApplication::translate("MainWindow", "Open analysis settings", nullptr));
#endif // QT_CONFIG(tooltip)
        actionSwitchJumpTable->setText(QCoreApplication::translate("MainWindow", "SwitchJumpTable...", nullptr));
#if QT_CONFIG(tooltip)
        actionSwitchJumpTable->setToolTip(QCoreApplication::translate("MainWindow", "Create or edit a switch / jump table at the current dispatcher", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        actionSwitchJumpTable->setStatusTip(QCoreApplication::translate("MainWindow", "Open the switch/jump table panel (afbt / afb+ / afbe)", nullptr));
#endif // QT_CONFIG(statustip)
        actionExport_as_code->setText(QCoreApplication::translate("MainWindow", "Disassembly/code...", nullptr));
        actionDump->setText(QCoreApplication::translate("MainWindow", "Binary range...", nullptr));
#if QT_CONFIG(tooltip)
        actionDump->setToolTip(QCoreApplication::translate("MainWindow", "Dump a range of bytes to a file", nullptr));
#endif // QT_CONFIG(tooltip)
        actionImportDWARF->setText(QCoreApplication::translate("MainWindow", "DWARF information...", nullptr));
#if QT_CONFIG(tooltip)
        actionImportDWARF->setToolTip(QCoreApplication::translate("MainWindow", "Import DWARF information from another binary object file", nullptr));
#endif // QT_CONFIG(tooltip)
        actionImportFLIRT->setText(QCoreApplication::translate("MainWindow", "FLIRT signatures...", nullptr));
#if QT_CONFIG(tooltip)
        actionImportFLIRT->setToolTip(QCoreApplication::translate("MainWindow", "Load and scan FLIRT signature files", nullptr));
#endif // QT_CONFIG(tooltip)
        actionImportProjectArchive->setText(QCoreApplication::translate("MainWindow", "Project archive...", nullptr));
        actionExportDWARF->setText(QCoreApplication::translate("MainWindow", "DWARF information...", nullptr));
#if QT_CONFIG(tooltip)
        actionExportDWARF->setToolTip(QCoreApplication::translate("MainWindow", "Export DWARF source line information", nullptr));
#endif // QT_CONFIG(tooltip)
        actionExportProjectArchive->setText(QCoreApplication::translate("MainWindow", "Project archive...", nullptr));
        actionExtraHexdump->setText(QCoreApplication::translate("MainWindow", "Hexdump", nullptr));
        actionExtraDecompiler->setText(QCoreApplication::translate("MainWindow", "Decompiler", nullptr));
        actionExtraDisassembly->setText(QCoreApplication::translate("MainWindow", "Disassembly", nullptr));
        actionExtraGraph->setText(QCoreApplication::translate("MainWindow", "Graph", nullptr));
        actionAddCustomCommand->setText(QCoreApplication::translate("MainWindow", "Custom Command", nullptr));
        actionGrouped_dock_dragging->setText(QCoreApplication::translate("MainWindow", "Grouped dock dragging", nullptr));
        actionZoomIn->setText(QCoreApplication::translate("MainWindow", "Zoom In", nullptr));
        actionZoomOut->setText(QCoreApplication::translate("MainWindow", "Zoom Out", nullptr));
        actionZoomReset->setText(QCoreApplication::translate("MainWindow", "Reset", nullptr));
        actionCommitChanges->setText(QCoreApplication::translate("MainWindow", "Commit iocache to disk", nullptr));
        actionUndoWrite->setText(QCoreApplication::translate("MainWindow", "Undo write", nullptr));
#if QT_CONFIG(tooltip)
        actionUndoWrite->setToolTip(QCoreApplication::translate("MainWindow", "Undo the last pending write-cache change", nullptr));
#endif // QT_CONFIG(tooltip)
        actionRedoWrite->setText(QCoreApplication::translate("MainWindow", "Redo write", nullptr));
#if QT_CONFIG(tooltip)
        actionRedoWrite->setToolTip(QCoreApplication::translate("MainWindow", "Redo the last undone write-cache change", nullptr));
#endif // QT_CONFIG(tooltip)
        actionPatchInstruction->setText(QCoreApplication::translate("MainWindow", "Patch Instruction...", nullptr));
#if QT_CONFIG(tooltip)
        actionPatchInstruction->setToolTip(QCoreApplication::translate("MainWindow", "Patch the instruction at the current address", nullptr));
#endif // QT_CONFIG(tooltip)
        actionPatchString->setText(QCoreApplication::translate("MainWindow", "Patch String...", nullptr));
#if QT_CONFIG(tooltip)
        actionPatchString->setToolTip(QCoreApplication::translate("MainWindow", "Patch a string at the current address", nullptr));
#endif // QT_CONFIG(tooltip)
        actionPatchBytes->setText(QCoreApplication::translate("MainWindow", "Patch Bytes...", nullptr));
#if QT_CONFIG(tooltip)
        actionPatchBytes->setToolTip(QCoreApplication::translate("MainWindow", "Patch bytes at the current address", nullptr));
#endif // QT_CONFIG(tooltip)
        actionWriteMode->setText(QCoreApplication::translate("MainWindow", "Write mode", nullptr));
#if QT_CONFIG(tooltip)
        actionWriteMode->setToolTip(QCoreApplication::translate("MainWindow", "Open the file in write mode. Every change to the file will change the original file on disk.", nullptr));
#endif // QT_CONFIG(tooltip)
        actionCacheMode->setText(QCoreApplication::translate("MainWindow", "Cache mode", nullptr));
#if QT_CONFIG(tooltip)
        actionCacheMode->setToolTip(QCoreApplication::translate("MainWindow", "Enable cache mode. Changes to the file would not be applied to disk unless you specifically commit them. This is a safer option.", nullptr));
#endif // QT_CONFIG(tooltip)
        actionReadOnly->setText(QCoreApplication::translate("MainWindow", "Read-Only mode", nullptr));
        actionSaveLayout->setText(QCoreApplication::translate("MainWindow", "Save layout", nullptr));
        actionManageLayouts->setText(QCoreApplication::translate("MainWindow", "Manage layouts", nullptr));
        actionFiles->setText(QCoreApplication::translate("MainWindow", "Files", nullptr));
        actionMaps->setText(QCoreApplication::translate("MainWindow", "Maps", nullptr));
        actionEntropy->setText(QCoreApplication::translate("MainWindow", "Entropy", nullptr));
        actionBinaries->setText(QCoreApplication::translate("MainWindow", "Binaries", nullptr));
        actionNavigation_Bar->setText(QCoreApplication::translate("MainWindow", "Navigation Bar", nullptr));
        addExtraWidgets->setTitle(QCoreApplication::translate("MainWindow", "Add extra...", nullptr));
        menuFile->setTitle(QCoreApplication::translate("MainWindow", "File", nullptr));
        menuImport->setTitle(QCoreApplication::translate("MainWindow", "Import...", nullptr));
        menuExport->setTitle(QCoreApplication::translate("MainWindow", "Export...", nullptr));
        menuRun->setTitle(QCoreApplication::translate("MainWindow", "Run", nullptr));
        menuView->setTitle(QCoreApplication::translate("MainWindow", "View", nullptr));
        menuZoom->setTitle(QCoreApplication::translate("MainWindow", "Zoom", nullptr));
        menuAnalysis->setTitle(QCoreApplication::translate("MainWindow", "Analysis", nullptr));
        menuHelp->setTitle(QCoreApplication::translate("MainWindow", "Help", nullptr));
        menuEdit->setTitle(QCoreApplication::translate("MainWindow", "Edit", nullptr));
#if QT_CONFIG(tooltip)
        menuSetMode->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        menuSetMode->setTitle(QCoreApplication::translate("MainWindow", "IO mode", nullptr));
        menuCode->setTitle(QCoreApplication::translate("MainWindow", "Code", nullptr));
        menuPlugins->setTitle(QCoreApplication::translate("MainWindow", "Plugins", nullptr));
        menuTools->setTitle(QCoreApplication::translate("MainWindow", "Tools", nullptr));
        menuWindows->setTitle(QCoreApplication::translate("MainWindow", "Window", nullptr));
        menuWindowLayout->setTitle(QCoreApplication::translate("MainWindow", "Layout", nullptr));
        menuLayouts->setTitle(QCoreApplication::translate("MainWindow", "Layouts", nullptr));
        menuAddInfoWidgets->setTitle(QCoreApplication::translate("MainWindow", "Info...", nullptr));
        menuAddIoWidgets->setTitle(QCoreApplication::translate("MainWindow", "IO...", nullptr));
        menuAddDebugWidgets->setTitle(QCoreApplication::translate("MainWindow", "Debug...", nullptr));
        menuAddAnother->setTitle(QCoreApplication::translate("MainWindow", "Add another", nullptr));
        menuDebug->setTitle(QCoreApplication::translate("MainWindow", "Debug", nullptr));
        (void)MainWindow;
    } // retranslateUi

};

namespace Ui {
    class MainWindow: public Ui_MainWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAINWINDOW_H
