/****************************************************************************
** Meta object code from reading C++ file 'DisassemblyWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/widgets/DisassemblyWidget.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DisassemblyWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17DisassemblyWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto DisassemblyWidget::qt_create_metaobjectdata<qt_meta_tag_ZN17DisassemblyWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DisassemblyWidget",
        "highlightCurrentLine",
        "",
        "highlightPCLine",
        "showDisasContextMenu",
        "QPoint",
        "pt",
        "copyBytes",
        "fontsUpdatedSlot",
        "colorsUpdatedSlot",
        "scrollInstructions",
        "count",
        "seekPrev",
        "setPreviewMode",
        "previewMode",
        "getFontMetrics",
        "QFontMetrics",
        "getLines",
        "QList<DisassemblyLine>",
        "on_seekChanged",
        "RVA",
        "offset",
        "on_refreshContents",
        "refreshIfInRange",
        "refreshDisasm",
        "updateMaxLines",
        "cursorPositionChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'highlightCurrentLine'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'highlightPCLine'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showDisasContextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'copyBytes'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fontsUpdatedSlot'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'colorsUpdatedSlot'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'scrollInstructions'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'seekPrev'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setPreviewMode'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'getFontMetrics'
        QtMocHelpers::SlotData<QFontMetrics()>(15, 2, QMC::AccessPublic, 0x80000000 | 16),
        // Slot 'getLines'
        QtMocHelpers::SlotData<QList<DisassemblyLine>()>(17, 2, QMC::AccessPublic, 0x80000000 | 18),
        // Slot 'on_seekChanged'
        QtMocHelpers::SlotData<void(RVA)>(19, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'on_refreshContents'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'refreshIfInRange'
        QtMocHelpers::SlotData<void(RVA)>(23, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'refreshDisasm'
        QtMocHelpers::SlotData<void(RVA)>(24, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'refreshDisasm'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void),
        // Slot 'updateMaxLines'
        QtMocHelpers::SlotData<bool()>(25, 2, QMC::AccessProtected, QMetaType::Bool),
        // Slot 'cursorPositionChanged'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DisassemblyWidget, qt_meta_tag_ZN17DisassemblyWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DisassemblyWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<MemoryDockWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DisassemblyWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DisassemblyWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17DisassemblyWidgetE_t>.metaTypes,
    nullptr
} };

void DisassemblyWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DisassemblyWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->highlightCurrentLine(); break;
        case 1: _t->highlightPCLine(); break;
        case 2: _t->showDisasContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 3: _t->copyBytes(); break;
        case 4: _t->fontsUpdatedSlot(); break;
        case 5: _t->colorsUpdatedSlot(); break;
        case 6: _t->scrollInstructions((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->seekPrev(); break;
        case 8: _t->setPreviewMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: { QFontMetrics _r = _t->getFontMetrics();
            if (_a[0]) *reinterpret_cast<QFontMetrics*>(_a[0]) = std::move(_r); }  break;
        case 10: { QList<DisassemblyLine> _r = _t->getLines();
            if (_a[0]) *reinterpret_cast<QList<DisassemblyLine>*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->on_seekChanged((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1]))); break;
        case 12: _t->on_refreshContents(); break;
        case 13: _t->refreshIfInRange((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1]))); break;
        case 14: _t->refreshDisasm((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1]))); break;
        case 15: _t->refreshDisasm(); break;
        case 16: { bool _r = _t->updateMaxLines();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->cursorPositionChanged(); break;
        default: ;
        }
    }
}

const QMetaObject *DisassemblyWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DisassemblyWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DisassemblyWidgetE_t>.strings))
        return static_cast<void*>(this);
    return MemoryDockWidget::qt_metacast(_clname);
}

int DisassemblyWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MemoryDockWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN21DisassemblyScrollAreaE_t {};
} // unnamed namespace

template <> constexpr inline auto DisassemblyScrollArea::qt_create_metaobjectdata<qt_meta_tag_ZN21DisassemblyScrollAreaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DisassemblyScrollArea",
        "scrollLines",
        "",
        "lines",
        "disassemblyResized"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'scrollLines'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'disassemblyResized'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DisassemblyScrollArea, qt_meta_tag_ZN21DisassemblyScrollAreaE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DisassemblyScrollArea::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractScrollArea::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21DisassemblyScrollAreaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21DisassemblyScrollAreaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21DisassemblyScrollAreaE_t>.metaTypes,
    nullptr
} };

void DisassemblyScrollArea::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DisassemblyScrollArea *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->scrollLines((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->disassemblyResized(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DisassemblyScrollArea::*)(int )>(_a, &DisassemblyScrollArea::scrollLines, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisassemblyScrollArea::*)()>(_a, &DisassemblyScrollArea::disassemblyResized, 1))
            return;
    }
}

const QMetaObject *DisassemblyScrollArea::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DisassemblyScrollArea::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21DisassemblyScrollAreaE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractScrollArea::qt_metacast(_clname);
}

int DisassemblyScrollArea::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractScrollArea::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void DisassemblyScrollArea::scrollLines(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DisassemblyScrollArea::disassemblyResized()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN19DisassemblyTextEditE_t {};
} // unnamed namespace

template <> constexpr inline auto DisassemblyTextEdit::qt_create_metaobjectdata<qt_meta_tag_ZN19DisassemblyTextEditE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DisassemblyTextEdit",
        "refreshContents",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'refreshContents'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DisassemblyTextEdit, qt_meta_tag_ZN19DisassemblyTextEditE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DisassemblyTextEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<QPlainTextEdit::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DisassemblyTextEditE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DisassemblyTextEditE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19DisassemblyTextEditE_t>.metaTypes,
    nullptr
} };

void DisassemblyTextEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DisassemblyTextEdit *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->refreshContents(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DisassemblyTextEdit::*)()>(_a, &DisassemblyTextEdit::refreshContents, 0))
            return;
    }
}

const QMetaObject *DisassemblyTextEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DisassemblyTextEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DisassemblyTextEditE_t>.strings))
        return static_cast<void*>(this);
    return QPlainTextEdit::qt_metacast(_clname);
}

int DisassemblyTextEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QPlainTextEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void DisassemblyTextEdit::refreshContents()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
