/********************************************************************************
** Form generated from reading UI file 'DumpDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DUMPDIALOG_H
#define UI_DUMPDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_DumpDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *fileLayout;
    QLabel *fileLabel;
    QLineEdit *fileLE;
    QPushButton *browsePB;
    QHBoxLayout *addressLayout;
    QLabel *addressLabel;
    QLineEdit *addressLE;
    QHBoxLayout *lengthLayout;
    QLabel *lengthLabel;
    QLineEdit *lengthLE;
    QCheckBox *vaModeCB;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *DumpDialog)
    {
        if (DumpDialog->objectName().isEmpty())
            DumpDialog->setObjectName("DumpDialog");
        DumpDialog->resize(400, 200);
        verticalLayout = new QVBoxLayout(DumpDialog);
        verticalLayout->setObjectName("verticalLayout");
        fileLayout = new QHBoxLayout();
        fileLayout->setObjectName("fileLayout");
        fileLabel = new QLabel(DumpDialog);
        fileLabel->setObjectName("fileLabel");

        fileLayout->addWidget(fileLabel);

        fileLE = new QLineEdit(DumpDialog);
        fileLE->setObjectName("fileLE");

        fileLayout->addWidget(fileLE);

        browsePB = new QPushButton(DumpDialog);
        browsePB->setObjectName("browsePB");

        fileLayout->addWidget(browsePB);


        verticalLayout->addLayout(fileLayout);

        addressLayout = new QHBoxLayout();
        addressLayout->setObjectName("addressLayout");
        addressLabel = new QLabel(DumpDialog);
        addressLabel->setObjectName("addressLabel");

        addressLayout->addWidget(addressLabel);

        addressLE = new QLineEdit(DumpDialog);
        addressLE->setObjectName("addressLE");
        addressLE->setMaxLength(18);

        addressLayout->addWidget(addressLE);


        verticalLayout->addLayout(addressLayout);

        lengthLayout = new QHBoxLayout();
        lengthLayout->setObjectName("lengthLayout");
        lengthLabel = new QLabel(DumpDialog);
        lengthLabel->setObjectName("lengthLabel");

        lengthLayout->addWidget(lengthLabel);

        lengthLE = new QLineEdit(DumpDialog);
        lengthLE->setObjectName("lengthLE");
        lengthLE->setMaxLength(18);

        lengthLayout->addWidget(lengthLE);


        verticalLayout->addLayout(lengthLayout);

        vaModeCB = new QCheckBox(DumpDialog);
        vaModeCB->setObjectName("vaModeCB");
        vaModeCB->setChecked(true);

        verticalLayout->addWidget(vaModeCB);

        buttonBox = new QDialogButtonBox(DumpDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(DumpDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, DumpDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, DumpDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(DumpDialog);
    } // setupUi

    void retranslateUi(QDialog *DumpDialog)
    {
        DumpDialog->setWindowTitle(QCoreApplication::translate("DumpDialog", "Dump to file", nullptr));
        fileLabel->setText(QCoreApplication::translate("DumpDialog", "File:", nullptr));
        fileLE->setPlaceholderText(QCoreApplication::translate("DumpDialog", "Output file path", nullptr));
        browsePB->setText(QCoreApplication::translate("DumpDialog", "Browse...", nullptr));
        addressLabel->setText(QCoreApplication::translate("DumpDialog", "Address:", nullptr));
        addressLE->setPlaceholderText(QCoreApplication::translate("DumpDialog", "0x00000000", nullptr));
        lengthLabel->setText(QCoreApplication::translate("DumpDialog", "Length:", nullptr));
        lengthLE->setPlaceholderText(QCoreApplication::translate("DumpDialog", "Number of bytes", nullptr));
        vaModeCB->setText(QCoreApplication::translate("DumpDialog", "Use virtual addressing (io.va)", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DumpDialog: public Ui_DumpDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DUMPDIALOG_H
