/****************************************************************************
** Meta object code from reading C++ file 'MainWindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/core/MainWindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MainWindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainWindow",
        "uiReady",
        "",
        "finalizeOpen",
        "updateStatusBar",
        "RVA",
        "addr",
        "name",
        "refreshAll",
        "seekToFunctionLastInstruction",
        "seekToFunctionStart",
        "setTabLocation",
        "on_actionTabs_triggered",
        "on_actionAnalyze_triggered",
        "on_actionAnalyzeFunction_triggered",
        "on_actionAutonameAll_triggered",
        "on_actionSwitchJumpTable_triggered",
        "on_actionAnalysisSettings_triggered",
        "on_actionPatchInstruction_triggered",
        "on_actionPatchString_triggered",
        "on_actionPatchBytes_triggered",
        "lockDocks",
        "lock",
        "on_actionRun_Script_triggered",
        "on_actionRunR2jsScript_triggered",
        "on_actionScripts_triggered",
        "toggleResponsive",
        "maybe",
        "openNewFileFailed",
        "toggleOverview",
        "visibility",
        "GraphWidget*",
        "targetGraph",
        "on_actionAbout_triggered",
        "on_actionIssue_triggered",
        "on_actionR2pm_triggered",
        "on_actionPackageManagerPrefs_triggered",
        "websiteClicked",
        "fortuneClicked",
        "bookClicked",
        "checkForUpdatesClicked",
        "addExtraGraph",
        "addExtraHexdump",
        "addExtraDisassembly",
        "addExtraDecompiler",
        "addExtraCustomCommand",
        "on_actionRefresh_Panels_triggered",
        "on_actionDisasAdd_comment_triggered",
        "on_actionDefault_triggered",
        "on_actionNew_triggered",
        "on_actionManageAddressSpace_triggered",
        "on_actionSave_triggered",
        "on_actionSaveAs_triggered",
        "on_actionBackward_triggered",
        "on_actionForward_triggered",
        "on_actionMap_triggered",
        "on_actionTabs_on_Top_triggered",
        "on_actionReset_settings_triggered",
        "on_actionQuit_triggered",
        "on_actionHighlight_triggered",
        "on_actionRefresh_contents_triggered",
        "on_actionSettings_triggered",
        "on_actionStart_Web_Server_triggered",
        "checked",
        "on_actionImportPDB_triggered",
        "on_actionImportSymbols_triggered",
        "on_actionImportDWARF_triggered",
        "on_actionImportFLIRT_triggered",
        "on_actionImportProjectArchive_triggered",
        "on_actionExport_as_code_triggered",
        "on_actionDump_triggered",
        "on_actionExportDWARF_triggered",
        "on_actionExportProjectArchive_triggered",
        "on_actionGrouped_dock_dragging_triggered",
        "projectSaved",
        "successfully",
        "updateTasksIndicator",
        "mousePressEvent",
        "QMouseEvent*",
        "event",
        "eventFilter",
        "object",
        "QEvent*",
        "toggleDebugView",
        "chooseThemeIcons",
        "onZoomIn",
        "onZoomOut",
        "onZoomReset",
        "setAvailableIOModeOptions",
        "updateVisualNavbarLocation",
        "Configuration::VisualNavbarLocation",
        "location",
        "repositionSuperBottomNavbar"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'uiReady'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'finalizeOpen'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateStatusBar'
        QtMocHelpers::SlotData<void(RVA, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'updateStatusBar'
        QtMocHelpers::SlotData<void(RVA)>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'refreshAll'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'seekToFunctionLastInstruction'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'seekToFunctionStart'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setTabLocation'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'on_actionTabs_triggered'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'on_actionAnalyze_triggered'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'on_actionAnalyzeFunction_triggered'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'on_actionAutonameAll_triggered'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'on_actionSwitchJumpTable_triggered'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'on_actionAnalysisSettings_triggered'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'on_actionPatchInstruction_triggered'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'on_actionPatchString_triggered'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'on_actionPatchBytes_triggered'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'lockDocks'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'on_actionRun_Script_triggered'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'on_actionRunR2jsScript_triggered'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'on_actionScripts_triggered'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleResponsive'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'openNewFileFailed'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleOverview'
        QtMocHelpers::SlotData<void(bool, GraphWidget *)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 }, { 0x80000000 | 31, 32 },
        }}),
        // Slot 'on_actionAbout_triggered'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionIssue_triggered'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionR2pm_triggered'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionPackageManagerPrefs_triggered'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'websiteClicked'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fortuneClicked'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'bookClicked'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'checkForUpdatesClicked'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addExtraGraph'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addExtraHexdump'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addExtraDisassembly'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addExtraDecompiler'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addExtraCustomCommand'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionRefresh_Panels_triggered'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionDisasAdd_comment_triggered'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionDefault_triggered'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionNew_triggered'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionManageAddressSpace_triggered'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSave_triggered'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSaveAs_triggered'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionBackward_triggered'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionForward_triggered'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionMap_triggered'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionTabs_on_Top_triggered'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionReset_settings_triggered'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionQuit_triggered'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionHighlight_triggered'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionRefresh_contents_triggered'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSettings_triggered'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionStart_Web_Server_triggered'
        QtMocHelpers::SlotData<void(bool)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 63 },
        }}),
        // Slot 'on_actionImportPDB_triggered'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionImportSymbols_triggered'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionImportDWARF_triggered'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionImportFLIRT_triggered'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionImportProjectArchive_triggered'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionExport_as_code_triggered'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionDump_triggered'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionExportDWARF_triggered'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionExportProjectArchive_triggered'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionGrouped_dock_dragging_triggered'
        QtMocHelpers::SlotData<void(bool)>(73, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 63 },
        }}),
        // Slot 'projectSaved'
        QtMocHelpers::SlotData<void(bool, const QString &)>(74, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 75 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'updateTasksIndicator'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'mousePressEvent'
        QtMocHelpers::SlotData<void(QMouseEvent *)>(77, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 78, 79 },
        }}),
        // Slot 'eventFilter'
        QtMocHelpers::SlotData<bool(QObject *, QEvent *)>(80, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::QObjectStar, 81 }, { 0x80000000 | 82, 79 },
        }}),
        // Slot 'event'
        QtMocHelpers::SlotData<bool(QEvent *)>(79, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { 0x80000000 | 82, 79 },
        }}),
        // Slot 'toggleDebugView'
        QtMocHelpers::SlotData<void()>(83, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'chooseThemeIcons'
        QtMocHelpers::SlotData<void()>(84, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onZoomIn'
        QtMocHelpers::SlotData<void()>(85, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onZoomOut'
        QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onZoomReset'
        QtMocHelpers::SlotData<void()>(87, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setAvailableIOModeOptions'
        QtMocHelpers::SlotData<void()>(88, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateVisualNavbarLocation'
        QtMocHelpers::SlotData<void(Configuration::VisualNavbarLocation)>(89, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 90, 91 },
        }}),
        // Slot 'repositionSuperBottomNavbar'
        QtMocHelpers::SlotData<void()>(92, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MainWindowE_t>.metaTypes,
    nullptr
} };

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->uiReady(); break;
        case 1: _t->finalizeOpen(); break;
        case 2: _t->updateStatusBar((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->updateStatusBar((*reinterpret_cast<std::add_pointer_t<RVA>>(_a[1]))); break;
        case 4: _t->refreshAll(); break;
        case 5: _t->seekToFunctionLastInstruction(); break;
        case 6: _t->seekToFunctionStart(); break;
        case 7: _t->setTabLocation(); break;
        case 8: _t->on_actionTabs_triggered(); break;
        case 9: _t->on_actionAnalyze_triggered(); break;
        case 10: _t->on_actionAnalyzeFunction_triggered(); break;
        case 11: _t->on_actionAutonameAll_triggered(); break;
        case 12: _t->on_actionSwitchJumpTable_triggered(); break;
        case 13: _t->on_actionAnalysisSettings_triggered(); break;
        case 14: _t->on_actionPatchInstruction_triggered(); break;
        case 15: _t->on_actionPatchString_triggered(); break;
        case 16: _t->on_actionPatchBytes_triggered(); break;
        case 17: _t->lockDocks((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->on_actionRun_Script_triggered(); break;
        case 19: _t->on_actionRunR2jsScript_triggered(); break;
        case 20: _t->on_actionScripts_triggered(); break;
        case 21: _t->toggleResponsive((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->openNewFileFailed(); break;
        case 23: _t->toggleOverview((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GraphWidget*>>(_a[2]))); break;
        case 24: _t->on_actionAbout_triggered(); break;
        case 25: _t->on_actionIssue_triggered(); break;
        case 26: _t->on_actionR2pm_triggered(); break;
        case 27: _t->on_actionPackageManagerPrefs_triggered(); break;
        case 28: _t->websiteClicked(); break;
        case 29: _t->fortuneClicked(); break;
        case 30: _t->bookClicked(); break;
        case 31: _t->checkForUpdatesClicked(); break;
        case 32: _t->addExtraGraph(); break;
        case 33: _t->addExtraHexdump(); break;
        case 34: _t->addExtraDisassembly(); break;
        case 35: _t->addExtraDecompiler(); break;
        case 36: _t->addExtraCustomCommand(); break;
        case 37: _t->on_actionRefresh_Panels_triggered(); break;
        case 38: _t->on_actionDisasAdd_comment_triggered(); break;
        case 39: _t->on_actionDefault_triggered(); break;
        case 40: _t->on_actionNew_triggered(); break;
        case 41: _t->on_actionManageAddressSpace_triggered(); break;
        case 42: _t->on_actionSave_triggered(); break;
        case 43: _t->on_actionSaveAs_triggered(); break;
        case 44: _t->on_actionBackward_triggered(); break;
        case 45: _t->on_actionForward_triggered(); break;
        case 46: _t->on_actionMap_triggered(); break;
        case 47: _t->on_actionTabs_on_Top_triggered(); break;
        case 48: _t->on_actionReset_settings_triggered(); break;
        case 49: _t->on_actionQuit_triggered(); break;
        case 50: _t->on_actionHighlight_triggered(); break;
        case 51: _t->on_actionRefresh_contents_triggered(); break;
        case 52: _t->on_actionSettings_triggered(); break;
        case 53: _t->on_actionStart_Web_Server_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 54: _t->on_actionImportPDB_triggered(); break;
        case 55: _t->on_actionImportSymbols_triggered(); break;
        case 56: _t->on_actionImportDWARF_triggered(); break;
        case 57: _t->on_actionImportFLIRT_triggered(); break;
        case 58: _t->on_actionImportProjectArchive_triggered(); break;
        case 59: _t->on_actionExport_as_code_triggered(); break;
        case 60: _t->on_actionDump_triggered(); break;
        case 61: _t->on_actionExportDWARF_triggered(); break;
        case 62: _t->on_actionExportProjectArchive_triggered(); break;
        case 63: _t->on_actionGrouped_dock_dragging_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 64: _t->projectSaved((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 65: _t->updateTasksIndicator(); break;
        case 66: _t->mousePressEvent((*reinterpret_cast<std::add_pointer_t<QMouseEvent*>>(_a[1]))); break;
        case 67: { bool _r = _t->eventFilter((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QEvent*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 68: { bool _r = _t->event((*reinterpret_cast<std::add_pointer_t<QEvent*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 69: _t->toggleDebugView(); break;
        case 70: _t->chooseThemeIcons(); break;
        case 71: _t->onZoomIn(); break;
        case 72: _t->onZoomOut(); break;
        case 73: _t->onZoomReset(); break;
        case 74: _t->setAvailableIOModeOptions(); break;
        case 75: _t->updateVisualNavbarLocation((*reinterpret_cast<std::add_pointer_t<Configuration::VisualNavbarLocation>>(_a[1]))); break;
        case 76: _t->repositionSuperBottomNavbar(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::uiReady, 0))
            return;
    }
}

const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 77)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 77;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 77)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 77;
    }
    return _id;
}

// SIGNAL 0
void MainWindow::uiReady()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
