/********************************************************************************
** Form generated from reading UI file 'R2GraphWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_R2GRAPHWIDGET_H
#define UI_R2GRAPHWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_R2GraphWidget
{
public:
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_2;
    QComboBox *graphType;
    QLineEdit *customCommand;
    QPushButton *refreshButton;
    QSpacerItem *horizontalSpacer;

    void setupUi(QDockWidget *R2GraphWidget)
    {
        if (R2GraphWidget->objectName().isEmpty())
            R2GraphWidget->setObjectName("R2GraphWidget");
        R2GraphWidget->resize(439, 162);
        R2GraphWidget->setWindowTitle(QString::fromUtf8("R2 graphs"));
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        verticalLayout = new QVBoxLayout(dockWidgetContents);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        graphType = new QComboBox(dockWidgetContents);
        graphType->setObjectName("graphType");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(graphType->sizePolicy().hasHeightForWidth());
        graphType->setSizePolicy(sizePolicy);
        graphType->setEditable(false);

        horizontalLayout_2->addWidget(graphType);

        customCommand = new QLineEdit(dockWidgetContents);
        customCommand->setObjectName("customCommand");
        customCommand->setEnabled(true);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(1);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(customCommand->sizePolicy().hasHeightForWidth());
        customCommand->setSizePolicy(sizePolicy1);

        horizontalLayout_2->addWidget(customCommand);

        refreshButton = new QPushButton(dockWidgetContents);
        refreshButton->setObjectName("refreshButton");
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/img/icons/arrow_right.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        refreshButton->setIcon(icon);

        horizontalLayout_2->addWidget(refreshButton);

        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout_2);

        R2GraphWidget->setWidget(dockWidgetContents);

        retranslateUi(R2GraphWidget);

        QMetaObject::connectSlotsByName(R2GraphWidget);
    } // setupUi

    void retranslateUi(QDockWidget *R2GraphWidget)
    {
        customCommand->setPlaceholderText(QCoreApplication::translate("R2GraphWidget", "ag...", nullptr));
        refreshButton->setText(QString());
        (void)R2GraphWidget;
    } // retranslateUi

};

namespace Ui {
    class R2GraphWidget: public Ui_R2GraphWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_R2GRAPHWIDGET_H
