/********************************************************************************
** Form generated from reading UI file 'EditFunctionDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITFUNCTIONDIALOG_H
#define UI_EDITFUNCTIONDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_EditFunctionDialog
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *nameLabel;
    QLineEdit *nameLineEdit;
    QLabel *startLabel;
    QLineEdit *startLineEdit;
    QLabel *stackSizeLabel;
    QLineEdit *stackSizeLineEdit;
    QLabel *callConLabel;
    QComboBox *callConComboBox;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *EditFunctionDialog)
    {
        if (EditFunctionDialog->objectName().isEmpty())
            EditFunctionDialog->setObjectName("EditFunctionDialog");
        EditFunctionDialog->resize(318, 192);
        EditFunctionDialog->setToolTipDuration(0);
        verticalLayout = new QVBoxLayout(EditFunctionDialog);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(2, 5, 2, 2);
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setContentsMargins(-1, 0, -1, -1);
        nameLabel = new QLabel(EditFunctionDialog);
        nameLabel->setObjectName("nameLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, nameLabel);

        nameLineEdit = new QLineEdit(EditFunctionDialog);
        nameLineEdit->setObjectName("nameLineEdit");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, nameLineEdit);

        startLabel = new QLabel(EditFunctionDialog);
        startLabel->setObjectName("startLabel");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, startLabel);

        startLineEdit = new QLineEdit(EditFunctionDialog);
        startLineEdit->setObjectName("startLineEdit");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, startLineEdit);

        stackSizeLabel = new QLabel(EditFunctionDialog);
        stackSizeLabel->setObjectName("stackSizeLabel");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, stackSizeLabel);

        stackSizeLineEdit = new QLineEdit(EditFunctionDialog);
        stackSizeLineEdit->setObjectName("stackSizeLineEdit");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, stackSizeLineEdit);

        callConLabel = new QLabel(EditFunctionDialog);
        callConLabel->setObjectName("callConLabel");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, callConLabel);

        callConComboBox = new QComboBox(EditFunctionDialog);
        callConComboBox->setObjectName("callConComboBox");

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, callConComboBox);


        verticalLayout->addLayout(formLayout);

        buttonBox = new QDialogButtonBox(EditFunctionDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(EditFunctionDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, EditFunctionDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, EditFunctionDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(EditFunctionDialog);
    } // setupUi

    void retranslateUi(QDialog *EditFunctionDialog)
    {
        EditFunctionDialog->setWindowTitle(QCoreApplication::translate("EditFunctionDialog", "Edit Function", nullptr));
        nameLabel->setText(QCoreApplication::translate("EditFunctionDialog", "Name of function", nullptr));
        startLabel->setText(QCoreApplication::translate("EditFunctionDialog", "Start address", nullptr));
        stackSizeLabel->setText(QCoreApplication::translate("EditFunctionDialog", "Stack size", nullptr));
        callConLabel->setText(QCoreApplication::translate("EditFunctionDialog", "Calling convention", nullptr));
    } // retranslateUi

};

namespace Ui {
    class EditFunctionDialog: public Ui_EditFunctionDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_EDITFUNCTIONDIALOG_H
