/********************************************************************************
** Form generated from reading UI file 'R2TaskDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_R2TASKDIALOG_H
#define UI_R2TASKDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_R2TaskDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *descLabel;
    QLabel *timeLabel;
    QProgressBar *progressBar;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *R2TaskDialog)
    {
        if (R2TaskDialog->objectName().isEmpty())
            R2TaskDialog->setObjectName("R2TaskDialog");
        R2TaskDialog->resize(400, 87);
        verticalLayout = new QVBoxLayout(R2TaskDialog);
        verticalLayout->setObjectName("verticalLayout");
        descLabel = new QLabel(R2TaskDialog);
        descLabel->setObjectName("descLabel");

        verticalLayout->addWidget(descLabel);

        timeLabel = new QLabel(R2TaskDialog);
        timeLabel->setObjectName("timeLabel");

        verticalLayout->addWidget(timeLabel);

        progressBar = new QProgressBar(R2TaskDialog);
        progressBar->setObjectName("progressBar");
        progressBar->setMaximum(0);
        progressBar->setTextVisible(false);
        progressBar->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(progressBar);

        buttonBox = new QDialogButtonBox(R2TaskDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(R2TaskDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, R2TaskDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, R2TaskDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(R2TaskDialog);
    } // setupUi

    void retranslateUi(QDialog *R2TaskDialog)
    {
        R2TaskDialog->setWindowTitle(QCoreApplication::translate("R2TaskDialog", "R2 Task", nullptr));
        descLabel->setText(QCoreApplication::translate("R2TaskDialog", "R2 task in progress..", nullptr));
        timeLabel->setText(QCoreApplication::translate("R2TaskDialog", "Time", nullptr));
    } // retranslateUi

};

namespace Ui {
    class R2TaskDialog: public Ui_R2TaskDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_R2TASKDIALOG_H
