/********************************************************************************
** Form generated from reading UI file 'TypesWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TYPESWIDGET_H
#define UI_TYPESWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/ComboQuickFilterView.h"
#include "widgets/IaitoTreeView.h"

QT_BEGIN_NAMESPACE

class Ui_TypesWidget
{
public:
    QAction *actionExport_Types;
    QAction *actionLoad_New_Types;
    QAction *actionDelete_Type;
    QAction *actionLink_Type_To_Address;
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout;
    QSplitter *splitter;
    QWidget *leftWidget;
    QVBoxLayout *leftLayout;
    IaitoTreeView *typesTreeView;
    QTextEdit *typeDetailTextEdit;
    ComboQuickFilterView *quickFilterView;

    void setupUi(QDockWidget *TypesWidget)
    {
        if (TypesWidget->objectName().isEmpty())
            TypesWidget->setObjectName("TypesWidget");
        TypesWidget->resize(600, 300);
        TypesWidget->setWindowTitle(QString::fromUtf8("Types"));
        actionExport_Types = new QAction(TypesWidget);
        actionExport_Types->setObjectName("actionExport_Types");
        actionLoad_New_Types = new QAction(TypesWidget);
        actionLoad_New_Types->setObjectName("actionLoad_New_Types");
        actionDelete_Type = new QAction(TypesWidget);
        actionDelete_Type->setObjectName("actionDelete_Type");
        actionLink_Type_To_Address = new QAction(TypesWidget);
        actionLink_Type_To_Address->setObjectName("actionLink_Type_To_Address");
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        verticalLayout = new QVBoxLayout(dockWidgetContents);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        splitter = new QSplitter(dockWidgetContents);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Horizontal);
        leftWidget = new QWidget(splitter);
        leftWidget->setObjectName("leftWidget");
        leftLayout = new QVBoxLayout(leftWidget);
        leftLayout->setSpacing(0);
        leftLayout->setObjectName("leftLayout");
        leftLayout->setContentsMargins(0, 0, 0, 0);
        typesTreeView = new IaitoTreeView(leftWidget);
        typesTreeView->setObjectName("typesTreeView");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(typesTreeView->sizePolicy().hasHeightForWidth());
        typesTreeView->setSizePolicy(sizePolicy);
        typesTreeView->setContextMenuPolicy(Qt::CustomContextMenu);
        typesTreeView->setStyleSheet(QString::fromUtf8("IaitoTreeView::item\n"
"{\n"
"    padding-top: 1px;\n"
"    padding-bottom: 1px;\n"
"}"));
        typesTreeView->setFrameShape(QFrame::NoFrame);
        typesTreeView->setLineWidth(0);
        typesTreeView->setIndentation(8);
        typesTreeView->setSortingEnabled(true);

        leftLayout->addWidget(typesTreeView);

        splitter->addWidget(leftWidget);
        typeDetailTextEdit = new QTextEdit(splitter);
        typeDetailTextEdit->setObjectName("typeDetailTextEdit");
        typeDetailTextEdit->setReadOnly(true);
        typeDetailTextEdit->setFrameShape(QFrame::NoFrame);
        splitter->addWidget(typeDetailTextEdit);

        verticalLayout->addWidget(splitter);

        quickFilterView = new ComboQuickFilterView(dockWidgetContents);
        quickFilterView->setObjectName("quickFilterView");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(quickFilterView->sizePolicy().hasHeightForWidth());
        quickFilterView->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(quickFilterView);

        TypesWidget->setWidget(dockWidgetContents);

        retranslateUi(TypesWidget);

        QMetaObject::connectSlotsByName(TypesWidget);
    } // setupUi

    void retranslateUi(QDockWidget *TypesWidget)
    {
        actionExport_Types->setText(QCoreApplication::translate("TypesWidget", "Export Types", nullptr));
#if QT_CONFIG(tooltip)
        actionExport_Types->setToolTip(QCoreApplication::translate("TypesWidget", "Export Types", nullptr));
#endif // QT_CONFIG(tooltip)
        actionLoad_New_Types->setText(QCoreApplication::translate("TypesWidget", "Load New Types", nullptr));
#if QT_CONFIG(tooltip)
        actionLoad_New_Types->setToolTip(QCoreApplication::translate("TypesWidget", "Load New Types", nullptr));
#endif // QT_CONFIG(tooltip)
        actionDelete_Type->setText(QCoreApplication::translate("TypesWidget", "Delete Type", nullptr));
#if QT_CONFIG(tooltip)
        actionDelete_Type->setToolTip(QCoreApplication::translate("TypesWidget", "Delete Type", nullptr));
#endif // QT_CONFIG(tooltip)
        actionLink_Type_To_Address->setText(QCoreApplication::translate("TypesWidget", "Link Type to Address", nullptr));
        (void)TypesWidget;
    } // retranslateUi

};

namespace Ui {
    class TypesWidget: public Ui_TypesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TYPESWIDGET_H
