/********************************************************************************
** Form generated from reading UI file 'EditStringDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITSTRINGDIALOG_H
#define UI_EDITSTRINGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_EditStringDialog
{
public:
    QGridLayout *gridLayout;
    QDialogButtonBox *dialogButtonBox;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_size;
    QLabel *label_type;
    QLabel *label_address;
    QVBoxLayout *verticalLayout;
    QSpinBox *spinBox_size;
    QComboBox *comboBox_type;
    QLineEdit *lineEdit_address;
    QCheckBox *checkBox_autoSize;

    void setupUi(QDialog *EditStringDialog)
    {
        if (EditStringDialog->objectName().isEmpty())
            EditStringDialog->setObjectName("EditStringDialog");
        EditStringDialog->setWindowModality(Qt::WindowModal);
        EditStringDialog->resize(243, 109);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(EditStringDialog->sizePolicy().hasHeightForWidth());
        EditStringDialog->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(EditStringDialog);
        gridLayout->setObjectName("gridLayout");
        dialogButtonBox = new QDialogButtonBox(EditStringDialog);
        dialogButtonBox->setObjectName("dialogButtonBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(dialogButtonBox->sizePolicy().hasHeightForWidth());
        dialogButtonBox->setSizePolicy(sizePolicy1);
        dialogButtonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(dialogButtonBox, 1, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        label_size = new QLabel(EditStringDialog);
        label_size->setObjectName("label_size");
        label_size->setMinimumSize(QSize(0, 0));

        verticalLayout_2->addWidget(label_size);

        label_type = new QLabel(EditStringDialog);
        label_type->setObjectName("label_type");

        verticalLayout_2->addWidget(label_type);

        label_address = new QLabel(EditStringDialog);
        label_address->setObjectName("label_address");

        verticalLayout_2->addWidget(label_address);


        horizontalLayout->addLayout(verticalLayout_2);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        spinBox_size = new QSpinBox(EditStringDialog);
        spinBox_size->setObjectName("spinBox_size");
        spinBox_size->setMinimumSize(QSize(150, 24));

        verticalLayout->addWidget(spinBox_size);

        comboBox_type = new QComboBox(EditStringDialog);
        comboBox_type->setObjectName("comboBox_type");

        verticalLayout->addWidget(comboBox_type);

        lineEdit_address = new QLineEdit(EditStringDialog);
        lineEdit_address->setObjectName("lineEdit_address");

        verticalLayout->addWidget(lineEdit_address);


        horizontalLayout->addLayout(verticalLayout);

        checkBox_autoSize = new QCheckBox(EditStringDialog);
        checkBox_autoSize->setObjectName("checkBox_autoSize");

        horizontalLayout->addWidget(checkBox_autoSize, 0, Qt::AlignTop);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 2);

        QWidget::setTabOrder(spinBox_size, checkBox_autoSize);
        QWidget::setTabOrder(checkBox_autoSize, comboBox_type);
        QWidget::setTabOrder(comboBox_type, lineEdit_address);
        QWidget::setTabOrder(lineEdit_address, dialogButtonBox);

        retranslateUi(EditStringDialog);
        QObject::connect(dialogButtonBox, &QDialogButtonBox::accepted, EditStringDialog, qOverload<>(&QDialog::accept));
        QObject::connect(dialogButtonBox, &QDialogButtonBox::rejected, EditStringDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(EditStringDialog);
    } // setupUi

    void retranslateUi(QDialog *EditStringDialog)
    {
        EditStringDialog->setWindowTitle(QCoreApplication::translate("EditStringDialog", "Edit string", nullptr));
        label_size->setText(QCoreApplication::translate("EditStringDialog", "Size:", nullptr));
        label_type->setText(QCoreApplication::translate("EditStringDialog", "Type:", nullptr));
        label_address->setText(QCoreApplication::translate("EditStringDialog", "Address:", nullptr));
        lineEdit_address->setText(QString());
        checkBox_autoSize->setText(QCoreApplication::translate("EditStringDialog", "Auto", nullptr));
    } // retranslateUi

};

namespace Ui {
    class EditStringDialog: public Ui_EditStringDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_EDITSTRINGDIALOG_H
