/********************************************************************************
** Form generated from reading UI file 'FlagDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FLAGDIALOG_H
#define UI_FLAGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_FlagDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *labelAction;
    QFormLayout *formLayout;
    QLabel *labelFlag;
    QLineEdit *nameEdit;
    QLineEdit *sizeEdit;
    QLabel *labelSize;
    QLineEdit *commentEdit;
    QLabel *label;
    QLabel *label_2;
    QHBoxLayout *colorLayout;
    QLineEdit *colorEdit;
    QFrame *colorPreview;
    QLabel *labelOffset;
    QLineEdit *offsetEdit;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *FlagDialog)
    {
        if (FlagDialog->objectName().isEmpty())
            FlagDialog->setObjectName("FlagDialog");
        FlagDialog->resize(417, 399);
        verticalLayout = new QVBoxLayout(FlagDialog);
        verticalLayout->setObjectName("verticalLayout");
        labelAction = new QLabel(FlagDialog);
        labelAction->setObjectName("labelAction");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(labelAction->sizePolicy().hasHeightForWidth());
        labelAction->setSizePolicy(sizePolicy);

        verticalLayout->addWidget(labelAction);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setHorizontalSpacing(12);
        labelFlag = new QLabel(FlagDialog);
        labelFlag->setObjectName("labelFlag");
        QFont font;
        font.setBold(true);
        labelFlag->setFont(font);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, labelFlag);

        nameEdit = new QLineEdit(FlagDialog);
        nameEdit->setObjectName("nameEdit");
        nameEdit->setFrame(false);
        nameEdit->setPlaceholderText(QString::fromUtf8(""));

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, nameEdit);

        sizeEdit = new QLineEdit(FlagDialog);
        sizeEdit->setObjectName("sizeEdit");
        sizeEdit->setMaximumSize(QSize(100, 16777215));
        sizeEdit->setFrame(false);
        sizeEdit->setPlaceholderText(QString::fromUtf8(""));

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, sizeEdit);

        labelSize = new QLabel(FlagDialog);
        labelSize->setObjectName("labelSize");
        labelSize->setFont(font);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, labelSize);

        commentEdit = new QLineEdit(FlagDialog);
        commentEdit->setObjectName("commentEdit");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, commentEdit);

        label = new QLabel(FlagDialog);
        label->setObjectName("label");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label);

        label_2 = new QLabel(FlagDialog);
        label_2->setObjectName("label_2");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_2);

        colorLayout = new QHBoxLayout();
        colorLayout->setObjectName("colorLayout");
        colorEdit = new QLineEdit(FlagDialog);
        colorEdit->setObjectName("colorEdit");

        colorLayout->addWidget(colorEdit);

        colorPreview = new QFrame(FlagDialog);
        colorPreview->setObjectName("colorPreview");
        colorPreview->setMinimumSize(QSize(16, 16));
        colorPreview->setMaximumSize(QSize(16, 16));
        colorPreview->setFrameShape(QFrame::Shape::Box);

        colorLayout->addWidget(colorPreview);


        formLayout->setLayout(4, QFormLayout::ItemRole::FieldRole, colorLayout);

        labelOffset = new QLabel(FlagDialog);
        labelOffset->setObjectName("labelOffset");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, labelOffset);

        offsetEdit = new QLineEdit(FlagDialog);
        offsetEdit->setObjectName("offsetEdit");
        offsetEdit->setReadOnly(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, offsetEdit);


        verticalLayout->addLayout(formLayout);

        buttonBox = new QDialogButtonBox(FlagDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(FlagDialog);

        QMetaObject::connectSlotsByName(FlagDialog);
    } // setupUi

    void retranslateUi(QDialog *FlagDialog)
    {
        FlagDialog->setWindowTitle(QCoreApplication::translate("FlagDialog", "Add Flag", nullptr));
        labelAction->setText(QCoreApplication::translate("FlagDialog", "Add flag at", nullptr));
        labelFlag->setText(QCoreApplication::translate("FlagDialog", "Name:", nullptr));
        sizeEdit->setText(QCoreApplication::translate("FlagDialog", "1", nullptr));
        labelSize->setText(QCoreApplication::translate("FlagDialog", "Size:", nullptr));
        label->setText(QCoreApplication::translate("FlagDialog", "Comment", nullptr));
        label_2->setText(QCoreApplication::translate("FlagDialog", "Color", nullptr));
        labelOffset->setText(QCoreApplication::translate("FlagDialog", "Offset:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class FlagDialog: public Ui_FlagDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FLAGDIALOG_H
