/********************************************************************************
** Form generated from reading UI file 'InitializationFileEditor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INITIALIZATIONFILEEDITOR_H
#define UI_INITIALIZATIONFILEEDITOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_InitializationFileEditor
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *iaitoRCLoaded;
    QLabel *iaitoRCLoaded_1;
    QPlainTextEdit *ConfigFileEdit;
    QLabel *iaitoRCLoaded_2;
    QPlainTextEdit *ConfigFileEdit2;
    QHBoxLayout *buttonsLayout;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *executeNow;
    QDialogButtonBox *saveRC;

    void setupUi(QWidget *InitializationFileEditor)
    {
        if (InitializationFileEditor->objectName().isEmpty())
            InitializationFileEditor->setObjectName("InitializationFileEditor");
        verticalLayout = new QVBoxLayout(InitializationFileEditor);
        verticalLayout->setObjectName("verticalLayout");
        iaitoRCLoaded = new QLabel(InitializationFileEditor);
        iaitoRCLoaded->setObjectName("iaitoRCLoaded");

        verticalLayout->addWidget(iaitoRCLoaded);

        iaitoRCLoaded_1 = new QLabel(InitializationFileEditor);
        iaitoRCLoaded_1->setObjectName("iaitoRCLoaded_1");

        verticalLayout->addWidget(iaitoRCLoaded_1);

        ConfigFileEdit = new QPlainTextEdit(InitializationFileEditor);
        ConfigFileEdit->setObjectName("ConfigFileEdit");

        verticalLayout->addWidget(ConfigFileEdit);

        iaitoRCLoaded_2 = new QLabel(InitializationFileEditor);
        iaitoRCLoaded_2->setObjectName("iaitoRCLoaded_2");

        verticalLayout->addWidget(iaitoRCLoaded_2);

        ConfigFileEdit2 = new QPlainTextEdit(InitializationFileEditor);
        ConfigFileEdit2->setObjectName("ConfigFileEdit2");

        verticalLayout->addWidget(ConfigFileEdit2);

        buttonsLayout = new QHBoxLayout();
        buttonsLayout->setObjectName("buttonsLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        buttonsLayout->addItem(horizontalSpacer);

        executeNow = new QDialogButtonBox(InitializationFileEditor);
        executeNow->setObjectName("executeNow");
        executeNow->setStandardButtons(QDialogButtonBox::Retry);
        executeNow->setCenterButtons(false);

        buttonsLayout->addWidget(executeNow);

        saveRC = new QDialogButtonBox(InitializationFileEditor);
        saveRC->setObjectName("saveRC");
        saveRC->setStandardButtons(QDialogButtonBox::Save);

        buttonsLayout->addWidget(saveRC);


        verticalLayout->addLayout(buttonsLayout);


        retranslateUi(InitializationFileEditor);

        QMetaObject::connectSlotsByName(InitializationFileEditor);
    } // setupUi

    void retranslateUi(QWidget *InitializationFileEditor)
    {
        InitializationFileEditor->setWindowTitle(QCoreApplication::translate("InitializationFileEditor", "Startup Script Editor", nullptr));
        iaitoRCLoaded->setText(QCoreApplication::translate("InitializationFileEditor", "TextLabel", nullptr));
        iaitoRCLoaded_1->setText(QCoreApplication::translate("InitializationFileEditor", "Startup Script", nullptr));
        iaitoRCLoaded_2->setText(QCoreApplication::translate("InitializationFileEditor", "OnLoad Script", nullptr));
    } // retranslateUi

};

namespace Ui {
    class InitializationFileEditor: public Ui_InitializationFileEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_INITIALIZATIONFILEEDITOR_H
