/********************************************************************************
** Form generated from reading UI file 'WebserverOptionsWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WEBSERVEROPTIONSWIDGET_H
#define UI_WEBSERVEROPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_WebserverOptionsWidget
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *portLabel;
    QLineEdit *portEdit;
    QLabel *bindLabel;
    QLineEdit *bindEdit;
    QLabel *rootLabel;
    QLineEdit *rootEdit;
    QCheckBox *sandboxCheckBox;
    QCheckBox *uploadCheckBox;
    QCheckBox *dirlistCheckBox;
    QCheckBox *verboseCheckBox;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *WebserverOptionsWidget)
    {
        if (WebserverOptionsWidget->objectName().isEmpty())
            WebserverOptionsWidget->setObjectName("WebserverOptionsWidget");
        WebserverOptionsWidget->resize(489, 300);
        verticalLayout = new QVBoxLayout(WebserverOptionsWidget);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout->setLabelAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        portLabel = new QLabel(WebserverOptionsWidget);
        portLabel->setObjectName("portLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, portLabel);

        portEdit = new QLineEdit(WebserverOptionsWidget);
        portEdit->setObjectName("portEdit");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(portEdit->sizePolicy().hasHeightForWidth());
        portEdit->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, portEdit);

        bindLabel = new QLabel(WebserverOptionsWidget);
        bindLabel->setObjectName("bindLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, bindLabel);

        bindEdit = new QLineEdit(WebserverOptionsWidget);
        bindEdit->setObjectName("bindEdit");
        sizePolicy.setHeightForWidth(bindEdit->sizePolicy().hasHeightForWidth());
        bindEdit->setSizePolicy(sizePolicy);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, bindEdit);

        rootLabel = new QLabel(WebserverOptionsWidget);
        rootLabel->setObjectName("rootLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, rootLabel);

        rootEdit = new QLineEdit(WebserverOptionsWidget);
        rootEdit->setObjectName("rootEdit");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(1);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(rootEdit->sizePolicy().hasHeightForWidth());
        rootEdit->setSizePolicy(sizePolicy1);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, rootEdit);

        sandboxCheckBox = new QCheckBox(WebserverOptionsWidget);
        sandboxCheckBox->setObjectName("sandboxCheckBox");

        formLayout->setWidget(3, QFormLayout::ItemRole::SpanningRole, sandboxCheckBox);

        uploadCheckBox = new QCheckBox(WebserverOptionsWidget);
        uploadCheckBox->setObjectName("uploadCheckBox");

        formLayout->setWidget(4, QFormLayout::ItemRole::SpanningRole, uploadCheckBox);

        dirlistCheckBox = new QCheckBox(WebserverOptionsWidget);
        dirlistCheckBox->setObjectName("dirlistCheckBox");

        formLayout->setWidget(5, QFormLayout::ItemRole::SpanningRole, dirlistCheckBox);

        verboseCheckBox = new QCheckBox(WebserverOptionsWidget);
        verboseCheckBox->setObjectName("verboseCheckBox");

        formLayout->setWidget(6, QFormLayout::ItemRole::SpanningRole, verboseCheckBox);


        verticalLayout->addLayout(formLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(WebserverOptionsWidget);

        QMetaObject::connectSlotsByName(WebserverOptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *WebserverOptionsWidget)
    {
        WebserverOptionsWidget->setWindowTitle(QCoreApplication::translate("WebserverOptionsWidget", "Webserver", nullptr));
        portLabel->setText(QCoreApplication::translate("WebserverOptionsWidget", "Port (http.port):", nullptr));
        portEdit->setPlaceholderText(QCoreApplication::translate("WebserverOptionsWidget", "9090", nullptr));
        bindLabel->setText(QCoreApplication::translate("WebserverOptionsWidget", "Bind address (http.bind):", nullptr));
        bindEdit->setPlaceholderText(QCoreApplication::translate("WebserverOptionsWidget", "localhost", nullptr));
        rootLabel->setText(QCoreApplication::translate("WebserverOptionsWidget", "Root directory (http.root):", nullptr));
        sandboxCheckBox->setText(QCoreApplication::translate("WebserverOptionsWidget", "Enable sandbox (http.sandbox)", nullptr));
        uploadCheckBox->setText(QCoreApplication::translate("WebserverOptionsWidget", "Enable file upload (http.upload)", nullptr));
        dirlistCheckBox->setText(QCoreApplication::translate("WebserverOptionsWidget", "Enable directory listing (http.dirlist)", nullptr));
        verboseCheckBox->setText(QCoreApplication::translate("WebserverOptionsWidget", "Verbose logging (http.verbose)", nullptr));
    } // retranslateUi

};

namespace Ui {
    class WebserverOptionsWidget: public Ui_WebserverOptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_WEBSERVEROPTIONSWIDGET_H
