/****************************************************************************
** Meta object code from reading C++ file 'DecompilerWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/widgets/DecompilerWidget.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DecompilerWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16DecompilerWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto DecompilerWidget::qt_create_metaobjectdata<qt_meta_tag_ZN16DecompilerWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DecompilerWidget",
        "showDecompilerContextMenu",
        "",
        "QPoint",
        "pt",
        "highlightPC",
        "setAddressColumnVisible",
        "visible",
        "isAddressColumnVisible",
        "copy",
        "fontsUpdatedSlot",
        "colorsUpdatedSlot",
        "refreshDecompiler",
        "decompilerSelected",
        "optionActivated",
        "index",
        "cursorPositionChanged",
        "seekChanged",
        "decompilationFinished",
        "RCodeMeta*",
        "code",
        "startApprovedDecompilation",
        "editSourceFile",
        "openSourceDirectory",
        "editSourceLineMap",
        "selectSourcePath",
        "cancelDecompilation"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'showDecompilerContextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'highlightPC'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setAddressColumnVisible'
        QtMocHelpers::SlotData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'isAddressColumnVisible'
        QtMocHelpers::SlotData<bool() const>(8, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'copy'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fontsUpdatedSlot'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'colorsUpdatedSlot'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'refreshDecompiler'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'decompilerSelected'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'optionActivated'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'cursorPositionChanged'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'seekChanged'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'decompilationFinished'
        QtMocHelpers::SlotData<void(RCodeMeta *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'startApprovedDecompilation'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editSourceFile'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openSourceDirectory'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editSourceLineMap'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'selectSourcePath'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cancelDecompilation'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DecompilerWidget, qt_meta_tag_ZN16DecompilerWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DecompilerWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<MemoryDockWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DecompilerWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DecompilerWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16DecompilerWidgetE_t>.metaTypes,
    nullptr
} };

void DecompilerWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DecompilerWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showDecompilerContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 1: _t->highlightPC(); break;
        case 2: _t->setAddressColumnVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: { bool _r = _t->isAddressColumnVisible();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->copy(); break;
        case 5: _t->fontsUpdatedSlot(); break;
        case 6: _t->colorsUpdatedSlot(); break;
        case 7: _t->refreshDecompiler(); break;
        case 8: _t->decompilerSelected(); break;
        case 9: _t->optionActivated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->cursorPositionChanged(); break;
        case 11: _t->seekChanged(); break;
        case 12: _t->decompilationFinished((*reinterpret_cast<std::add_pointer_t<RCodeMeta*>>(_a[1]))); break;
        case 13: _t->startApprovedDecompilation(); break;
        case 14: _t->editSourceFile(); break;
        case 15: _t->openSourceDirectory(); break;
        case 16: _t->editSourceLineMap(); break;
        case 17: _t->selectSourcePath(); break;
        case 18: _t->cancelDecompilation(); break;
        default: ;
        }
    }
}

const QMetaObject *DecompilerWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DecompilerWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DecompilerWidgetE_t>.strings))
        return static_cast<void*>(this);
    return MemoryDockWidget::qt_metacast(_clname);
}

int DecompilerWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MemoryDockWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}
QT_WARNING_POP
