/********************************************************************************
** Form generated from reading UI file 'SamplesOptionsWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SAMPLESOPTIONSWIDGET_H
#define UI_SAMPLESOPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SamplesOptionsWidget
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *lookupUrlLabel;
    QHBoxLayout *lookupUrlLayout;
    QLineEdit *lookupUrlEdit;
    QPushButton *resetUrlButton;
    QLabel *dbPathTitleLabel;
    QLabel *dbPathLabel;
    QLabel *hintLabel;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *SamplesOptionsWidget)
    {
        if (SamplesOptionsWidget->objectName().isEmpty())
            SamplesOptionsWidget->setObjectName("SamplesOptionsWidget");
        SamplesOptionsWidget->resize(489, 200);
        verticalLayout = new QVBoxLayout(SamplesOptionsWidget);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        lookupUrlLabel = new QLabel(SamplesOptionsWidget);
        lookupUrlLabel->setObjectName("lookupUrlLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, lookupUrlLabel);

        lookupUrlLayout = new QHBoxLayout();
        lookupUrlLayout->setObjectName("lookupUrlLayout");
        lookupUrlEdit = new QLineEdit(SamplesOptionsWidget);
        lookupUrlEdit->setObjectName("lookupUrlEdit");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lookupUrlEdit->sizePolicy().hasHeightForWidth());
        lookupUrlEdit->setSizePolicy(sizePolicy);

        lookupUrlLayout->addWidget(lookupUrlEdit);

        resetUrlButton = new QPushButton(SamplesOptionsWidget);
        resetUrlButton->setObjectName("resetUrlButton");

        lookupUrlLayout->addWidget(resetUrlButton);


        formLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, lookupUrlLayout);

        dbPathTitleLabel = new QLabel(SamplesOptionsWidget);
        dbPathTitleLabel->setObjectName("dbPathTitleLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, dbPathTitleLabel);

        dbPathLabel = new QLabel(SamplesOptionsWidget);
        dbPathLabel->setObjectName("dbPathLabel");
        dbPathLabel->setTextInteractionFlags(Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, dbPathLabel);


        verticalLayout->addLayout(formLayout);

        hintLabel = new QLabel(SamplesOptionsWidget);
        hintLabel->setObjectName("hintLabel");
        hintLabel->setWordWrap(true);

        verticalLayout->addWidget(hintLabel);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(SamplesOptionsWidget);

        QMetaObject::connectSlotsByName(SamplesOptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *SamplesOptionsWidget)
    {
        SamplesOptionsWidget->setWindowTitle(QCoreApplication::translate("SamplesOptionsWidget", "Samples", nullptr));
        lookupUrlLabel->setText(QCoreApplication::translate("SamplesOptionsWidget", "SHA256 lookup URL:", nullptr));
        lookupUrlEdit->setPlaceholderText(QCoreApplication::translate("SamplesOptionsWidget", "https://www.virustotal.com/gui/file/", nullptr));
        resetUrlButton->setText(QCoreApplication::translate("SamplesOptionsWidget", "Reset", nullptr));
        dbPathTitleLabel->setText(QCoreApplication::translate("SamplesOptionsWidget", "Database:", nullptr));
        dbPathLabel->setText(QString());
        hintLabel->setText(QCoreApplication::translate("SamplesOptionsWidget", "The lookup URL is opened with a file's SHA256 appended. Files you open are registered automatically; use the Sha256 tab in the New File dialog to scan folders or manage entries.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SamplesOptionsWidget: public Ui_SamplesOptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SAMPLESOPTIONSWIDGET_H
